//
// Copyright (c) 2003, 2019, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2014, 2019, Red Hat Inc.
// All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_aarch64.hpp"
#include "adfiles/ad_aarch64.hpp"
#include "memory/allocation.inline.hpp"
#include "asm/macroAssembler.inline.hpp"
#include "code/compiledIC.hpp"
#include "code/vmreg.hpp"
#include "gc_interface/collectedHeap.inline.hpp"
#include "oops/compiledICHolder.hpp"
#include "oops/markOop.hpp"
#include "oops/method.hpp"
#include "oops/oop.inline.hpp"
#include "oops/oop.inline2.hpp"
#include "opto/cfgnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/biasedLocking.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "assembler_aarch64.inline.hpp"
#include "nativeInst_aarch64.hpp"
#include "vmreg_aarch64.inline.hpp"

//SourceForm

#line 987 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"


  // Optimizaton of volatile gets and puts
  // -------------------------------------
  //
  // AArch64 has ldar<x> and stlr<x> instructions which we can safely
  // use to implement volatile reads and writes. For a volatile read
  // we simply need
  //
  //   ldar<x>
  //
  // and for a volatile write we need
  //
  //   stlr<x>
  // 
  // Alternatively, we can implement them by pairing a normal
  // load/store with a memory barrier. For a volatile read we need
  // 
  //   ldr<x>
  //   dmb ishld
  //
  // for a volatile write
  //
  //   dmb ish
  //   str<x>
  //   dmb ish
  //
  // We can also use ldaxr and stlxr to implement compare and swap CAS
  // sequences. These are normally translated to an instruction
  // sequence like the following
  //
  //   dmb      ish
  // retry:
  //   ldxr<x>   rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //   dmb ishld
  //
  // Note that the exclusive store is already using an stlxr
  // instruction. That is required to ensure visibility to other
  // threads of the exclusive write (assuming it succeeds) before that
  // of any subsequent writes.
  //
  // The following instruction sequence is an improvement on the above
  //
  // retry:
  //   ldaxr<x>  rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //
  // We don't need the leading dmb ish since the stlxr guarantees
  // visibility of prior writes in the case that the swap is
  // successful. Crucially we don't have to worry about the case where
  // the swap is not successful since no valid program should be
  // relying on visibility of prior changes by the attempting thread
  // in the case where the CAS fails.
  //
  // Similarly, we don't need the trailing dmb ishld if we substitute
  // an ldaxr instruction since that will provide all the guarantees we
  // require regarding observation of changes made by other threads
  // before any change to the CAS address observed by the load.
  //
  // In order to generate the desired instruction sequence we need to
  // be able to identify specific 'signature' ideal graph node
  // sequences which i) occur as a translation of a volatile reads or
  // writes or CAS operations and ii) do not occur through any other
  // translation or graph transformation. We can then provide
  // alternative aldc matching rules which translate these node
  // sequences to the desired machine code sequences. Selection of the
  // alternative rules can be implemented by predicates which identify
  // the relevant node sequences.
  //
  // The ideal graph generator translates a volatile read to the node
  // sequence
  //
  //   LoadX[mo_acquire]
  //   MemBarAcquire
  //
  // As a special case when using the compressed oops optimization we
  // may also see this variant
  //
  //   LoadN[mo_acquire]
  //   DecodeN
  //   MemBarAcquire
  //
  // A volatile write is translated to the node sequence
  //
  //   MemBarRelease
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarVolatile
  //
  // n.b. the above node patterns are generated with a strict
  // 'signature' configuration of input and output dependencies (see
  // the predicates below for exact details). The card mark may be as
  // simple as a few extra nodes or, in a few GC configurations, may
  // include more complex control flow between the leading and
  // trailing memory barriers. However, whatever the card mark
  // configuration these signatures are unique to translated volatile
  // reads/stores -- they will not appear as a result of any other
  // bytecode translation or inlining nor as a consequence of
  // optimizing transforms.
  //
  // We also want to catch inlined unsafe volatile gets and puts and
  // be able to implement them using either ldar<x>/stlr<x> or some
  // combination of ldr<x>/stlr<x> and dmb instructions.
  //
  // Inlined unsafe volatiles puts manifest as a minor variant of the
  // normal volatile put node sequence containing an extra cpuorder
  // membar
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarVolatile
  //
  // n.b. as an aside, the cpuorder membar is not itself subject to
  // matching and translation by adlc rules.  However, the rule
  // predicates need to detect its presence in order to correctly
  // select the desired adlc rules.
  //
  // Inlined unsafe volatile gets manifest as a somewhat different
  // node sequence to a normal volatile get
  //
  //   MemBarCPUOrder
  //        ||       \\
  //   MemBarAcquire LoadX[mo_acquire]
  //        ||
  //   MemBarCPUOrder
  //
  // In this case the acquire membar does not directly depend on the
  // load. However, we can be sure that the load is generated from an
  // inlined unsafe volatile get if we see it dependent on this unique
  // sequence of membar nodes. Similarly, given an acquire membar we
  // can know that it was added because of an inlined unsafe volatile
  // get if it is fed and feeds a cpuorder membar and if its feed
  // membar also feeds an acquiring load.
  //
  // Finally an inlined (Unsafe) CAS operation is translated to the
  // following ideal graph
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   CompareAndSwapX {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarAcquire
  //
  // So, where we can identify these volatile read and write
  // signatures we can choose to plant either of the above two code
  // sequences. For a volatile read we can simply plant a normal
  // ldr<x> and translate the MemBarAcquire to a dmb. However, we can
  // also choose to inhibit translation of the MemBarAcquire and
  // inhibit planting of the ldr<x>, instead planting an ldar<x>.
  //
  // When we recognise a volatile store signature we can choose to
  // plant at a dmb ish as a translation for the MemBarRelease, a
  // normal str<x> and then a dmb ish for the MemBarVolatile.
  // Alternatively, we can inhibit translation of the MemBarRelease
  // and MemBarVolatile and instead plant a simple stlr<x>
  // instruction.
  //
  // when we recognise a CAS signature we can choose to plant a dmb
  // ish as a translation for the MemBarRelease, the conventional
  // macro-instruction sequence for the CompareAndSwap node (which
  // uses ldxr<x>) and then a dmb ishld for the MemBarAcquire.
  // Alternatively, we can elide generation of the dmb instructions
  // and plant the alternative CompareAndSwap macro-instruction
  // sequence (which uses ldaxr<x>).
  // 
  // Of course, the above only applies when we see these signature
  // configurations. We still want to plant dmb instructions in any
  // other cases where we may see a MemBarAcquire, MemBarRelease or
  // MemBarVolatile. For example, at the end of a constructor which
  // writes final/volatile fields we will see a MemBarRelease
  // instruction and this needs a 'dmb ish' lest we risk the
  // constructed object being visible without making the
  // final/volatile field writes visible.
  //
  // n.b. the translation rules below which rely on detection of the
  // volatile signatures and insert ldar<x> or stlr<x> are failsafe.
  // If we see anything other than the signature configurations we
  // always just translate the loads and stores to ldr<x> and str<x>
  // and translate acquire, release and volatile membars to the
  // relevant dmb instructions.
  //

  // is_CAS(int opcode)
  //
  // return true if opcode is one of the possible CompareAndSwapX
  // values otherwise false.

  bool is_CAS(int opcode)
  {
    return (opcode == Op_CompareAndSwapI ||
	    opcode == Op_CompareAndSwapL ||
	    opcode == Op_CompareAndSwapN ||
	    opcode == Op_CompareAndSwapP);
  }

// predicates controlling emit of ldr<x>/ldar<x> and associated dmb

bool unnecessary_acquire(const Node *barrier)
{
  assert(barrier->is_MemBar(), "expecting a membar");

  if (UseBarriersForVolatile) {
    // we need to plant a dmb
    return false;
  }

  MemBarNode* mb = barrier->as_MemBar();

  if (mb->trailing_load()) {
    return true;
  }

  if (mb->trailing_load_store()) {
    Node* load_store = mb->in(MemBarNode::Precedent);
    assert(load_store->is_LoadStore(), "unexpected graph shape");
    return is_CAS(load_store->Opcode());
  }

  return false;
}

bool needs_acquiring_load(const Node *n)
{
  assert(n->is_Load(), "expecting a load");
  if (UseBarriersForVolatile) {
    // we use a normal load and a dmb
    return false;
  }

  LoadNode *ld = n->as_Load();

  return ld->is_acquire();
}

bool unnecessary_release(const Node *n)
{
  assert((n->is_MemBar() &&
	  n->Opcode() == Op_MemBarRelease),
	 "expecting a release membar");

  if (UseBarriersForVolatile) {
    // we need to plant a dmb
    return false;
  }

  MemBarNode *barrier = n->as_MemBar();

  if (!barrier->leading()) {
    return false;
  } else {
    Node* trailing = barrier->trailing_membar();
    MemBarNode* trailing_mb = trailing->as_MemBar();
    assert(trailing_mb->trailing(), "Not a trailing membar?");
    assert(trailing_mb->leading_membar() == n, "inconsistent leading/trailing membars");

    Node* mem = trailing_mb->in(MemBarNode::Precedent);
    if (mem->is_Store()) {
      assert(mem->as_Store()->is_release(), "");
      assert(trailing_mb->Opcode() == Op_MemBarVolatile, "");
      return true;
    } else {
      assert(mem->is_LoadStore(), "");
      assert(trailing_mb->Opcode() == Op_MemBarAcquire, "");
      return is_CAS(mem->Opcode());
    }
  }

  return false;
}

bool unnecessary_volatile(const Node *n)
{
  // assert n->is_MemBar();
  if (UseBarriersForVolatile) {
    // we need to plant a dmb
    return false;
  }

  MemBarNode *mbvol = n->as_MemBar();

  bool release = mbvol->trailing_store();
  assert(!release || (mbvol->in(MemBarNode::Precedent)->is_Store() && mbvol->in(MemBarNode::Precedent)->as_Store()->is_release()), "");
#ifdef ASSERT
  if (release) {
    Node* leading = mbvol->leading_membar();
    assert(leading->Opcode() == Op_MemBarRelease, "");
    assert(leading->as_MemBar()->leading_store(), "");
    assert(leading->as_MemBar()->trailing_membar() == mbvol, "");
   }
#endif

  return release;
}

// predicates controlling emit of str<x>/stlr<x> and associated dmbs

bool needs_releasing_store(const Node *n)
{
  // assert n->is_Store();
  if (UseBarriersForVolatile) {
    // we use a normal store and dmb combination
    return false;
  }

  StoreNode *st = n->as_Store();

  return st->trailing_membar() != NULL;
}

// predicate controlling translation of CAS
//
// returns true if CAS needs to use an acquiring load otherwise false

bool needs_acquiring_load_exclusive(const Node *n)
{
  assert(is_CAS(n->Opcode()), "expecting a compare and swap");
  if (UseBarriersForVolatile) {
    return false;
  }

  LoadStoreNode* ldst = n->as_LoadStore();
  assert(ldst->trailing_membar() != NULL, "expected trailing membar");

  // so we can just return true here
  return true;
}

// predicate controlling translation of StoreCM
//
// returns true if a StoreStore must precede the card write otherwise
// false

bool unnecessary_storestore(const Node *storecm)
{
  assert(storecm->Opcode()  == Op_StoreCM, "expecting a StoreCM");

  // we need to generate a dmb ishst between an object put and the
  // associated card mark when we are using CMS without conditional
  // card marking

  if (UseConcMarkSweepGC && !UseCondCardMark) {
    return false;
  }

  // a storestore is unnecesary in all other cases

  return true;
}


#define __ _masm.

// advance declaratuons for helper functions to convert register
// indices to register objects

// the ad file has to provide implementations of certain methods
// expected by the generic code
//
// REQUIRED FUNCTIONALITY

//=============================================================================

// !!!!! Special hack to get all types of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.

int MachCallStaticJavaNode::ret_addr_offset()
{
  // call should be a simple bl
  // unless this is a method handle invoke in which case it is
  // mov(rfp, sp), bl, mov(sp, rfp)
  int off = 4;
  if (_method_handle_invoke) {
    off += 4;
  }
  return off;
}

int MachCallDynamicJavaNode::ret_addr_offset()
{
  return 16; // movz, movk, movk, bl
}

int MachCallRuntimeNode::ret_addr_offset() {
  // for generated stubs the call will be
  //   bl(addr)
  // for real runtime callouts it will be six instructions
  // see aarch64_enc_java_to_runtime
  //   adr(rscratch2, retaddr)
  //   lea(rscratch1, RuntimeAddress(addr)
  //   stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)))
  //   blr(rscratch1)
  CodeBlob *cb = CodeCache::find_blob(_entry_point);
  if (cb) {
    return MacroAssembler::far_branch_size();
  } else {
    return 6 * NativeInstruction::instruction_size;
  }
}

// Indicate if the safepoint node needs the polling page as an input

// the shared code plants the oop data at the start of the generated
// code for the safepoint node and that needs ot be at the load
// instruction itself. so we cannot plant a mov of the safepoint poll
// address followed by a load. setting this to true means the mov is
// scheduled as a prior instruction. that's better for scheduling
// anyway.

bool SafePointNode::needs_polling_address_input()
{
  return true;
}

//=============================================================================

#ifndef PRODUCT
void MachBreakpointNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  st->print("BREAKPOINT");
}
#endif

void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  MacroAssembler _masm(&cbuf);
  __ brk(0);
}

uint MachBreakpointNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
  void MachNopNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("nop \t# %d bytes pad for loops and calls", _count);
  }
#endif

  void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc*) const {
    MacroAssembler _masm(&cbuf);
    for (int i = 0; i < _count; i++) { 
      __ nop();
    }
  }

  uint MachNopNode::size(PhaseRegAlloc*) const {
    return _count * NativeInstruction::instruction_size;
  }

//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = RegMask::Empty;

int Compile::ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

bool MachConstantBaseNode::requires_postalloc_expand() const { return false; }
void MachConstantBaseNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  ShouldNotReachHere();
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Empty encoding
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("-- \t// MachConstantBaseNode (empty encoding)");
}
#endif

#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;

  int framesize = C->frame_slots() << LogBytesPerInt;

  if (C->need_stack_bang(framesize))
    st->print("# stack bang size=%d\n\t", framesize);

  if (framesize == 0) {
    // Is this even possible?
    st->print("stp  lr, rfp, [sp, #%d]!", -(2 * wordSize)); 
  } else if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("sub  sp, sp, #%d\n\t", framesize);
    st->print("stp  rfp, lr, [sp, #%d]", framesize - 2 * wordSize);
  } else {
    st->print("stp  lr, rfp, [sp, #%d]!\n\t", -(2 * wordSize)); 
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("sub  sp, sp, rscratch1");
  }
}
#endif

void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  MacroAssembler _masm(&cbuf);

  // n.b. frame size includes space for return pc and rfp
  long framesize = ((long)C->frame_slots()) << LogBytesPerInt;
  assert(framesize%(2*wordSize) == 0, "must preserve 2*wordSize alignment");

  // insert a nop at the start of the prolog so we can patch in a
  // branch if we need to invalidate the method later
  __ nop();

  if (C->need_stack_bang(framesize))
    __ generate_stack_overflow_check(framesize);

  __ build_frame(framesize);

  if (VerifyStackAtCalls) {
    Unimplemented();
  }

  C->set_frame_complete(cbuf.insts_size());

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    Compile::ConstantTable& constant_table = C->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_); // too many variables; just compute it
                              // the hard way
}

int MachPrologNode::reloc() const
{
  return 0;
}

//=============================================================================

#ifndef PRODUCT
void MachEpilogNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;
  int framesize = C->frame_slots() << LogBytesPerInt;

  st->print("# pop frame %d\n\t",framesize);

  if (framesize == 0) {
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  } else if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("ldp  lr, rfp, [sp,#%d]\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, #%d\n\t", framesize);
  } else {
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, rscratch1\n\t");
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  }

  if (do_polling() && C->is_method_compilation()) {
    st->print("# touch polling page\n\t");
    st->print("mov  rscratch1, #" INTPTR_FORMAT "\n\t", p2i(os::get_polling_page()));
    st->print("ldr zr, [rscratch1]");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  MacroAssembler _masm(&cbuf);
  int framesize = C->frame_slots() << LogBytesPerInt;

  __ remove_frame(framesize);

  if (do_polling() && C->is_method_compilation()) {
    __ read_polling_page(rscratch1, os::get_polling_page(), relocInfo::poll_return_type);
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  // Variable size. Determine dynamically.
  return MachNode::size(ra_);
}

int MachEpilogNode::reloc() const {
  // Return number of relocatable values contained in this instruction.
  return 1; // 1 for polling page.
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

// This method seems to be obsolete. It is declared in machnode.hpp
// and defined in all *.ad files, but it is never called. Should we
// get rid of it?
int MachEpilogNode::safepoint_offset() const {
  assert(do_polling(), "no return for this epilog node");
  return 4;
}

//=============================================================================

// Figure out which register class each belongs in: rc_int, rc_float or
// rc_stack.
enum RC { rc_bad, rc_int, rc_float, rc_stack };

static enum RC rc_class(OptoReg::Name reg) {

  if (reg == OptoReg::Bad) {
    return rc_bad;
  }

  // we have 30 int registers * 2 halves
  // (rscratch1 and rscratch2 are omitted)

  if (reg < 60) {
    return rc_int;
  }

  // we have 32 float register * 2 halves
  if (reg < 60 + 128) {
    return rc_float;
  }

  // Between float regs & stack is the flags regs.
  assert(OptoReg::is_stack(reg), "blow up if spilling flags");

  return rc_stack;
}

uint MachSpillCopyNode::implementation(CodeBuffer *cbuf, PhaseRegAlloc *ra_, bool do_size, outputStream *st) const {
  Compile* C = ra_->C;

  // Get registers to move.
  OptoReg::Name src_hi = ra_->get_reg_second(in(1));
  OptoReg::Name src_lo = ra_->get_reg_first(in(1));
  OptoReg::Name dst_hi = ra_->get_reg_second(this);
  OptoReg::Name dst_lo = ra_->get_reg_first(this);

  enum RC src_hi_rc = rc_class(src_hi);
  enum RC src_lo_rc = rc_class(src_lo);
  enum RC dst_hi_rc = rc_class(dst_hi);
  enum RC dst_lo_rc = rc_class(dst_lo);

  assert(src_lo != OptoReg::Bad && dst_lo != OptoReg::Bad, "must move at least 1 register");

  if (src_hi != OptoReg::Bad) {
    assert((src_lo&1)==0 && src_lo+1==src_hi &&
           (dst_lo&1)==0 && dst_lo+1==dst_hi,
           "expected aligned-adjacent pairs");
  }

  if (src_lo == dst_lo && src_hi == dst_hi) {
    return 0;            // Self copy, no move.
  }

  bool is64 = (src_lo & 1) == 0 && src_lo + 1 == src_hi &&
              (dst_lo & 1) == 0 && dst_lo + 1 == dst_hi;
  int src_offset = ra_->reg2offset(src_lo);
  int dst_offset = ra_->reg2offset(dst_lo);

  if (bottom_type()->isa_vect() != NULL) {
    uint ireg = ideal_reg();
    assert(ireg == Op_VecD || ireg == Op_VecX, "must be 64 bit or 128 bit vector");
    if (cbuf) {
      MacroAssembler _masm(cbuf);
      assert((src_lo_rc != rc_int && dst_lo_rc != rc_int), "sanity");
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        assert((src_offset & 7) == 0 && (dst_offset & 7) == 0, "unaligned stack offset");
        if (ireg == Op_VecD) {
          __ unspill(rscratch1, true, src_offset);
          __ spill(rscratch1, true, dst_offset);
        } else {
          __ spill_copy128(src_offset, dst_offset);
        }
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ mov(as_FloatRegister(Matcher::_regEncode[dst_lo]),
               ireg == Op_VecD ? __ T8B : __ T16B,
               as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                       ireg == Op_VecD ? __ D : __ Q,
                       ra_->reg2offset(dst_lo));
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                       ireg == Op_VecD ? __ D : __ Q,
                       ra_->reg2offset(src_lo));
      } else {
        ShouldNotReachHere();
      }
    }
  } else if (cbuf) {
    MacroAssembler _masm(cbuf);
    switch (src_lo_rc) {
    case rc_int:
      if (dst_lo_rc == rc_int) {  // gpr --> gpr copy
        if (is64) {
            __ mov(as_Register(Matcher::_regEncode[dst_lo]),
                   as_Register(Matcher::_regEncode[src_lo]));
        } else {
            MacroAssembler _masm(cbuf);
            __ movw(as_Register(Matcher::_regEncode[dst_lo]),
                    as_Register(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // gpr --> fpr copy
        if (is64) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        }
      } else {                    // gpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_Register(Matcher::_regEncode[src_lo]), is64, dst_offset);
      }
      break;
    case rc_float:
      if (dst_lo_rc == rc_int) {  // fpr --> gpr copy
        if (is64) {
            __ fmovd(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // fpr --> fpr copy
          if (cbuf) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else {                    // fpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 is64 ? __ D : __ S, dst_offset);
      }
      break;
    case rc_stack:
      if (dst_lo_rc == rc_int) {  // stack --> gpr load
        __ unspill(as_Register(Matcher::_regEncode[dst_lo]), is64, src_offset);
      } else if (dst_lo_rc == rc_float) { // stack --> fpr load
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   is64 ? __ D : __ S, src_offset);
      } else {                    // stack --> stack copy
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ unspill(rscratch1, is64, src_offset);
        __ spill(rscratch1, is64, dst_offset);
      }
      break;
    default:
      assert(false, "bad rc_class for spill");
      ShouldNotReachHere();
    }
  }

  if (st) {
    st->print("spill ");
    if (src_lo_rc == rc_stack) {
      st->print("[sp, #%d] -> ", ra_->reg2offset(src_lo));
    } else {
      st->print("%s -> ", Matcher::regName[src_lo]);
    }
    if (dst_lo_rc == rc_stack) {
      st->print("[sp, #%d]", ra_->reg2offset(dst_lo));
    } else {
      st->print("%s", Matcher::regName[dst_lo]);
    }
    if (bottom_type()->isa_vect() != NULL) {
      st->print("\t# vector spill size = %d", ideal_reg()==Op_VecD ? 64:128);
    } else {
      st->print("\t# spill size = %d", is64 ? 64:32);
    }
  }

  return 0;

}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  if (!ra_)
    st->print("N%d = SpillCopy(N%d)", _idx, in(1)->_idx);
  else
    implementation(NULL, ra_, false, st);
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation(&cbuf, ra_, false, NULL);
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
void BoxLockNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("add %s, rsp, #%d]\t# box lock",
            Matcher::regName[reg], offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  MacroAssembler _masm(&cbuf);

  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg    = ra_->get_encode(this);

  if (Assembler::operand_valid_for_add_sub_immediate(offset)) {
    __ add(as_Register(reg), sp, offset);
  } else {
    ShouldNotReachHere();
  }
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  // BoxLockNode is not a MachNode, so we can't just call MachNode::size(ra_).
  return 4;
}

//=============================================================================

#ifndef PRODUCT
void MachUEPNode::format(PhaseRegAlloc* ra_, outputStream* st) const
{
  st->print_cr("# MachUEPNode");
  if (UseCompressedClassPointers) {
    st->print_cr("\tldrw rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
    if (Universe::narrow_klass_shift() != 0) {
      st->print_cr("\tdecode_klass_not_null rscratch1, rscratch1");
    }
  } else {
   st->print_cr("\tldr rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
  }
  st->print_cr("\tcmp r0, rscratch1\t # Inline cache check");
  st->print_cr("\tbne, SharedRuntime::_ic_miss_stub");
}
#endif

void MachUEPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const
{
  // This is the unverified entry point.
  MacroAssembler _masm(&cbuf);

  __ cmp_klass(j_rarg0, rscratch2, rscratch1);
  Label skip;
  // TODO
  // can we avoid this skip and still use a reloc?
  __ br(Assembler::EQ, skip);
  __ far_jump(RuntimeAddress(SharedRuntime::get_ic_miss_stub()));
  __ bind(skip);
}

uint MachUEPNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_);
}

// REQUIRED EMIT CODE

//=============================================================================

// Emit exception handler code.
int HandlerImpl::emit_exception_handler(CodeBuffer& cbuf)
{
  // mov rscratch1 #exception_blob_entry_point
  // br rscratch1
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_exception_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();
  __ far_jump(RuntimeAddress(OptoRuntime::exception_blob()->entry_point()));
  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// Emit deopt handler code.
int HandlerImpl::emit_deopt_handler(CodeBuffer& cbuf)
{
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_deopt_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();

  __ adr(lr, __ pc());
  __ far_jump(RuntimeAddress(SharedRuntime::deopt_blob()->unpack()));

  assert(__ offset() - offset <= (int) size_deopt_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// REQUIRED MATCHER CODE

//=============================================================================

const bool Matcher::match_rule_supported(int opcode) {

  // TODO 
  // identify extra cases that we might want to provide match rules for
  // e.g. Op_StrEquals and other intrinsics
  if (!has_match_rule(opcode)) {
    return false;
  }

  return true;  // Per default match rules are supported.
}

int Matcher::regnum_to_fpu_offset(int regnum)
{
  Unimplemented();
  return 0;
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.

  return (-32768 <= offset && offset < 32768);
}

const bool Matcher::isSimpleConstant64(jlong value) {
  // Will one (StoreL ConL) be cheaper than two (StoreI ConI)?.
  // Probably always true, even if a temp register is required.
  return true;
}

// true just means we have fast l2f conversion
const bool Matcher::convL2FSupported(void) {
  return true;
}

// Vector width in bytes.
const int Matcher::vector_width_in_bytes(BasicType bt) {
  int size = MIN2(16,(int)MaxVectorSize);
  // Minimum 2 values in vector
  if (size < 2*type2aelembytes(bt)) size = 0;
  // But never < 4
  if (size < 4) size = 0;
  return size;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}
const int Matcher::min_vector_size(const BasicType bt) {
//  For the moment limit the vector size to 8 bytes
    int size = 8 / type2aelembytes(bt);
    if (size < 2) size = 2;
    return size;
}

// Vector ideal reg.
const uint Matcher::vector_ideal_reg(int len) {
  switch(len) {
    case  8: return Op_VecD;
    case 16: return Op_VecX;
  }
  ShouldNotReachHere();
  return 0;
}

const uint Matcher::vector_shift_count_ideal_reg(int size) {
  switch(size) {
    case  8: return Op_VecD;
    case 16: return Op_VecX;
  }
  ShouldNotReachHere();
  return 0;
}

// AES support not yet implemented
const bool Matcher::pass_original_key_for_aes() {
  return false;
}

// x86 supports misaligned vectors store/load.
const bool Matcher::misaligned_vectors_ok() {
  return !AlignVector; // can be changed by flag
}

// false => size gets scaled to BytesPerLong, ok.
const bool Matcher::init_array_count_is_in_bytes = false;

// Threshold size for cleararray.
const int Matcher::init_array_short_size = 4 * BytesPerLong;

// Use conditional move (CMOVL)
const int Matcher::long_cmove_cost() {
  // long cmoves are no more expensive than int cmoves
  return 0;
}

const int Matcher::float_cmove_cost() {
  // float cmoves are no more expensive than int cmoves
  return 0;
}

// Does the CPU require late expand (see block.cpp for description of late expand)?
const bool Matcher::require_postalloc_expand = false;

// Should the Matcher clone shifts on addressing modes, expecting them
// to be subsumed into complex addressing expressions or compute them
// into registers?  True for Intel but false for most RISCs
const bool Matcher::clone_shift_expressions = false;

// Do we need to mask the count passed to shift instructions or does
// the cpu only look at the lower 5/6 bits anyway?
const bool Matcher::need_masked_shift_count = false;

// This affects two different things:
//  - how Decode nodes are matched
//  - how ImplicitNullCheck opportunities are recognized
// If true, the matcher will try to remove all Decodes and match them
// (as operands) into nodes. NullChecks are not prepared to deal with 
// Decodes by final_graph_reshaping().
// If false, final_graph_reshaping() forces the decode behind the Cmp
// for a NullCheck. The matcher matches the Decode node into a register.
// Implicit_null_check optimization moves the Decode along with the 
// memory operation back up before the NullCheck.
bool Matcher::narrow_oop_use_complex_address() {
  return Universe::narrow_oop_shift() == 0;
}

bool Matcher::narrow_klass_use_complex_address() {
// TODO
// decide whether we need to set this to true
  return false;
}

// Is it better to copy float constants, or load them directly from
// memory?  Intel can load a float constant from a direct address,
// requiring no extra registers.  Most RISCs will have to materialize
// an address into a register first, so they would do better to copy
// the constant from stack.
const bool Matcher::rematerialize_float_constants = false;

// If CPU can load and store mis-aligned doubles directly then no
// fixup is needed.  Else we split the double into 2 integer pieces
// and move it piece-by-piece.  Only happens when passing doubles into
// C code as the Java calling convention forces doubles to be aligned.
const bool Matcher::misaligned_doubles_ok = true;

// No-op on amd64
void Matcher::pd_implicit_null_fixup(MachNode *node, uint idx) {
  Unimplemented();
}

// Advertise here if the CPU requires explicit rounding operations to
// implement the UseStrictFP mode.
const bool Matcher::strict_fp_requires_explicit_rounding = false;

// Are floats converted to double when stored to stack during
// deoptimization?
bool Matcher::float_in_double() { return true; }

// Do ints take an entire long register or just half?
// The relevant question is how the int is callee-saved:
// the whole long is written but de-opt'ing will have to extract
// the relevant 32 bits.
const bool Matcher::int_in_long = true;

// Return whether or not this register is ever used as an argument.
// This function is used on startup to build the trampoline stubs in
// generateOptoStub.  Registers not mentioned will be killed by the VM
// call in the trampoline, and arguments in those registers not be
// available to the callee.
bool Matcher::can_be_java_arg(int reg)
{
  return
    reg ==  R0_num || reg == R0_H_num ||
    reg ==  R1_num || reg == R1_H_num ||
    reg ==  R2_num || reg == R2_H_num ||
    reg ==  R3_num || reg == R3_H_num ||
    reg ==  R4_num || reg == R4_H_num ||
    reg ==  R5_num || reg == R5_H_num ||
    reg ==  R6_num || reg == R6_H_num ||
    reg ==  R7_num || reg == R7_H_num ||
    reg ==  V0_num || reg == V0_H_num ||
    reg ==  V1_num || reg == V1_H_num ||
    reg ==  V2_num || reg == V2_H_num ||
    reg ==  V3_num || reg == V3_H_num ||
    reg ==  V4_num || reg == V4_H_num ||
    reg ==  V5_num || reg == V5_H_num ||
    reg ==  V6_num || reg == V6_H_num ||
    reg ==  V7_num || reg == V7_H_num;
}

bool Matcher::is_spillable_arg(int reg)
{
  return can_be_java_arg(reg);
}

bool Matcher::use_asm_for_ldiv_by_con(jlong divisor) {
  return false;
}

RegMask Matcher::divI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODI projection of divmodI.
RegMask Matcher::modI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for DIVL projection of divmodL.
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL.
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return FP_REG_mask();
}


#define MOV_VOLATILE(REG, BASE, INDEX, SCALE, DISP, SCRATCH, INSN)	\
  MacroAssembler _masm(&cbuf);						\
  {									\
    guarantee(INDEX == -1, "mode not permitted for volatile");		\
    guarantee(DISP == 0, "mode not permitted for volatile");		\
    guarantee(SCALE == 0, "mode not permitted for volatile");		\
    __ INSN(REG, as_Register(BASE));					\
  }

typedef void (MacroAssembler::* mem_insn)(Register Rt, const Address &adr);
typedef void (MacroAssembler::* mem_float_insn)(FloatRegister Rt, const Address &adr);
typedef void (MacroAssembler::* mem_vector_insn)(FloatRegister Rt,
                                  MacroAssembler::SIMD_RegVariant T, const Address &adr);

  // Used for all non-volatile memory accesses.  The use of
  // $mem->opcode() to discover whether this pattern uses sign-extended
  // offsets is something of a kludge.
  static void loadStore(MacroAssembler masm, mem_insn insn,
			 Register reg, int opcode,
			 Register base, int index, int size, int disp)
  {
    Address::extend scale;

    // Hooboy, this is fugly.  We need a way to communicate to the
    // encoder that the index needs to be sign extended, so we have to
    // enumerate all the cases.
    switch (opcode) {
    case INDINDEXSCALEDOFFSETI2L:
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDOFFSETI2LN:
    case INDINDEXSCALEDI2LN:
    case INDINDEXOFFSETI2L:
    case INDINDEXOFFSETI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      (masm.*insn)(reg, Address(base, disp));
    } else {
      if (disp == 0) {
	(masm.*insn)(reg, Address(base, as_Register(index), scale));
      } else {
	masm.lea(rscratch1, Address(base, disp));
	(masm.*insn)(reg, Address(rscratch1, as_Register(index), scale));
      }
    }
  }

  static void loadStore(MacroAssembler masm, mem_float_insn insn,
			 FloatRegister reg, int opcode,
			 Register base, int index, int size, int disp)
  {
    Address::extend scale;

    switch (opcode) {
    case INDINDEXSCALEDOFFSETI2L:
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDOFFSETI2LN:
    case INDINDEXSCALEDI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

     if (index == -1) {
      (masm.*insn)(reg, Address(base, disp));
    } else {
      if (disp == 0) {
	(masm.*insn)(reg, Address(base, as_Register(index), scale));
      } else {
	masm.lea(rscratch1, Address(base, disp));
	(masm.*insn)(reg, Address(rscratch1, as_Register(index), scale));
      }
    }
  }

  static void loadStore(MacroAssembler masm, mem_vector_insn insn,
                         FloatRegister reg, MacroAssembler::SIMD_RegVariant T,
                         int opcode, Register base, int index, int size, int disp)
  {
    if (index == -1) {
      (masm.*insn)(reg, T, Address(base, disp));
    } else {
      assert(disp == 0, "unsupported address mode");
      (masm.*insn)(reg, T, Address(base, as_Register(index), Address::lsl(size)));
    }
  }


#line 1315 "../generated/adfiles/ad_aarch64.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
  assert( INSN_COST == 100, "Expect (100) to equal 100");
  assert( BRANCH_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( CALL_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( VOLATILE_REF_COST == 1000, "Expect (10 * INSN_COST) to equal 1000");
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'C', // R19
  'C', // R19_H
  'C', // R20
  'C', // R20_H
  'C', // R21
  'C', // R21_H
  'C', // R22
  'C', // R22_H
  'C', // R23
  'C', // R23_H
  'C', // R24
  'C', // R24_H
  'C', // R25
  'C', // R25_H
  'C', // R26
  'C', // R26_H
  'N', // R27
  'N', // R27_H
  'N', // R28
  'N', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V8
  'C', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V9
  'C', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V10
  'C', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V11
  'C', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V12
  'C', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V13
  'C', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V14
  'C', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V15
  'C', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'E', // R19
  'E', // R19_H
  'E', // R20
  'E', // R20_H
  'E', // R21
  'E', // R21_H
  'E', // R22
  'E', // R22_H
  'E', // R23
  'E', // R23_H
  'E', // R24
  'E', // R24_H
  'E', // R25
  'E', // R25_H
  'E', // R26
  'E', // R26_H
  'E', // R27
  'E', // R27_H
  'E', // R28
  'E', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V8
  'C', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V9
  'C', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V10
  'C', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V11
  'C', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V12
  'C', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V13
  'C', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V14
  'C', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V15
  'C', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  0 // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immI_rule,
  /*    9 */  immI0_rule,
  /*   10 */  immI_1_rule,
  /*   11 */  immI_M1_rule,
  /*   12 */  immI_le_4_rule,
  /*   13 */  immI_31_rule,
  /*   14 */  immI_8_rule,
  /*   15 */  immI_16_rule,
  /*   16 */  immI_24_rule,
  /*   17 */  immI_32_rule,
  /*   18 */  immI_48_rule,
  /*   19 */  immI_56_rule,
  /*   20 */  immI_64_rule,
  /*   21 */  immI_255_rule,
  /*   22 */  immI_65535_rule,
  /*   23 */  immL_63_rule,
  /*   24 */  immL_255_rule,
  /*   25 */  immL_65535_rule,
  /*   26 */  immL_4294967295_rule,
  /*   27 */  immL_bitmask_rule,
  /*   28 */  immI_bitmask_rule,
  /*   29 */  immIScale_rule,
  /*   30 */  immI26_rule,
  /*   31 */  immI19_rule,
  /*   32 */  immIU12_rule,
  /*   33 */  immLU12_rule,
  /*   34 */  immIOffset_rule,
  /*   35 */  immIOffset4_rule,
  /*   36 */  immIOffset8_rule,
  /*   37 */  immIOffset16_rule,
  /*   38 */  immLoffset_rule,
  /*   39 */  immLoffset4_rule,
  /*   40 */  immLoffset8_rule,
  /*   41 */  immLoffset16_rule,
  /*   42 */  immIAddSub_rule,
  /*   43 */  immILog_rule,
  /*   44 */  immL_rule,
  /*   45 */  immL0_rule,
  /*   46 */  immL_1_rule,
  /*   47 */  immL_M1_rule,
  /*   48 */  immL_pc_off_rule,
  /*   49 */  immLAddSub_rule,
  /*   50 */  immLLog_rule,
  /*   51 */  immL_32bits_rule,
  /*   52 */  immP_rule,
  /*   53 */  immP0_rule,
  /*   54 */  immP_1_rule,
  /*   55 */  immPollPage_rule,
  /*   56 */  immByteMapBase_rule,
  /*   57 */  immP_M1_rule,
  /*   58 */  immP_M2_rule,
  /*   59 */  immD_rule,
  /*   60 */  immD0_rule,
  /*   61 */  immDPacked_rule,
  /*   62 */  immF_rule,
  /*   63 */  immF0_rule,
  /*   64 */  immFPacked_rule,
  /*   65 */  immN_rule,
  /*   66 */  immN0_rule,
  /*   67 */  immNKlass_rule,
  /*   68 */  iRegI_rule,
  /*   69 */  iRegINoSp_rule,
  /*   70 */  iRegL_rule,
  /*   71 */  iRegLNoSp_rule,
  /*   72 */  iRegP_rule,
  /*   73 */  iRegPNoSp_rule,
  /*   74 */  iRegP_R0_rule,
  /*   75 */  iRegP_R1_rule,
  /*   76 */  iRegP_R2_rule,
  /*   77 */  iRegP_R3_rule,
  /*   78 */  iRegP_R4_rule,
  /*   79 */  iRegP_R5_rule,
  /*   80 */  iRegP_R10_rule,
  /*   81 */  iRegL_R11_rule,
  /*   82 */  iRegP_FP_rule,
  /*   83 */  iRegI_R0_rule,
  /*   84 */  iRegI_R2_rule,
  /*   85 */  iRegI_R3_rule,
  /*   86 */  iRegI_R4_rule,
  /*   87 */  iRegN_rule,
  /*   88 */  iRegNNoSp_rule,
  /*   89 */  iRegIHeapbase_rule,
  /*   90 */  vRegF_rule,
  /*   91 */  vRegD_rule,
  /*   92 */  vecD_rule,
  /*   93 */  vecX_rule,
  /*   94 */  vRegD_V0_rule,
  /*   95 */  vRegD_V1_rule,
  /*   96 */  vRegD_V2_rule,
  /*   97 */  vRegD_V3_rule,
  /*   98 */  rFlagsReg_rule,
  /*   99 */  rFlagsRegU_rule,
  /*  100 */  inline_cache_RegP_rule,
  /*  101 */  interpreter_method_oop_RegP_rule,
  /*  102 */  thread_RegP_rule,
  /*  103 */  lr_RegP_rule,
  /*  104 */  indirect_rule,
  /*  105 */  indIndexScaledOffsetI_rule,
  /*  106 */  indIndexScaledOffsetL_rule,
  /*  107 */  indIndexOffsetI2L_rule,
  /*  108 */  indIndexScaledOffsetI2L_rule,
  /*  109 */  indIndexScaledI2L_rule,
  /*  110 */  indIndexScaled_rule,
  /*  111 */  indIndex_rule,
  /*  112 */  indOffI_rule,
  /*  113 */  indOffI4_rule,
  /*  114 */  indOffI8_rule,
  /*  115 */  indOffI16_rule,
  /*  116 */  indOffL_rule,
  /*  117 */  indOffL4_rule,
  /*  118 */  indOffL8_rule,
  /*  119 */  indOffL16_rule,
  /*  120 */  indirectN_rule,
  /*  121 */  indIndexScaledOffsetIN_rule,
  /*  122 */  indIndexScaledOffsetLN_rule,
  /*  123 */  indIndexOffsetI2LN_rule,
  /*  124 */  indIndexScaledOffsetI2LN_rule,
  /*  125 */  indIndexScaledI2LN_rule,
  /*  126 */  indIndexScaledN_rule,
  /*  127 */  indIndexN_rule,
  /*  128 */  indOffIN_rule,
  /*  129 */  indOffLN_rule,
  /*  130 */  thread_anchor_pc_rule,
  /*  131 */  stackSlotP_rule,
  /*  132 */  stackSlotI_rule,
  /*  133 */  stackSlotF_rule,
  /*  134 */  stackSlotD_rule,
  /*  135 */  stackSlotL_rule,
  /*  136 */  cmpOp_rule,
  /*  137 */  cmpOpU_rule,
  /*  138 */  iRegL2I_rule,
  // last operand
  /*  139 */  vmem4_rule,
  /*  140 */  vmem8_rule,
  /*  141 */  vmem16_rule,
  /*  142 */  memory_rule,
  /*  143 */  iRegIorL2I_rule,
  // last operand class
  /*  144 */  _LShiftL_iRegL_immIScale_rule,
  /*  145 */  _AddP_iRegP__LShiftL_iRegL_immIScale_rule,
  /*  146 */  _ConvI2L_iRegI__rule,
  /*  147 */  _AddP_iRegP__ConvI2L_iRegI__rule,
  /*  148 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  149 */  _AddP_iRegP__LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  150 */  _DecodeN_iRegN__rule,
  /*  151 */  _AddP__DecodeN_iRegN___LShiftL_iRegL_immIScale_rule,
  /*  152 */  _AddP__DecodeN_iRegN___ConvI2L_iRegI__rule,
  /*  153 */  _AddP__DecodeN_iRegN___LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  154 */  _LoadB_memory__rule,
  /*  155 */  _LoadUB_memory__rule,
  /*  156 */  _LoadS_memory__rule,
  /*  157 */  _LoadUS_memory__rule,
  /*  158 */  _LoadI_memory__rule,
  /*  159 */  _ConvI2L__LoadI_memory___rule,
  /*  160 */  _LoadB_indirect__rule,
  /*  161 */  _LoadUB_indirect__rule,
  /*  162 */  _LoadUS_indirect__rule,
  /*  163 */  _LoadS_indirect__rule,
  /*  164 */  _LoadI_indirect__rule,
  /*  165 */  _ConvI2L__LoadI_indirect___rule,
  /*  166 */  _LoadL_memory__rule,
  /*  167 */  _CastP2X_iRegP__rule,
  /*  168 */  _CastP2X__DecodeN_iRegN___rule,
  /*  169 */  _Binary_iRegP_iRegP_rule,
  /*  170 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  171 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  172 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  173 */  _Binary_iRegN_iRegN_rule,
  /*  174 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  175 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  176 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  177 */  _Binary_immI0_iRegIorL2I_rule,
  /*  178 */  _Binary_iRegIorL2I_immI0_rule,
  /*  179 */  _Binary_immI_1_immI0_rule,
  /*  180 */  _Binary_iRegL_iRegL_rule,
  /*  181 */  _Binary_iRegL_immL0_rule,
  /*  182 */  _Binary_immL0_iRegL_rule,
  /*  183 */  _Binary_iRegP_immP0_rule,
  /*  184 */  _Binary_immP0_iRegP_rule,
  /*  185 */  _Binary_iRegN_immN0_rule,
  /*  186 */  _Binary_immN0_iRegN_rule,
  /*  187 */  _Binary_vRegF_vRegF_rule,
  /*  188 */  _Binary_vRegD_vRegD_rule,
  /*  189 */  _ConvL2I_iRegL__rule,
  /*  190 */  _ConvI2L_iRegIorL2I__rule,
  /*  191 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  192 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  193 */  _MulL_iRegL_iRegL_rule,
  /*  194 */  _RShiftI_iRegIorL2I_immI_31_rule,
  /*  195 */  _URShiftI__RShiftI_iRegIorL2I_immI_31_immI_31_rule,
  /*  196 */  _RShiftL_iRegL_immL_63_rule,
  /*  197 */  _URShiftL__RShiftL_iRegL_immL_63_immL_63_rule,
  /*  198 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  199 */  _XorL_iRegL_immL_M1_rule,
  /*  200 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  201 */  _XorL_iRegL_iRegL_rule,
  /*  202 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  203 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  204 */  _URShiftL_iRegL_immI_rule,
  /*  205 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  206 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  207 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  208 */  _RShiftL_iRegL_immI_rule,
  /*  209 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  210 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  211 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  212 */  _LShiftL_iRegL_immI_rule,
  /*  213 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  214 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  215 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  216 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  217 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  218 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  219 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  220 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  221 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  222 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  223 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  224 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  225 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  226 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  227 */  _LShiftL_iRegL_iRegI_rule,
  /*  228 */  _SubI_immI_64_iRegI_rule,
  /*  229 */  _URShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  230 */  _SubI_immI0_iRegI_rule,
  /*  231 */  _URShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  232 */  _LShiftI_iRegI_iRegI_rule,
  /*  233 */  _SubI_immI_32_iRegI_rule,
  /*  234 */  _URShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  235 */  _URShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  236 */  _URShiftL_iRegL_iRegI_rule,
  /*  237 */  _LShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  238 */  _LShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  239 */  _URShiftI_iRegI_iRegI_rule,
  /*  240 */  _LShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  241 */  _LShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  242 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  243 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  244 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  245 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  246 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  247 */  _LShiftL_iRegL_immI_48_rule,
  /*  248 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  249 */  _LShiftL_iRegL_immI_32_rule,
  /*  250 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  251 */  _LShiftL_iRegL_immI_56_rule,
  /*  252 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  253 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  254 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  255 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  256 */  _AndL_iRegL_immL_255_rule,
  /*  257 */  _AndL_iRegL_immL_65535_rule,
  /*  258 */  _AndL_iRegL_immL_4294967295_rule,
  /*  259 */  _ConvF2D_vRegF__rule,
  /*  260 */  _SqrtD__ConvF2D_vRegF___rule,
  /*  261 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /*  262 */  _OverflowMulL_iRegL_iRegL_rule,
  /*  263 */  _CmpI_iRegIorL2I_immI0_rule,
  /*  264 */  _CmpL_iRegL_immL0_rule,
  /*  265 */  _CmpP_iRegP_immP0_rule,
  /*  266 */  _CmpN_iRegN_immN0_rule,
  /*  267 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /*  268 */  _CmpU_iRegIorL2I_immI0_rule,
  /*  269 */  _CmpUL_iRegL_immL0_rule,
  /*  270 */  _AndL_iRegL_immL_rule,
  /*  271 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /*  272 */  _AndI_iRegIorL2I_immI_rule,
  /*  273 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /*  274 */  _AndL_iRegL_iRegL_rule,
  /*  275 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  276 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  277 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /*  278 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /*  279 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /*  280 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /*  281 */  _Binary_iRegP_R3_immI_le_4_rule,
  /*  282 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /*  283 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /*  284 */  _MulVS_vecD_vecD_rule,
  /*  285 */  _MulVS_vecX_vecX_rule,
  /*  286 */  _MulVI_vecD_vecD_rule,
  /*  287 */  _MulVI_vecX_vecX_rule,
  // last internally defined operand
  /*  288 */  iRegINoSp_rule,
  /*  289 */  iRegLNoSp_rule,
  /*  290 */  iRegPNoSp_rule,
  /*  291 */  iRegPNoSp_rule,
  /*  292 */  iRegPNoSp_rule,
  /*  293 */  iRegPNoSp_rule,
  /*  294 */  iRegPNoSp_rule,
  /*  295 */  iRegNNoSp_rule,
  /*  296 */  iRegNNoSp_rule,
  /*  297 */  iRegNNoSp_rule,
  /*  298 */  vRegF_rule,
  /*  299 */  vRegF_rule,
  /*  300 */  vRegD_rule,
  /*  301 */  vRegD_rule,
  /*  302 */  iRegINoSp_rule,
  /*  303 */  iRegINoSp_rule,
  /*  304 */  iRegINoSp_rule,
  /*  305 */  iRegINoSp_rule,
  /*  306 */  iRegPNoSp_rule,
  /*  307 */  iRegLNoSp_rule,
  /*  308 */  iRegPNoSp_rule,
  /*  309 */  iRegPNoSp_rule,
  /*  310 */  iRegI_rule,
  /*  311 */  rFlagsReg_rule,
  /*  312 */  rFlagsReg_rule,
  /*  313 */  rFlagsReg_rule,
  /*  314 */  vRegF_rule,
  /*  315 */  vRegD_rule,
  /*  316 */  vRegF_rule,
  /*  317 */  vRegD_rule,
  /*  318 */  iRegINoSp_rule,
  /*  319 */  vRegF_rule,
  /*  320 */  iRegLNoSp_rule,
  /*  321 */  vRegD_rule,
  /*  322 */  iRegINoSp_rule,
  /*  323 */  vRegF_rule,
  /*  324 */  iRegLNoSp_rule,
  /*  325 */  vRegD_rule,
  /*  326 */  rFlagsReg_rule,
  /*  327 */  rFlagsReg_rule,
  /*  328 */  rFlagsReg_rule,
  /*  329 */  rFlagsReg_rule,
  /*  330 */  rFlagsReg_rule,
  /*  331 */  rFlagsReg_rule,
  /*  332 */  rFlagsReg_rule,
  /*  333 */  rFlagsReg_rule,
  /*  334 */  rFlagsReg_rule,
  /*  335 */  rFlagsReg_rule,
  /*  336 */  rFlagsReg_rule,
  /*  337 */  rFlagsReg_rule,
  /*  338 */  rFlagsReg_rule,
  /*  339 */  rFlagsReg_rule,
  /*  340 */  rFlagsReg_rule,
  /*  341 */  rFlagsReg_rule,
  /*  342 */  rFlagsRegU_rule,
  /*  343 */  rFlagsRegU_rule,
  /*  344 */  rFlagsRegU_rule,
  /*  345 */  rFlagsRegU_rule,
  /*  346 */  rFlagsReg_rule,
  /*  347 */  rFlagsReg_rule,
  /*  348 */  rFlagsReg_rule,
  /*  349 */  rFlagsReg_rule,
  /*  350 */  rFlagsRegU_rule,
  /*  351 */  rFlagsRegU_rule,
  /*  352 */  rFlagsRegU_rule,
  /*  353 */  rFlagsRegU_rule,
  /*  354 */  rFlagsRegU_rule,
  /*  355 */  rFlagsRegU_rule,
  /*  356 */  rFlagsRegU_rule,
  /*  357 */  rFlagsRegU_rule,
  /*  358 */  rFlagsReg_rule,
  /*  359 */  rFlagsReg_rule,
  /*  360 */  rFlagsReg_rule,
  /*  361 */  rFlagsReg_rule,
  /*  362 */  rFlagsReg_rule,
  /*  363 */  rFlagsReg_rule,
  /*  364 */  rFlagsReg_rule,
  /*  365 */  rFlagsReg_rule,
  /*  366 */  rFlagsReg_rule,
  /*  367 */  rFlagsReg_rule,
  /*  368 */  rFlagsReg_rule,
  /*  369 */  thread_RegP_rule,
  /*  370 */  vecD_rule,
  /*  371 */  vecD_rule,
  /*  372 */  vecX_rule,
  /*  373 */  vecX_rule,
  /*  374 */  iRegINoSp_rule,
  /*  375 */  iRegLNoSp_rule,
  /*  376 */  iRegINoSp_rule,
  /*  377 */  iRegLNoSp_rule,
  /*  378 */  iRegINoSp_rule,
  /*  379 */  iRegLNoSp_rule,
  /*  380 */  iRegINoSp_rule,
  /*  381 */  iRegLNoSp_rule,
  /*  382 */  iRegINoSp_rule,
  /*  383 */  iRegLNoSp_rule,
  /*  384 */  iRegLNoSp_rule,
  /*  385 */  iRegLNoSp_rule,
  /*  386 */  iRegINoSp_rule,
  /*  387 */  iRegPNoSp_rule,
  /*  388 */  iRegNNoSp_rule,
  /*  389 */  iRegPNoSp_rule,
  /*  390 */  iRegNNoSp_rule,
  /*  391 */  vRegF_rule,
  /*  392 */  vRegD_rule,
  /*  393 */  Universe_rule,
  /*  394 */  Universe_rule,
  /*  395 */  Universe_rule,
  /*  396 */  Universe_rule,
  /*  397 */  Universe_rule,
  /*  398 */  Universe_rule,
  /*  399 */  Universe_rule,
  /*  400 */  Universe_rule,
  /*  401 */  Universe_rule,
  /*  402 */  Universe_rule,
  /*  403 */  Universe_rule,
  /*  404 */  Universe_rule,
  /*  405 */  Universe_rule,
  /*  406 */  Universe_rule,
  /*  407 */  Universe_rule,
  /*  408 */  Universe_rule,
  /*  409 */  Universe_rule,
  /*  410 */  Universe_rule,
  /*  411 */  Universe_rule,
  /*  412 */  Universe_rule,
  /*  413 */  iRegINoSp_rule,
  /*  414 */  iRegLNoSp_rule,
  /*  415 */  iRegINoSp_rule,
  /*  416 */  iRegLNoSp_rule,
  /*  417 */  iRegINoSp_rule,
  /*  418 */  iRegINoSp_rule,
  /*  419 */  iRegLNoSp_rule,
  /*  420 */  iRegLNoSp_rule,
  /*  421 */  iRegINoSp_rule,
  /*  422 */  iRegLNoSp_rule,
  /*  423 */  iRegLNoSp_rule,
  /*  424 */  iRegPNoSp_rule,
  /*  425 */  iRegNNoSp_rule,
  /*  426 */  vRegF_rule,
  /*  427 */  vRegD_rule,
  /*  428 */  Universe_rule,
  /*  429 */  Universe_rule,
  /*  430 */  Universe_rule,
  /*  431 */  Universe_rule,
  /*  432 */  Universe_rule,
  /*  433 */  Universe_rule,
  /*  434 */  Universe_rule,
  /*  435 */  Universe_rule,
  /*  436 */  iRegINoSp_rule,
  /*  437 */  iRegLNoSp_rule,
  /*  438 */  iRegINoSp_rule,
  /*  439 */  iRegINoSp_rule,
  /*  440 */  iRegINoSp_rule,
  /*  441 */  iRegINoSp_rule,
  /*  442 */  iRegINoSp_rule,
  /*  443 */  iRegINoSp_rule,
  /*  444 */  Universe_rule,
  /*  445 */  Universe_rule,
  /*  446 */  Universe_rule,
  /*  447 */  Universe_rule,
  /*  448 */  Universe_rule,
  /*  449 */  Universe_rule,
  /*  450 */  Universe_rule,
  /*  451 */  Universe_rule,
  /*  452 */  Universe_rule,
  /*  453 */  Universe_rule,
  /*  454 */  Universe_rule,
  /*  455 */  iRegINoSp_rule,
  /*  456 */  iRegINoSp_rule,
  /*  457 */  iRegPNoSp_rule,
  /*  458 */  iRegNNoSp_rule,
  /*  459 */  iRegNNoSp_rule,
  /*  460 */  iRegPNoSp_rule,
  /*  461 */  iRegPNoSp_rule,
  /*  462 */  iRegNNoSp_rule,
  /*  463 */  iRegPNoSp_rule,
  /*  464 */  iRegPNoSp_rule,
  /*  465 */  iRegINoSp_rule,
  /*  466 */  iRegINoSp_rule,
  /*  467 */  iRegINoSp_rule,
  /*  468 */  iRegINoSp_rule,
  /*  469 */  iRegINoSp_rule,
  /*  470 */  iRegINoSp_rule,
  /*  471 */  iRegINoSp_rule,
  /*  472 */  iRegINoSp_rule,
  /*  473 */  iRegINoSp_rule,
  /*  474 */  iRegINoSp_rule,
  /*  475 */  iRegINoSp_rule,
  /*  476 */  iRegINoSp_rule,
  /*  477 */  iRegINoSp_rule,
  /*  478 */  iRegLNoSp_rule,
  /*  479 */  iRegINoSp_rule,
  /*  480 */  iRegPNoSp_rule,
  /*  481 */  iRegLNoSp_rule,
  /*  482 */  Universe_rule,
  /*  483 */  iRegLNoSp_rule,
  /*  484 */  Universe_rule,
  /*  485 */  iRegINoSp_rule,
  /*  486 */  Universe_rule,
  /*  487 */  iRegINoSp_rule,
  /*  488 */  Universe_rule,
  /*  489 */  iRegINoSp_rule,
  /*  490 */  iRegINoSp_rule,
  /*  491 */  iRegINoSp_rule,
  /*  492 */  iRegINoSp_rule,
  /*  493 */  iRegINoSp_rule,
  /*  494 */  iRegINoSp_rule,
  /*  495 */  iRegINoSp_rule,
  /*  496 */  iRegINoSp_rule,
  /*  497 */  iRegLNoSp_rule,
  /*  498 */  iRegLNoSp_rule,
  /*  499 */  iRegLNoSp_rule,
  /*  500 */  iRegLNoSp_rule,
  /*  501 */  iRegLNoSp_rule,
  /*  502 */  iRegLNoSp_rule,
  /*  503 */  iRegPNoSp_rule,
  /*  504 */  iRegPNoSp_rule,
  /*  505 */  iRegPNoSp_rule,
  /*  506 */  iRegPNoSp_rule,
  /*  507 */  iRegPNoSp_rule,
  /*  508 */  iRegPNoSp_rule,
  /*  509 */  iRegNNoSp_rule,
  /*  510 */  iRegNNoSp_rule,
  /*  511 */  iRegNNoSp_rule,
  /*  512 */  iRegNNoSp_rule,
  /*  513 */  iRegNNoSp_rule,
  /*  514 */  iRegNNoSp_rule,
  /*  515 */  vRegF_rule,
  /*  516 */  vRegF_rule,
  /*  517 */  vRegD_rule,
  /*  518 */  vRegD_rule,
  /*  519 */  iRegINoSp_rule,
  /*  520 */  iRegINoSp_rule,
  /*  521 */  iRegINoSp_rule,
  /*  522 */  iRegPNoSp_rule,
  /*  523 */  iRegPNoSp_rule,
  /*  524 */  iRegPNoSp_rule,
  /*  525 */  iRegPNoSp_rule,
  /*  526 */  iRegLNoSp_rule,
  /*  527 */  iRegPNoSp_rule,
  /*  528 */  iRegLNoSp_rule,
  /*  529 */  iRegLNoSp_rule,
  /*  530 */  iRegINoSp_rule,
  /*  531 */  iRegINoSp_rule,
  /*  532 */  iRegLNoSp_rule,
  /*  533 */  iRegLNoSp_rule,
  /*  534 */  iRegINoSp_rule,
  /*  535 */  iRegLNoSp_rule,
  /*  536 */  iRegINoSp_rule,
  /*  537 */  iRegLNoSp_rule,
  /*  538 */  iRegLNoSp_rule,
  /*  539 */  iRegLNoSp_rule,
  /*  540 */  iRegLNoSp_rule,
  /*  541 */  iRegINoSp_rule,
  /*  542 */  iRegINoSp_rule,
  /*  543 */  iRegINoSp_rule,
  /*  544 */  iRegLNoSp_rule,
  /*  545 */  iRegLNoSp_rule,
  /*  546 */  iRegLNoSp_rule,
  /*  547 */  iRegINoSp_rule,
  /*  548 */  iRegINoSp_rule,
  /*  549 */  iRegINoSp_rule,
  /*  550 */  iRegINoSp_rule,
  /*  551 */  iRegLNoSp_rule,
  /*  552 */  iRegLNoSp_rule,
  /*  553 */  iRegLNoSp_rule,
  /*  554 */  iRegLNoSp_rule,
  /*  555 */  iRegINoSp_rule,
  /*  556 */  iRegLNoSp_rule,
  /*  557 */  iRegINoSp_rule,
  /*  558 */  iRegINoSp_rule,
  /*  559 */  iRegINoSp_rule,
  /*  560 */  iRegINoSp_rule,
  /*  561 */  iRegINoSp_rule,
  /*  562 */  iRegINoSp_rule,
  /*  563 */  iRegLNoSp_rule,
  /*  564 */  iRegLNoSp_rule,
  /*  565 */  iRegLNoSp_rule,
  /*  566 */  iRegLNoSp_rule,
  /*  567 */  iRegLNoSp_rule,
  /*  568 */  iRegLNoSp_rule,
  /*  569 */  iRegLNoSp_rule,
  /*  570 */  iRegLNoSp_rule,
  /*  571 */  iRegINoSp_rule,
  /*  572 */  iRegINoSp_rule,
  /*  573 */  iRegINoSp_rule,
  /*  574 */  iRegLNoSp_rule,
  /*  575 */  iRegLNoSp_rule,
  /*  576 */  iRegINoSp_rule,
  /*  577 */  iRegINoSp_rule,
  /*  578 */  iRegLNoSp_rule,
  /*  579 */  iRegLNoSp_rule,
  /*  580 */  iRegINoSp_rule,
  /*  581 */  iRegINoSp_rule,
  /*  582 */  iRegLNoSp_rule,
  /*  583 */  iRegLNoSp_rule,
  /*  584 */  iRegINoSp_rule,
  /*  585 */  iRegINoSp_rule,
  /*  586 */  iRegLNoSp_rule,
  /*  587 */  iRegLNoSp_rule,
  /*  588 */  iRegINoSp_rule,
  /*  589 */  iRegINoSp_rule,
  /*  590 */  iRegLNoSp_rule,
  /*  591 */  iRegLNoSp_rule,
  /*  592 */  iRegINoSp_rule,
  /*  593 */  iRegINoSp_rule,
  /*  594 */  iRegLNoSp_rule,
  /*  595 */  iRegLNoSp_rule,
  /*  596 */  iRegINoSp_rule,
  /*  597 */  iRegINoSp_rule,
  /*  598 */  iRegINoSp_rule,
  /*  599 */  iRegINoSp_rule,
  /*  600 */  iRegLNoSp_rule,
  /*  601 */  iRegLNoSp_rule,
  /*  602 */  iRegLNoSp_rule,
  /*  603 */  iRegLNoSp_rule,
  /*  604 */  iRegINoSp_rule,
  /*  605 */  iRegINoSp_rule,
  /*  606 */  iRegINoSp_rule,
  /*  607 */  iRegINoSp_rule,
  /*  608 */  iRegLNoSp_rule,
  /*  609 */  iRegLNoSp_rule,
  /*  610 */  iRegLNoSp_rule,
  /*  611 */  iRegLNoSp_rule,
  /*  612 */  iRegINoSp_rule,
  /*  613 */  iRegINoSp_rule,
  /*  614 */  iRegINoSp_rule,
  /*  615 */  iRegINoSp_rule,
  /*  616 */  iRegLNoSp_rule,
  /*  617 */  iRegLNoSp_rule,
  /*  618 */  iRegLNoSp_rule,
  /*  619 */  iRegLNoSp_rule,
  /*  620 */  iRegINoSp_rule,
  /*  621 */  iRegINoSp_rule,
  /*  622 */  iRegLNoSp_rule,
  /*  623 */  iRegLNoSp_rule,
  /*  624 */  iRegINoSp_rule,
  /*  625 */  iRegINoSp_rule,
  /*  626 */  iRegLNoSp_rule,
  /*  627 */  iRegLNoSp_rule,
  /*  628 */  iRegINoSp_rule,
  /*  629 */  iRegINoSp_rule,
  /*  630 */  iRegLNoSp_rule,
  /*  631 */  iRegLNoSp_rule,
  /*  632 */  iRegINoSp_rule,
  /*  633 */  iRegINoSp_rule,
  /*  634 */  iRegLNoSp_rule,
  /*  635 */  iRegLNoSp_rule,
  /*  636 */  iRegINoSp_rule,
  /*  637 */  iRegINoSp_rule,
  /*  638 */  iRegLNoSp_rule,
  /*  639 */  iRegLNoSp_rule,
  /*  640 */  iRegINoSp_rule,
  /*  641 */  iRegINoSp_rule,
  /*  642 */  iRegLNoSp_rule,
  /*  643 */  iRegLNoSp_rule,
  /*  644 */  iRegINoSp_rule,
  /*  645 */  iRegINoSp_rule,
  /*  646 */  iRegLNoSp_rule,
  /*  647 */  iRegLNoSp_rule,
  /*  648 */  iRegINoSp_rule,
  /*  649 */  iRegINoSp_rule,
  /*  650 */  iRegLNoSp_rule,
  /*  651 */  iRegLNoSp_rule,
  /*  652 */  iRegINoSp_rule,
  /*  653 */  iRegINoSp_rule,
  /*  654 */  iRegLNoSp_rule,
  /*  655 */  iRegLNoSp_rule,
  /*  656 */  iRegINoSp_rule,
  /*  657 */  iRegINoSp_rule,
  /*  658 */  iRegLNoSp_rule,
  /*  659 */  iRegLNoSp_rule,
  /*  660 */  iRegINoSp_rule,
  /*  661 */  iRegINoSp_rule,
  /*  662 */  iRegLNoSp_rule,
  /*  663 */  iRegLNoSp_rule,
  /*  664 */  iRegINoSp_rule,
  /*  665 */  iRegINoSp_rule,
  /*  666 */  iRegLNoSp_rule,
  /*  667 */  iRegLNoSp_rule,
  /*  668 */  iRegINoSp_rule,
  /*  669 */  iRegINoSp_rule,
  /*  670 */  iRegLNoSp_rule,
  /*  671 */  iRegLNoSp_rule,
  /*  672 */  iRegINoSp_rule,
  /*  673 */  iRegINoSp_rule,
  /*  674 */  iRegLNoSp_rule,
  /*  675 */  iRegLNoSp_rule,
  /*  676 */  iRegINoSp_rule,
  /*  677 */  iRegINoSp_rule,
  /*  678 */  iRegLNoSp_rule,
  /*  679 */  iRegLNoSp_rule,
  /*  680 */  iRegINoSp_rule,
  /*  681 */  iRegLNoSp_rule,
  /*  682 */  iRegINoSp_rule,
  /*  683 */  iRegLNoSp_rule,
  /*  684 */  iRegINoSp_rule,
  /*  685 */  iRegLNoSp_rule,
  /*  686 */  iRegLNoSp_rule,
  /*  687 */  iRegINoSp_rule,
  /*  688 */  iRegLNoSp_rule,
  /*  689 */  iRegINoSp_rule,
  /*  690 */  iRegINoSp_rule,
  /*  691 */  iRegLNoSp_rule,
  /*  692 */  iRegLNoSp_rule,
  /*  693 */  iRegLNoSp_rule,
  /*  694 */  iRegLNoSp_rule,
  /*  695 */  iRegINoSp_rule,
  /*  696 */  iRegINoSp_rule,
  /*  697 */  iRegLNoSp_rule,
  /*  698 */  iRegLNoSp_rule,
  /*  699 */  iRegINoSp_rule,
  /*  700 */  iRegINoSp_rule,
  /*  701 */  0,
  /*  702 */  0,
  /*  703 */  iRegLNoSp_rule,
  /*  704 */  iRegLNoSp_rule,
  /*  705 */  iRegLNoSp_rule,
  /*  706 */  iRegLNoSp_rule,
  /*  707 */  iRegINoSp_rule,
  /*  708 */  iRegINoSp_rule,
  /*  709 */  iRegINoSp_rule,
  /*  710 */  iRegINoSp_rule,
  /*  711 */  0,
  /*  712 */  0,
  /*  713 */  iRegLNoSp_rule,
  /*  714 */  iRegLNoSp_rule,
  /*  715 */  iRegLNoSp_rule,
  /*  716 */  iRegLNoSp_rule,
  /*  717 */  iRegINoSp_rule,
  /*  718 */  iRegINoSp_rule,
  /*  719 */  iRegINoSp_rule,
  /*  720 */  iRegINoSp_rule,
  /*  721 */  iRegLNoSp_rule,
  /*  722 */  iRegLNoSp_rule,
  /*  723 */  iRegLNoSp_rule,
  /*  724 */  iRegINoSp_rule,
  /*  725 */  iRegINoSp_rule,
  /*  726 */  iRegINoSp_rule,
  /*  727 */  iRegINoSp_rule,
  /*  728 */  iRegINoSp_rule,
  /*  729 */  iRegINoSp_rule,
  /*  730 */  iRegLNoSp_rule,
  /*  731 */  iRegLNoSp_rule,
  /*  732 */  iRegLNoSp_rule,
  /*  733 */  iRegLNoSp_rule,
  /*  734 */  iRegLNoSp_rule,
  /*  735 */  iRegLNoSp_rule,
  /*  736 */  iRegLNoSp_rule,
  /*  737 */  iRegLNoSp_rule,
  /*  738 */  iRegINoSp_rule,
  /*  739 */  iRegINoSp_rule,
  /*  740 */  iRegINoSp_rule,
  /*  741 */  iRegINoSp_rule,
  /*  742 */  iRegLNoSp_rule,
  /*  743 */  iRegLNoSp_rule,
  /*  744 */  iRegLNoSp_rule,
  /*  745 */  iRegLNoSp_rule,
  /*  746 */  iRegLNoSp_rule,
  /*  747 */  iRegLNoSp_rule,
  /*  748 */  iRegINoSp_rule,
  /*  749 */  iRegINoSp_rule,
  /*  750 */  iRegLNoSp_rule,
  /*  751 */  iRegLNoSp_rule,
  /*  752 */  iRegLNoSp_rule,
  /*  753 */  vRegF_rule,
  /*  754 */  vRegD_rule,
  /*  755 */  vRegF_rule,
  /*  756 */  vRegD_rule,
  /*  757 */  vRegF_rule,
  /*  758 */  vRegD_rule,
  /*  759 */  vRegF_rule,
  /*  760 */  vRegD_rule,
  /*  761 */  vRegD_rule,
  /*  762 */  vRegF_rule,
  /*  763 */  iRegINoSp_rule,
  /*  764 */  iRegINoSp_rule,
  /*  765 */  iRegINoSp_rule,
  /*  766 */  iRegINoSp_rule,
  /*  767 */  iRegINoSp_rule,
  /*  768 */  iRegINoSp_rule,
  /*  769 */  iRegLNoSp_rule,
  /*  770 */  iRegLNoSp_rule,
  /*  771 */  iRegLNoSp_rule,
  /*  772 */  iRegLNoSp_rule,
  /*  773 */  iRegLNoSp_rule,
  /*  774 */  iRegLNoSp_rule,
  /*  775 */  iRegLNoSp_rule,
  /*  776 */  iRegLNoSp_rule,
  /*  777 */  iRegINoSp_rule,
  /*  778 */  iRegINoSp_rule,
  /*  779 */  iRegINoSp_rule,
  /*  780 */  vRegF_rule,
  /*  781 */  vRegD_rule,
  /*  782 */  iRegINoSp_rule,
  /*  783 */  iRegLNoSp_rule,
  /*  784 */  vRegF_rule,
  /*  785 */  vRegF_rule,
  /*  786 */  iRegINoSp_rule,
  /*  787 */  iRegLNoSp_rule,
  /*  788 */  vRegD_rule,
  /*  789 */  vRegD_rule,
  /*  790 */  stackSlotI_rule,
  /*  791 */  stackSlotF_rule,
  /*  792 */  stackSlotL_rule,
  /*  793 */  stackSlotD_rule,
  /*  794 */  Universe_rule,
  /*  795 */  Universe_rule,
  /*  796 */  Universe_rule,
  /*  797 */  Universe_rule,
  /*  798 */  iRegINoSp_rule,
  /*  799 */  iRegINoSp_rule,
  /*  800 */  iRegINoSp_rule,
  /*  801 */  iRegINoSp_rule,
  /*  802 */  iRegINoSp_rule,
  /*  803 */  iRegINoSp_rule,
  /*  804 */  iRegINoSp_rule,
  /*  805 */  iRegINoSp_rule,
  /*  806 */  iRegINoSp_rule,
  /*  807 */  Universe_rule,
  /*  808 */  Universe_rule,
  /*  809 */  Universe_rule,
  /*  810 */  Universe_rule,
  /*  811 */  Universe_rule,
  /*  812 */  Universe_rule,
  /*  813 */  Universe_rule,
  /*  814 */  Universe_rule,
  /*  815 */  Universe_rule,
  /*  816 */  Universe_rule,
  /*  817 */  Universe_rule,
  /*  818 */  Universe_rule,
  /*  819 */  Universe_rule,
  /*  820 */  Universe_rule,
  /*  821 */  Universe_rule,
  /*  822 */  Universe_rule,
  /*  823 */  Universe_rule,
  /*  824 */  Universe_rule,
  /*  825 */  Universe_rule,
  /*  826 */  Universe_rule,
  /*  827 */  Universe_rule,
  /*  828 */  Universe_rule,
  /*  829 */  Universe_rule,
  /*  830 */  Universe_rule,
  /*  831 */  Universe_rule,
  /*  832 */  Universe_rule,
  /*  833 */  Universe_rule,
  /*  834 */  Universe_rule,
  /*  835 */  Universe_rule,
  /*  836 */  iRegP_R0_rule,
  /*  837 */  Universe_rule,
  /*  838 */  Universe_rule,
  /*  839 */  Universe_rule,
  /*  840 */  iRegP_R5_rule,
  /*  841 */  iRegI_R0_rule,
  /*  842 */  iRegI_R0_rule,
  /*  843 */  iRegI_R0_rule,
  /*  844 */  iRegI_R0_rule,
  /*  845 */  iRegI_R0_rule,
  /*  846 */  iRegI_R0_rule,
  /*  847 */  vecD_rule,
  /*  848 */  vecD_rule,
  /*  849 */  vecX_rule,
  /*  850 */  Universe_rule,
  /*  851 */  Universe_rule,
  /*  852 */  Universe_rule,
  /*  853 */  vecD_rule,
  /*  854 */  vecX_rule,
  /*  855 */  vecD_rule,
  /*  856 */  vecX_rule,
  /*  857 */  vecD_rule,
  /*  858 */  vecX_rule,
  /*  859 */  vecD_rule,
  /*  860 */  vecX_rule,
  /*  861 */  vecD_rule,
  /*  862 */  vecX_rule,
  /*  863 */  vecD_rule,
  /*  864 */  vecX_rule,
  /*  865 */  vecX_rule,
  /*  866 */  vecX_rule,
  /*  867 */  vecD_rule,
  /*  868 */  vecX_rule,
  /*  869 */  vecX_rule,
  /*  870 */  vecD_rule,
  /*  871 */  vecX_rule,
  /*  872 */  vecD_rule,
  /*  873 */  vecX_rule,
  /*  874 */  vecD_rule,
  /*  875 */  vecX_rule,
  /*  876 */  vecX_rule,
  /*  877 */  vecD_rule,
  /*  878 */  vecX_rule,
  /*  879 */  vecX_rule,
  /*  880 */  vecD_rule,
  /*  881 */  vecX_rule,
  /*  882 */  vecD_rule,
  /*  883 */  vecX_rule,
  /*  884 */  vecD_rule,
  /*  885 */  vecX_rule,
  /*  886 */  vecX_rule,
  /*  887 */  vecD_rule,
  /*  888 */  vecX_rule,
  /*  889 */  vecX_rule,
  /*  890 */  vecD_rule,
  /*  891 */  vecX_rule,
  /*  892 */  vecD_rule,
  /*  893 */  vecX_rule,
  /*  894 */  vecD_rule,
  /*  895 */  vecX_rule,
  /*  896 */  vecX_rule,
  /*  897 */  vecD_rule,
  /*  898 */  vecX_rule,
  /*  899 */  vecD_rule,
  /*  900 */  vecX_rule,
  /*  901 */  vecD_rule,
  /*  902 */  vecX_rule,
  /*  903 */  vecD_rule,
  /*  904 */  vecX_rule,
  /*  905 */  vecD_rule,
  /*  906 */  vecX_rule,
  /*  907 */  vecX_rule,
  /*  908 */  vecD_rule,
  /*  909 */  vecX_rule,
  /*  910 */  vecD_rule,
  /*  911 */  vecX_rule,
  /*  912 */  vecD_rule,
  /*  913 */  vecX_rule,
  /*  914 */  vecD_rule,
  /*  915 */  vecX_rule,
  /*  916 */  vecD_rule,
  /*  917 */  vecX_rule,
  /*  918 */  vecD_rule,
  /*  919 */  vecX_rule,
  /*  920 */  vecD_rule,
  /*  921 */  vecX_rule,
  /*  922 */  vecD_rule,
  /*  923 */  vecX_rule,
  /*  924 */  vecD_rule,
  /*  925 */  vecX_rule,
  /*  926 */  vecD_rule,
  /*  927 */  vecX_rule,
  /*  928 */  vecD_rule,
  /*  929 */  vecX_rule,
  /*  930 */  vecD_rule,
  /*  931 */  vecX_rule,
  /*  932 */  vecD_rule,
  /*  933 */  vecX_rule,
  /*  934 */  vecD_rule,
  /*  935 */  vecX_rule,
  /*  936 */  vecD_rule,
  /*  937 */  vecX_rule,
  /*  938 */  vecD_rule,
  /*  939 */  vecX_rule,
  /*  940 */  vecD_rule,
  /*  941 */  vecX_rule,
  /*  942 */  vecD_rule,
  /*  943 */  vecX_rule,
  /*  944 */  vecD_rule,
  /*  945 */  vecX_rule,
  /*  946 */  vecD_rule,
  /*  947 */  vecX_rule,
  /*  948 */  vecD_rule,
  /*  949 */  vecX_rule,
  /*  950 */  vecX_rule,
  /*  951 */  vecX_rule,
  /*  952 */  vecX_rule,
  /*  953 */  vecX_rule,
  /*  954 */  vecX_rule,
  /*  955 */  vecX_rule,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  _AddP_iRegP__LShiftL_iRegL_immIScale_rule,
  /*  106 */  _AddP_iRegP__LShiftL_iRegL_immIScale_rule,
  /*  107 */  _AddP_iRegP__ConvI2L_iRegI__rule,
  /*  108 */  _AddP_iRegP__LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  109 */  iRegP_rule,
  /*  110 */  iRegP_rule,
  /*  111 */  iRegP_rule,
  /*  112 */  iRegP_rule,
  /*  113 */  iRegP_rule,
  /*  114 */  iRegP_rule,
  /*  115 */  iRegP_rule,
  /*  116 */  iRegP_rule,
  /*  117 */  iRegP_rule,
  /*  118 */  iRegP_rule,
  /*  119 */  iRegP_rule,
  /*  120 */  iRegN_rule,
  /*  121 */  _AddP__DecodeN_iRegN___LShiftL_iRegL_immIScale_rule,
  /*  122 */  _AddP__DecodeN_iRegN___LShiftL_iRegL_immIScale_rule,
  /*  123 */  _AddP__DecodeN_iRegN___ConvI2L_iRegI__rule,
  /*  124 */  _AddP__DecodeN_iRegN___LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  125 */  _DecodeN_iRegN__rule,
  /*  126 */  _DecodeN_iRegN__rule,
  /*  127 */  _DecodeN_iRegN__rule,
  /*  128 */  _DecodeN_iRegN__rule,
  /*  129 */  _DecodeN_iRegN__rule,
  /*  130 */  thread_RegP_rule,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  iRegL_rule,
  // last operand
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  // last operand class
  /*  144 */  iRegL_rule,
  /*  145 */  iRegP_rule,
  /*  146 */  iRegI_rule,
  /*  147 */  iRegP_rule,
  /*  148 */  _ConvI2L_iRegI__rule,
  /*  149 */  iRegP_rule,
  /*  150 */  iRegN_rule,
  /*  151 */  _DecodeN_iRegN__rule,
  /*  152 */  _DecodeN_iRegN__rule,
  /*  153 */  _DecodeN_iRegN__rule,
  /*  154 */  memory_rule,
  /*  155 */  memory_rule,
  /*  156 */  memory_rule,
  /*  157 */  memory_rule,
  /*  158 */  memory_rule,
  /*  159 */  _LoadI_memory__rule,
  /*  160 */  indirect_rule,
  /*  161 */  indirect_rule,
  /*  162 */  indirect_rule,
  /*  163 */  indirect_rule,
  /*  164 */  indirect_rule,
  /*  165 */  _LoadI_indirect__rule,
  /*  166 */  memory_rule,
  /*  167 */  iRegP_rule,
  /*  168 */  _DecodeN_iRegN__rule,
  /*  169 */  iRegP_rule,
  /*  170 */  iRegLNoSp_rule,
  /*  171 */  iRegINoSp_rule,
  /*  172 */  iRegNNoSp_rule,
  /*  173 */  iRegN_rule,
  /*  174 */  cmpOp_rule,
  /*  175 */  iRegIorL2I_rule,
  /*  176 */  cmpOpU_rule,
  /*  177 */  immI0_rule,
  /*  178 */  iRegIorL2I_rule,
  /*  179 */  immI_1_rule,
  /*  180 */  iRegL_rule,
  /*  181 */  iRegL_rule,
  /*  182 */  immL0_rule,
  /*  183 */  iRegP_rule,
  /*  184 */  immP0_rule,
  /*  185 */  iRegN_rule,
  /*  186 */  immN0_rule,
  /*  187 */  vRegF_rule,
  /*  188 */  vRegD_rule,
  /*  189 */  iRegL_rule,
  /*  190 */  iRegIorL2I_rule,
  /*  191 */  _ConvI2L_iRegIorL2I__rule,
  /*  192 */  iRegIorL2I_rule,
  /*  193 */  iRegL_rule,
  /*  194 */  iRegIorL2I_rule,
  /*  195 */  _RShiftI_iRegIorL2I_immI_31_rule,
  /*  196 */  iRegL_rule,
  /*  197 */  _RShiftL_iRegL_immL_63_rule,
  /*  198 */  iRegIorL2I_rule,
  /*  199 */  iRegL_rule,
  /*  200 */  iRegIorL2I_rule,
  /*  201 */  iRegL_rule,
  /*  202 */  iRegIorL2I_rule,
  /*  203 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  204 */  iRegL_rule,
  /*  205 */  _URShiftL_iRegL_immI_rule,
  /*  206 */  iRegIorL2I_rule,
  /*  207 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  208 */  iRegL_rule,
  /*  209 */  _RShiftL_iRegL_immI_rule,
  /*  210 */  iRegIorL2I_rule,
  /*  211 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  212 */  iRegL_rule,
  /*  213 */  _LShiftL_iRegL_immI_rule,
  /*  214 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  215 */  iRegIorL2I_rule,
  /*  216 */  _URShiftL_iRegL_immI_rule,
  /*  217 */  iRegL_rule,
  /*  218 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  219 */  iRegIorL2I_rule,
  /*  220 */  _RShiftL_iRegL_immI_rule,
  /*  221 */  iRegL_rule,
  /*  222 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  223 */  iRegIorL2I_rule,
  /*  224 */  _LShiftL_iRegL_immI_rule,
  /*  225 */  iRegL_rule,
  /*  226 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  227 */  iRegL_rule,
  /*  228 */  immI_64_rule,
  /*  229 */  iRegL_rule,
  /*  230 */  immI0_rule,
  /*  231 */  iRegL_rule,
  /*  232 */  iRegI_rule,
  /*  233 */  immI_32_rule,
  /*  234 */  iRegI_rule,
  /*  235 */  iRegI_rule,
  /*  236 */  iRegL_rule,
  /*  237 */  iRegL_rule,
  /*  238 */  iRegL_rule,
  /*  239 */  iRegI_rule,
  /*  240 */  iRegI_rule,
  /*  241 */  iRegI_rule,
  /*  242 */  iRegIorL2I_rule,
  /*  243 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  244 */  iRegIorL2I_rule,
  /*  245 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  246 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  247 */  iRegL_rule,
  /*  248 */  _LShiftL_iRegL_immI_48_rule,
  /*  249 */  iRegL_rule,
  /*  250 */  _LShiftL_iRegL_immI_32_rule,
  /*  251 */  iRegL_rule,
  /*  252 */  _LShiftL_iRegL_immI_56_rule,
  /*  253 */  _LShiftL_iRegL_immI_56_rule,
  /*  254 */  iRegIorL2I_rule,
  /*  255 */  iRegIorL2I_rule,
  /*  256 */  iRegL_rule,
  /*  257 */  iRegL_rule,
  /*  258 */  iRegL_rule,
  /*  259 */  vRegF_rule,
  /*  260 */  _ConvF2D_vRegF__rule,
  /*  261 */  iRegIorL2I_rule,
  /*  262 */  iRegL_rule,
  /*  263 */  iRegIorL2I_rule,
  /*  264 */  iRegL_rule,
  /*  265 */  iRegP_rule,
  /*  266 */  iRegN_rule,
  /*  267 */  _DecodeN_iRegN__rule,
  /*  268 */  iRegIorL2I_rule,
  /*  269 */  iRegL_rule,
  /*  270 */  iRegL_rule,
  /*  271 */  _AndL_iRegL_immL_rule,
  /*  272 */  iRegIorL2I_rule,
  /*  273 */  _AndI_iRegIorL2I_immI_rule,
  /*  274 */  iRegL_rule,
  /*  275 */  iRegIorL2I_rule,
  /*  276 */  iRegP_R4_rule,
  /*  277 */  iRegP_R1_rule,
  /*  278 */  iRegP_R3_rule,
  /*  279 */  iRegP_R1_rule,
  /*  280 */  iRegP_R3_rule,
  /*  281 */  iRegP_R3_rule,
  /*  282 */  iRegP_R1_rule,
  /*  283 */  iRegP_R1_rule,
  /*  284 */  vecD_rule,
  /*  285 */  vecX_rule,
  /*  286 */  vecD_rule,
  /*  287 */  vecX_rule,
  // last internally defined operand
  /*  288 */  immI_rule,
  /*  289 */  immL_rule,
  /*  290 */  immP_rule,
  /*  291 */  immP0_rule,
  /*  292 */  immP_1_rule,
  /*  293 */  immPollPage_rule,
  /*  294 */  immByteMapBase_rule,
  /*  295 */  immN_rule,
  /*  296 */  immN0_rule,
  /*  297 */  immNKlass_rule,
  /*  298 */  immFPacked_rule,
  /*  299 */  immF_rule,
  /*  300 */  immDPacked_rule,
  /*  301 */  immD_rule,
  /*  302 */  iRegIorL2I_rule,
  /*  303 */  iRegL_rule,
  /*  304 */  iRegIorL2I_rule,
  /*  305 */  iRegL_rule,
  /*  306 */  iRegL_rule,
  /*  307 */  iRegP_rule,
  /*  308 */  iRegPNoSp_rule,
  /*  309 */  iRegPNoSp_rule,
  /*  310 */  iRegI_rule,
  /*  311 */  memory_rule,
  /*  312 */  indirect_rule,
  /*  313 */  indirect_rule,
  /*  314 */  vRegF_rule,
  /*  315 */  vRegD_rule,
  /*  316 */  vRegF_rule,
  /*  317 */  vRegD_rule,
  /*  318 */  stackSlotF_rule,
  /*  319 */  stackSlotI_rule,
  /*  320 */  stackSlotD_rule,
  /*  321 */  stackSlotL_rule,
  /*  322 */  vRegF_rule,
  /*  323 */  iRegI_rule,
  /*  324 */  vRegD_rule,
  /*  325 */  iRegL_rule,
  /*  326 */  iRegIorL2I_rule,
  /*  327 */  iRegIorL2I_rule,
  /*  328 */  iRegL_rule,
  /*  329 */  iRegL_rule,
  /*  330 */  iRegIorL2I_rule,
  /*  331 */  iRegIorL2I_rule,
  /*  332 */  iRegL_rule,
  /*  333 */  iRegL_rule,
  /*  334 */  immI0_rule,
  /*  335 */  immI0_rule,
  /*  336 */  iRegIorL2I_rule,
  /*  337 */  iRegL_rule,
  /*  338 */  iRegI_rule,
  /*  339 */  iRegI_rule,
  /*  340 */  iRegI_rule,
  /*  341 */  iRegI_rule,
  /*  342 */  iRegI_rule,
  /*  343 */  iRegI_rule,
  /*  344 */  iRegI_rule,
  /*  345 */  iRegI_rule,
  /*  346 */  iRegL_rule,
  /*  347 */  iRegL_rule,
  /*  348 */  iRegL_rule,
  /*  349 */  iRegL_rule,
  /*  350 */  iRegL_rule,
  /*  351 */  iRegL_rule,
  /*  352 */  iRegL_rule,
  /*  353 */  iRegL_rule,
  /*  354 */  iRegP_rule,
  /*  355 */  iRegN_rule,
  /*  356 */  iRegP_rule,
  /*  357 */  iRegN_rule,
  /*  358 */  vRegF_rule,
  /*  359 */  vRegF_rule,
  /*  360 */  vRegD_rule,
  /*  361 */  vRegD_rule,
  /*  362 */  _AndL_iRegL_immL_rule,
  /*  363 */  _AndI_iRegIorL2I_immI_rule,
  /*  364 */  _AndL_iRegL_iRegL_rule,
  /*  365 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  366 */  iRegP_rule,
  /*  367 */  iRegP_rule,
  /*  368 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  369 */  0,
  /*  370 */  iRegIorL2I_rule,
  /*  371 */  iRegIorL2I_rule,
  /*  372 */  iRegIorL2I_rule,
  /*  373 */  iRegIorL2I_rule,
  /*  374 */  memory_rule,
  /*  375 */  _LoadB_memory__rule,
  /*  376 */  memory_rule,
  /*  377 */  _LoadUB_memory__rule,
  /*  378 */  memory_rule,
  /*  379 */  _LoadS_memory__rule,
  /*  380 */  memory_rule,
  /*  381 */  _LoadUS_memory__rule,
  /*  382 */  memory_rule,
  /*  383 */  _LoadI_memory__rule,
  /*  384 */  _ConvI2L__LoadI_memory___rule,
  /*  385 */  memory_rule,
  /*  386 */  memory_rule,
  /*  387 */  memory_rule,
  /*  388 */  memory_rule,
  /*  389 */  memory_rule,
  /*  390 */  memory_rule,
  /*  391 */  memory_rule,
  /*  392 */  memory_rule,
  /*  393 */  memory_rule,
  /*  394 */  memory_rule,
  /*  395 */  memory_rule,
  /*  396 */  memory_rule,
  /*  397 */  memory_rule,
  /*  398 */  memory_rule,
  /*  399 */  memory_rule,
  /*  400 */  memory_rule,
  /*  401 */  memory_rule,
  /*  402 */  memory_rule,
  /*  403 */  memory_rule,
  /*  404 */  memory_rule,
  /*  405 */  memory_rule,
  /*  406 */  memory_rule,
  /*  407 */  memory_rule,
  /*  408 */  memory_rule,
  /*  409 */  memory_rule,
  /*  410 */  memory_rule,
  /*  411 */  memory_rule,
  /*  412 */  memory_rule,
  /*  413 */  indirect_rule,
  /*  414 */  _LoadB_indirect__rule,
  /*  415 */  indirect_rule,
  /*  416 */  _LoadUB_indirect__rule,
  /*  417 */  indirect_rule,
  /*  418 */  indirect_rule,
  /*  419 */  _LoadUS_indirect__rule,
  /*  420 */  _LoadS_indirect__rule,
  /*  421 */  indirect_rule,
  /*  422 */  _ConvI2L__LoadI_indirect___rule,
  /*  423 */  indirect_rule,
  /*  424 */  indirect_rule,
  /*  425 */  indirect_rule,
  /*  426 */  indirect_rule,
  /*  427 */  indirect_rule,
  /*  428 */  indirect_rule,
  /*  429 */  indirect_rule,
  /*  430 */  indirect_rule,
  /*  431 */  indirect_rule,
  /*  432 */  indirect_rule,
  /*  433 */  indirect_rule,
  /*  434 */  indirect_rule,
  /*  435 */  indirect_rule,
  /*  436 */  iRegIorL2I_rule,
  /*  437 */  iRegL_rule,
  /*  438 */  iRegIorL2I_rule,
  /*  439 */  iRegIorL2I_rule,
  /*  440 */  iRegIorL2I_rule,
  /*  441 */  _LoadI_memory__rule,
  /*  442 */  iRegL_rule,
  /*  443 */  _LoadL_memory__rule,
  /*  444 */  0,
  /*  445 */  0,
  /*  446 */  0,
  /*  447 */  0,
  /*  448 */  0,
  /*  449 */  0,
  /*  450 */  0,
  /*  451 */  0,
  /*  452 */  0,
  /*  453 */  0,
  /*  454 */  0,
  /*  455 */  _CastP2X_iRegP__rule,
  /*  456 */  _CastP2X__DecodeN_iRegN___rule,
  /*  457 */  iRegP_rule,
  /*  458 */  iRegP_rule,
  /*  459 */  iRegP_rule,
  /*  460 */  iRegN_rule,
  /*  461 */  iRegN_rule,
  /*  462 */  iRegP_rule,
  /*  463 */  iRegN_rule,
  /*  464 */  indirect_rule,
  /*  465 */  indirect_rule,
  /*  466 */  indirect_rule,
  /*  467 */  indirect_rule,
  /*  468 */  indirect_rule,
  /*  469 */  indirect_rule,
  /*  470 */  indirect_rule,
  /*  471 */  indirect_rule,
  /*  472 */  indirect_rule,
  /*  473 */  indirect_rule,
  /*  474 */  indirect_rule,
  /*  475 */  indirect_rule,
  /*  476 */  indirect_rule,
  /*  477 */  indirect_rule,
  /*  478 */  indirect_rule,
  /*  479 */  indirect_rule,
  /*  480 */  indirect_rule,
  /*  481 */  indirect_rule,
  /*  482 */  indirect_rule,
  /*  483 */  indirect_rule,
  /*  484 */  indirect_rule,
  /*  485 */  indirect_rule,
  /*  486 */  indirect_rule,
  /*  487 */  indirect_rule,
  /*  488 */  indirect_rule,
  /*  489 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  490 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  491 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  492 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  493 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  494 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  495 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  496 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  497 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  498 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  499 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  500 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  501 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  502 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  503 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  504 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  505 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  506 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  507 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  508 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  509 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  510 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  511 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  512 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  513 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  514 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  515 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  516 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  517 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  518 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  519 */  iRegIorL2I_rule,
  /*  520 */  iRegIorL2I_rule,
  /*  521 */  _ConvL2I_iRegL__rule,
  /*  522 */  iRegP_rule,
  /*  523 */  iRegP_rule,
  /*  524 */  iRegP_rule,
  /*  525 */  iRegP_rule,
  /*  526 */  _ConvI2L_iRegIorL2I__rule,
  /*  527 */  iRegP_rule,
  /*  528 */  iRegL_rule,
  /*  529 */  iRegL_rule,
  /*  530 */  iRegIorL2I_rule,
  /*  531 */  iRegIorL2I_rule,
  /*  532 */  iRegL_rule,
  /*  533 */  iRegL_rule,
  /*  534 */  immI0_rule,
  /*  535 */  immL0_rule,
  /*  536 */  iRegIorL2I_rule,
  /*  537 */  _ConvI2L_iRegIorL2I__rule,
  /*  538 */  _ConvI2L_iRegIorL2I__rule,
  /*  539 */  iRegL_rule,
  /*  540 */  iRegL_rule,
  /*  541 */  iRegIorL2I_rule,
  /*  542 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  543 */  iRegIorL2I_rule,
  /*  544 */  iRegL_rule,
  /*  545 */  _MulL_iRegL_iRegL_rule,
  /*  546 */  iRegL_rule,
  /*  547 */  iRegIorL2I_rule,
  /*  548 */  _RShiftI_iRegIorL2I_immI_31_rule,
  /*  549 */  iRegIorL2I_rule,
  /*  550 */  _URShiftI__RShiftI_iRegIorL2I_immI_31_immI_31_rule,
  /*  551 */  iRegL_rule,
  /*  552 */  _RShiftL_iRegL_immL_63_rule,
  /*  553 */  iRegL_rule,
  /*  554 */  _URShiftL__RShiftL_iRegL_immL_63_immL_63_rule,
  /*  555 */  iRegIorL2I_rule,
  /*  556 */  iRegL_rule,
  /*  557 */  iRegIorL2I_rule,
  /*  558 */  iRegIorL2I_rule,
  /*  559 */  iRegIorL2I_rule,
  /*  560 */  iRegIorL2I_rule,
  /*  561 */  iRegIorL2I_rule,
  /*  562 */  iRegIorL2I_rule,
  /*  563 */  iRegL_rule,
  /*  564 */  iRegL_rule,
  /*  565 */  iRegL_rule,
  /*  566 */  iRegL_rule,
  /*  567 */  _CastP2X_iRegP__rule,
  /*  568 */  iRegL_rule,
  /*  569 */  iRegL_rule,
  /*  570 */  iRegL_rule,
  /*  571 */  iRegIorL2I_rule,
  /*  572 */  iRegIorL2I_rule,
  /*  573 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  574 */  iRegL_rule,
  /*  575 */  _XorL_iRegL_immL_M1_rule,
  /*  576 */  iRegIorL2I_rule,
  /*  577 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  578 */  iRegL_rule,
  /*  579 */  _XorL_iRegL_immL_M1_rule,
  /*  580 */  immI_M1_rule,
  /*  581 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  582 */  immL_M1_rule,
  /*  583 */  _XorL_iRegL_iRegL_rule,
  /*  584 */  iRegIorL2I_rule,
  /*  585 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  586 */  iRegL_rule,
  /*  587 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  588 */  iRegIorL2I_rule,
  /*  589 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  590 */  iRegL_rule,
  /*  591 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  592 */  iRegIorL2I_rule,
  /*  593 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  594 */  iRegL_rule,
  /*  595 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  596 */  immI_M1_rule,
  /*  597 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  598 */  immI_M1_rule,
  /*  599 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  600 */  immL_M1_rule,
  /*  601 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  602 */  immL_M1_rule,
  /*  603 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  604 */  immI_M1_rule,
  /*  605 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  606 */  immI_M1_rule,
  /*  607 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  608 */  immL_M1_rule,
  /*  609 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  610 */  immL_M1_rule,
  /*  611 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  612 */  immI_M1_rule,
  /*  613 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  614 */  immI_M1_rule,
  /*  615 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  616 */  immL_M1_rule,
  /*  617 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  618 */  immL_M1_rule,
  /*  619 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  620 */  iRegIorL2I_rule,
  /*  621 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  622 */  iRegL_rule,
  /*  623 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  624 */  iRegIorL2I_rule,
  /*  625 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  626 */  iRegL_rule,
  /*  627 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  628 */  iRegIorL2I_rule,
  /*  629 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  630 */  iRegL_rule,
  /*  631 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  632 */  iRegIorL2I_rule,
  /*  633 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  634 */  iRegL_rule,
  /*  635 */  _URShiftL_iRegL_immI_rule,
  /*  636 */  iRegIorL2I_rule,
  /*  637 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  638 */  iRegL_rule,
  /*  639 */  _RShiftL_iRegL_immI_rule,
  /*  640 */  iRegIorL2I_rule,
  /*  641 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  642 */  iRegL_rule,
  /*  643 */  _LShiftL_iRegL_immI_rule,
  /*  644 */  iRegIorL2I_rule,
  /*  645 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  646 */  iRegL_rule,
  /*  647 */  _URShiftL_iRegL_immI_rule,
  /*  648 */  iRegIorL2I_rule,
  /*  649 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  650 */  iRegL_rule,
  /*  651 */  _RShiftL_iRegL_immI_rule,
  /*  652 */  iRegIorL2I_rule,
  /*  653 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  654 */  iRegL_rule,
  /*  655 */  _LShiftL_iRegL_immI_rule,
  /*  656 */  iRegIorL2I_rule,
  /*  657 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  658 */  iRegL_rule,
  /*  659 */  _URShiftL_iRegL_immI_rule,
  /*  660 */  iRegIorL2I_rule,
  /*  661 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  662 */  iRegL_rule,
  /*  663 */  _RShiftL_iRegL_immI_rule,
  /*  664 */  iRegIorL2I_rule,
  /*  665 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  666 */  iRegL_rule,
  /*  667 */  _LShiftL_iRegL_immI_rule,
  /*  668 */  iRegIorL2I_rule,
  /*  669 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  670 */  iRegL_rule,
  /*  671 */  _URShiftL_iRegL_immI_rule,
  /*  672 */  iRegIorL2I_rule,
  /*  673 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  674 */  iRegL_rule,
  /*  675 */  _RShiftL_iRegL_immI_rule,
  /*  676 */  iRegIorL2I_rule,
  /*  677 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  678 */  iRegL_rule,
  /*  679 */  _LShiftL_iRegL_immI_rule,
  /*  680 */  iRegIorL2I_rule,
  /*  681 */  iRegL_rule,
  /*  682 */  iRegIorL2I_rule,
  /*  683 */  iRegL_rule,
  /*  684 */  iRegIorL2I_rule,
  /*  685 */  iRegL_rule,
  /*  686 */  _LShiftL_iRegL_immI_rule,
  /*  687 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  688 */  _LShiftL_iRegL_immI_rule,
  /*  689 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  690 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  691 */  _URShiftL_iRegL_immI_rule,
  /*  692 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  693 */  _LShiftL_iRegL_immI_rule,
  /*  694 */  _URShiftL_iRegL_immI_rule,
  /*  695 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  696 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  697 */  _LShiftL_iRegL_immI_rule,
  /*  698 */  _URShiftL_iRegL_immI_rule,
  /*  699 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  700 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  701 */  0,
  /*  702 */  0,
  /*  703 */  _LShiftL_iRegL_iRegI_rule,
  /*  704 */  _URShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  705 */  _LShiftL_iRegL_iRegI_rule,
  /*  706 */  _URShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  707 */  _LShiftI_iRegI_iRegI_rule,
  /*  708 */  _URShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  709 */  _LShiftI_iRegI_iRegI_rule,
  /*  710 */  _URShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  711 */  0,
  /*  712 */  0,
  /*  713 */  _URShiftL_iRegL_iRegI_rule,
  /*  714 */  _LShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  715 */  _URShiftL_iRegL_iRegI_rule,
  /*  716 */  _LShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  717 */  _URShiftI_iRegI_iRegI_rule,
  /*  718 */  _LShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  719 */  _URShiftI_iRegI_iRegI_rule,
  /*  720 */  _LShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  721 */  iRegL_rule,
  /*  722 */  _ConvI2L_iRegIorL2I__rule,
  /*  723 */  iRegL_rule,
  /*  724 */  iRegIorL2I_rule,
  /*  725 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  726 */  iRegIorL2I_rule,
  /*  727 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  728 */  iRegIorL2I_rule,
  /*  729 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  730 */  iRegL_rule,
  /*  731 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  732 */  iRegL_rule,
  /*  733 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  734 */  iRegL_rule,
  /*  735 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  736 */  iRegL_rule,
  /*  737 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  738 */  iRegIorL2I_rule,
  /*  739 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  740 */  iRegIorL2I_rule,
  /*  741 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  742 */  iRegL_rule,
  /*  743 */  _AndL_iRegL_immL_255_rule,
  /*  744 */  iRegL_rule,
  /*  745 */  _AndL_iRegL_immL_65535_rule,
  /*  746 */  iRegL_rule,
  /*  747 */  _AndL_iRegL_immL_4294967295_rule,
  /*  748 */  iRegIorL2I_rule,
  /*  749 */  iRegIorL2I_rule,
  /*  750 */  iRegL_rule,
  /*  751 */  iRegL_rule,
  /*  752 */  iRegL_rule,
  /*  753 */  vRegF_rule,
  /*  754 */  vRegD_rule,
  /*  755 */  vRegF_rule,
  /*  756 */  vRegD_rule,
  /*  757 */  vRegF_rule,
  /*  758 */  vRegD_rule,
  /*  759 */  vRegF_rule,
  /*  760 */  vRegD_rule,
  /*  761 */  vRegD_rule,
  /*  762 */  _SqrtD__ConvF2D_vRegF___rule,
  /*  763 */  iRegIorL2I_rule,
  /*  764 */  iRegIorL2I_rule,
  /*  765 */  iRegIorL2I_rule,
  /*  766 */  iRegIorL2I_rule,
  /*  767 */  iRegIorL2I_rule,
  /*  768 */  iRegIorL2I_rule,
  /*  769 */  iRegL_rule,
  /*  770 */  iRegL_rule,
  /*  771 */  iRegL_rule,
  /*  772 */  iRegL_rule,
  /*  773 */  iRegL_rule,
  /*  774 */  iRegL_rule,
  /*  775 */  iRegIorL2I_rule,
  /*  776 */  _ConvI2L_iRegIorL2I__rule,
  /*  777 */  iRegL_rule,
  /*  778 */  iRegIorL2I_rule,
  /*  779 */  iRegP_rule,
  /*  780 */  vRegD_rule,
  /*  781 */  vRegF_rule,
  /*  782 */  vRegF_rule,
  /*  783 */  vRegF_rule,
  /*  784 */  iRegIorL2I_rule,
  /*  785 */  iRegL_rule,
  /*  786 */  vRegD_rule,
  /*  787 */  vRegD_rule,
  /*  788 */  iRegIorL2I_rule,
  /*  789 */  iRegL_rule,
  /*  790 */  vRegF_rule,
  /*  791 */  iRegI_rule,
  /*  792 */  vRegD_rule,
  /*  793 */  iRegL_rule,
  /*  794 */  iRegL_R11_rule,
  /*  795 */  immL_rule,
  /*  796 */  cmpOp_rule,
  /*  797 */  cmpOp_rule,
  /*  798 */  vRegF_rule,
  /*  799 */  vRegD_rule,
  /*  800 */  vRegF_rule,
  /*  801 */  vRegD_rule,
  /*  802 */  iRegL_rule,
  /*  803 */  iRegIorL2I_rule,
  /*  804 */  iRegIorL2I_rule,
  /*  805 */  iRegI_rule,
  /*  806 */  iRegI_rule,
  /*  807 */  0,
  /*  808 */  cmpOp_rule,
  /*  809 */  cmpOpU_rule,
  /*  810 */  cmpOp_rule,
  /*  811 */  cmpOp_rule,
  /*  812 */  cmpOp_rule,
  /*  813 */  cmpOp_rule,
  /*  814 */  cmpOp_rule,
  /*  815 */  cmpOpU_rule,
  /*  816 */  cmpOpU_rule,
  /*  817 */  cmpOp_rule,
  /*  818 */  cmpOp_rule,
  /*  819 */  cmpOp_rule,
  /*  820 */  cmpOp_rule,
  /*  821 */  cmpOp_rule,
  /*  822 */  cmpOp_rule,
  /*  823 */  cmpOp_rule,
  /*  824 */  cmpOp_rule,
  /*  825 */  cmpOp_rule,
  /*  826 */  cmpOpU_rule,
  /*  827 */  iRegP_rule,
  /*  828 */  0,
  /*  829 */  0,
  /*  830 */  0,
  /*  831 */  0,
  /*  832 */  0,
  /*  833 */  0,
  /*  834 */  iRegPNoSp_rule,
  /*  835 */  iRegPNoSp_rule,
  /*  836 */  0,
  /*  837 */  0,
  /*  838 */  0,
  /*  839 */  0,
  /*  840 */  iRegP_R4_rule,
  /*  841 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /*  842 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /*  843 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /*  844 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /*  845 */  iRegP_R1_rule,
  /*  846 */  iRegP_R2_rule,
  /*  847 */  vmem4_rule,
  /*  848 */  vmem8_rule,
  /*  849 */  vmem16_rule,
  /*  850 */  vmem4_rule,
  /*  851 */  vmem8_rule,
  /*  852 */  vmem16_rule,
  /*  853 */  iRegIorL2I_rule,
  /*  854 */  iRegIorL2I_rule,
  /*  855 */  immI_rule,
  /*  856 */  immI_rule,
  /*  857 */  iRegIorL2I_rule,
  /*  858 */  iRegIorL2I_rule,
  /*  859 */  immI_rule,
  /*  860 */  immI_rule,
  /*  861 */  iRegIorL2I_rule,
  /*  862 */  iRegIorL2I_rule,
  /*  863 */  immI_rule,
  /*  864 */  immI_rule,
  /*  865 */  iRegL_rule,
  /*  866 */  immI0_rule,
  /*  867 */  vRegF_rule,
  /*  868 */  vRegF_rule,
  /*  869 */  vRegD_rule,
  /*  870 */  vecD_rule,
  /*  871 */  vecX_rule,
  /*  872 */  vecD_rule,
  /*  873 */  vecX_rule,
  /*  874 */  vecD_rule,
  /*  875 */  vecX_rule,
  /*  876 */  vecX_rule,
  /*  877 */  vecD_rule,
  /*  878 */  vecX_rule,
  /*  879 */  vecX_rule,
  /*  880 */  vecD_rule,
  /*  881 */  vecX_rule,
  /*  882 */  vecD_rule,
  /*  883 */  vecX_rule,
  /*  884 */  vecD_rule,
  /*  885 */  vecX_rule,
  /*  886 */  vecX_rule,
  /*  887 */  vecD_rule,
  /*  888 */  vecX_rule,
  /*  889 */  vecX_rule,
  /*  890 */  vecD_rule,
  /*  891 */  vecX_rule,
  /*  892 */  vecD_rule,
  /*  893 */  vecX_rule,
  /*  894 */  vecD_rule,
  /*  895 */  vecX_rule,
  /*  896 */  vecX_rule,
  /*  897 */  vecD_rule,
  /*  898 */  vecX_rule,
  /*  899 */  vecD_rule,
  /*  900 */  vecX_rule,
  /*  901 */  vecD_rule,
  /*  902 */  vecX_rule,
  /*  903 */  vecD_rule,
  /*  904 */  vecX_rule,
  /*  905 */  vecD_rule,
  /*  906 */  vecX_rule,
  /*  907 */  vecX_rule,
  /*  908 */  vecD_rule,
  /*  909 */  vecX_rule,
  /*  910 */  vecD_rule,
  /*  911 */  vecX_rule,
  /*  912 */  vecD_rule,
  /*  913 */  vecX_rule,
  /*  914 */  vecD_rule,
  /*  915 */  vecX_rule,
  /*  916 */  vecD_rule,
  /*  917 */  vecX_rule,
  /*  918 */  vecD_rule,
  /*  919 */  vecX_rule,
  /*  920 */  vecD_rule,
  /*  921 */  vecX_rule,
  /*  922 */  vecD_rule,
  /*  923 */  vecX_rule,
  /*  924 */  vecD_rule,
  /*  925 */  vecX_rule,
  /*  926 */  vecD_rule,
  /*  927 */  vecX_rule,
  /*  928 */  vecD_rule,
  /*  929 */  vecX_rule,
  /*  930 */  vecD_rule,
  /*  931 */  vecX_rule,
  /*  932 */  vecD_rule,
  /*  933 */  vecX_rule,
  /*  934 */  vecD_rule,
  /*  935 */  vecX_rule,
  /*  936 */  vecD_rule,
  /*  937 */  vecX_rule,
  /*  938 */  vecD_rule,
  /*  939 */  vecX_rule,
  /*  940 */  vecD_rule,
  /*  941 */  vecX_rule,
  /*  942 */  vecD_rule,
  /*  943 */  vecX_rule,
  /*  944 */  vecD_rule,
  /*  945 */  vecX_rule,
  /*  946 */  vecD_rule,
  /*  947 */  vecX_rule,
  /*  948 */  vecD_rule,
  /*  949 */  vecX_rule,
  /*  950 */  vecX_rule,
  /*  951 */  vecX_rule,
  /*  952 */  vecX_rule,
  /*  953 */  vecX_rule,
  /*  954 */  vecX_rule,
  /*  955 */  vecX_rule,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  immIU12_rule,
  /*  106 */  immLU12_rule,
  /*  107 */  immLU12_rule,
  /*  108 */  immLU12_rule,
  /*  109 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  110 */  _LShiftL_iRegL_immIScale_rule,
  /*  111 */  iRegL_rule,
  /*  112 */  immIOffset_rule,
  /*  113 */  immIOffset4_rule,
  /*  114 */  immIOffset8_rule,
  /*  115 */  immIOffset16_rule,
  /*  116 */  immLoffset_rule,
  /*  117 */  immLoffset4_rule,
  /*  118 */  immLoffset8_rule,
  /*  119 */  immLoffset16_rule,
  /*  120 */  0,
  /*  121 */  immIU12_rule,
  /*  122 */  immLU12_rule,
  /*  123 */  immLU12_rule,
  /*  124 */  immLU12_rule,
  /*  125 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  126 */  _LShiftL_iRegL_immIScale_rule,
  /*  127 */  iRegL_rule,
  /*  128 */  immIOffset_rule,
  /*  129 */  immLoffset_rule,
  /*  130 */  immL_pc_off_rule,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  // last operand
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  // last operand class
  /*  144 */  immIScale_rule,
  /*  145 */  _LShiftL_iRegL_immIScale_rule,
  /*  146 */  0,
  /*  147 */  _ConvI2L_iRegI__rule,
  /*  148 */  immIScale_rule,
  /*  149 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  150 */  0,
  /*  151 */  _LShiftL_iRegL_immIScale_rule,
  /*  152 */  _ConvI2L_iRegI__rule,
  /*  153 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  154 */  0,
  /*  155 */  0,
  /*  156 */  0,
  /*  157 */  0,
  /*  158 */  0,
  /*  159 */  0,
  /*  160 */  0,
  /*  161 */  0,
  /*  162 */  0,
  /*  163 */  0,
  /*  164 */  0,
  /*  165 */  0,
  /*  166 */  0,
  /*  167 */  0,
  /*  168 */  0,
  /*  169 */  iRegP_rule,
  /*  170 */  iRegLNoSp_rule,
  /*  171 */  iRegINoSp_rule,
  /*  172 */  iRegNNoSp_rule,
  /*  173 */  iRegN_rule,
  /*  174 */  rFlagsReg_rule,
  /*  175 */  iRegIorL2I_rule,
  /*  176 */  rFlagsRegU_rule,
  /*  177 */  iRegIorL2I_rule,
  /*  178 */  immI0_rule,
  /*  179 */  immI0_rule,
  /*  180 */  iRegL_rule,
  /*  181 */  immL0_rule,
  /*  182 */  iRegL_rule,
  /*  183 */  immP0_rule,
  /*  184 */  iRegP_rule,
  /*  185 */  immN0_rule,
  /*  186 */  iRegN_rule,
  /*  187 */  vRegF_rule,
  /*  188 */  vRegD_rule,
  /*  189 */  0,
  /*  190 */  0,
  /*  191 */  immIScale_rule,
  /*  192 */  iRegIorL2I_rule,
  /*  193 */  iRegL_rule,
  /*  194 */  immI_31_rule,
  /*  195 */  immI_31_rule,
  /*  196 */  immL_63_rule,
  /*  197 */  immL_63_rule,
  /*  198 */  immI_M1_rule,
  /*  199 */  immL_M1_rule,
  /*  200 */  iRegIorL2I_rule,
  /*  201 */  iRegL_rule,
  /*  202 */  immI_rule,
  /*  203 */  immI_M1_rule,
  /*  204 */  immI_rule,
  /*  205 */  immL_M1_rule,
  /*  206 */  immI_rule,
  /*  207 */  immI_M1_rule,
  /*  208 */  immI_rule,
  /*  209 */  immL_M1_rule,
  /*  210 */  immI_rule,
  /*  211 */  immI_M1_rule,
  /*  212 */  immI_rule,
  /*  213 */  immL_M1_rule,
  /*  214 */  iRegIorL2I_rule,
  /*  215 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  216 */  iRegL_rule,
  /*  217 */  _URShiftL_iRegL_immI_rule,
  /*  218 */  iRegIorL2I_rule,
  /*  219 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  220 */  iRegL_rule,
  /*  221 */  _RShiftL_iRegL_immI_rule,
  /*  222 */  iRegIorL2I_rule,
  /*  223 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  224 */  iRegL_rule,
  /*  225 */  _LShiftL_iRegL_immI_rule,
  /*  226 */  immI_bitmask_rule,
  /*  227 */  iRegI_rule,
  /*  228 */  iRegI_rule,
  /*  229 */  _SubI_immI_64_iRegI_rule,
  /*  230 */  iRegI_rule,
  /*  231 */  _SubI_immI0_iRegI_rule,
  /*  232 */  iRegI_rule,
  /*  233 */  iRegI_rule,
  /*  234 */  _SubI_immI_32_iRegI_rule,
  /*  235 */  _SubI_immI0_iRegI_rule,
  /*  236 */  iRegI_rule,
  /*  237 */  _SubI_immI_64_iRegI_rule,
  /*  238 */  _SubI_immI0_iRegI_rule,
  /*  239 */  iRegI_rule,
  /*  240 */  _SubI_immI_32_iRegI_rule,
  /*  241 */  _SubI_immI0_iRegI_rule,
  /*  242 */  immI_16_rule,
  /*  243 */  immI_16_rule,
  /*  244 */  immI_24_rule,
  /*  245 */  immI_24_rule,
  /*  246 */  immI_24_rule,
  /*  247 */  immI_48_rule,
  /*  248 */  immI_48_rule,
  /*  249 */  immI_32_rule,
  /*  250 */  immI_32_rule,
  /*  251 */  immI_56_rule,
  /*  252 */  immI_56_rule,
  /*  253 */  immI_56_rule,
  /*  254 */  immI_255_rule,
  /*  255 */  immI_65535_rule,
  /*  256 */  immL_255_rule,
  /*  257 */  immL_65535_rule,
  /*  258 */  immL_4294967295_rule,
  /*  259 */  0,
  /*  260 */  0,
  /*  261 */  iRegIorL2I_rule,
  /*  262 */  iRegL_rule,
  /*  263 */  immI0_rule,
  /*  264 */  immL0_rule,
  /*  265 */  immP0_rule,
  /*  266 */  immN0_rule,
  /*  267 */  immP0_rule,
  /*  268 */  immI0_rule,
  /*  269 */  immL0_rule,
  /*  270 */  immL_rule,
  /*  271 */  immL0_rule,
  /*  272 */  immI_rule,
  /*  273 */  immI0_rule,
  /*  274 */  iRegL_rule,
  /*  275 */  iRegIorL2I_rule,
  /*  276 */  iRegP_R0_rule,
  /*  277 */  iRegI_R2_rule,
  /*  278 */  iRegI_R4_rule,
  /*  279 */  iRegI_R4_rule,
  /*  280 */  iRegI_R2_rule,
  /*  281 */  immI_le_4_rule,
  /*  282 */  iRegP_R3_rule,
  /*  283 */  iRegI_R3_rule,
  /*  284 */  vecD_rule,
  /*  285 */  vecX_rule,
  /*  286 */  vecD_rule,
  /*  287 */  vecX_rule,
  // last internally defined operand
  /*  288 */  0,
  /*  289 */  0,
  /*  290 */  0,
  /*  291 */  0,
  /*  292 */  0,
  /*  293 */  0,
  /*  294 */  0,
  /*  295 */  0,
  /*  296 */  0,
  /*  297 */  0,
  /*  298 */  0,
  /*  299 */  0,
  /*  300 */  0,
  /*  301 */  0,
  /*  302 */  0,
  /*  303 */  0,
  /*  304 */  0,
  /*  305 */  0,
  /*  306 */  0,
  /*  307 */  0,
  /*  308 */  0,
  /*  309 */  0,
  /*  310 */  0,
  /*  311 */  _Binary_iRegP_iRegP_rule,
  /*  312 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  313 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  314 */  0,
  /*  315 */  0,
  /*  316 */  0,
  /*  317 */  0,
  /*  318 */  0,
  /*  319 */  0,
  /*  320 */  0,
  /*  321 */  0,
  /*  322 */  0,
  /*  323 */  0,
  /*  324 */  0,
  /*  325 */  0,
  /*  326 */  iRegIorL2I_rule,
  /*  327 */  immIAddSub_rule,
  /*  328 */  iRegL_rule,
  /*  329 */  immLAddSub_rule,
  /*  330 */  iRegIorL2I_rule,
  /*  331 */  immIAddSub_rule,
  /*  332 */  iRegL_rule,
  /*  333 */  immLAddSub_rule,
  /*  334 */  iRegIorL2I_rule,
  /*  335 */  iRegL_rule,
  /*  336 */  iRegIorL2I_rule,
  /*  337 */  iRegL_rule,
  /*  338 */  iRegI_rule,
  /*  339 */  immI0_rule,
  /*  340 */  immIAddSub_rule,
  /*  341 */  immI_rule,
  /*  342 */  iRegI_rule,
  /*  343 */  immI0_rule,
  /*  344 */  immIAddSub_rule,
  /*  345 */  immI_rule,
  /*  346 */  iRegL_rule,
  /*  347 */  immL0_rule,
  /*  348 */  immLAddSub_rule,
  /*  349 */  immL_rule,
  /*  350 */  iRegL_rule,
  /*  351 */  immL0_rule,
  /*  352 */  immLAddSub_rule,
  /*  353 */  immL_rule,
  /*  354 */  iRegP_rule,
  /*  355 */  iRegN_rule,
  /*  356 */  immP0_rule,
  /*  357 */  immN0_rule,
  /*  358 */  vRegF_rule,
  /*  359 */  immF0_rule,
  /*  360 */  vRegD_rule,
  /*  361 */  immD0_rule,
  /*  362 */  immL0_rule,
  /*  363 */  immI0_rule,
  /*  364 */  immL0_rule,
  /*  365 */  immI0_rule,
  /*  366 */  iRegP_rule,
  /*  367 */  iRegP_rule,
  /*  368 */  immP0_rule,
  /*  369 */  0,
  /*  370 */  0,
  /*  371 */  0,
  /*  372 */  0,
  /*  373 */  0,
  /*  374 */  0,
  /*  375 */  0,
  /*  376 */  0,
  /*  377 */  0,
  /*  378 */  0,
  /*  379 */  0,
  /*  380 */  0,
  /*  381 */  0,
  /*  382 */  0,
  /*  383 */  0,
  /*  384 */  immL_32bits_rule,
  /*  385 */  0,
  /*  386 */  0,
  /*  387 */  0,
  /*  388 */  0,
  /*  389 */  0,
  /*  390 */  0,
  /*  391 */  0,
  /*  392 */  0,
  /*  393 */  immI0_rule,
  /*  394 */  immI0_rule,
  /*  395 */  iRegIorL2I_rule,
  /*  396 */  immI0_rule,
  /*  397 */  iRegIorL2I_rule,
  /*  398 */  immI0_rule,
  /*  399 */  iRegIorL2I_rule,
  /*  400 */  immI0_rule,
  /*  401 */  iRegL_rule,
  /*  402 */  immL0_rule,
  /*  403 */  iRegP_rule,
  /*  404 */  immP0_rule,
  /*  405 */  iRegN_rule,
  /*  406 */  immN0_rule,
  /*  407 */  vRegF_rule,
  /*  408 */  vRegD_rule,
  /*  409 */  iRegN_rule,
  /*  410 */  0,
  /*  411 */  0,
  /*  412 */  0,
  /*  413 */  0,
  /*  414 */  0,
  /*  415 */  0,
  /*  416 */  0,
  /*  417 */  0,
  /*  418 */  0,
  /*  419 */  0,
  /*  420 */  0,
  /*  421 */  0,
  /*  422 */  immL_32bits_rule,
  /*  423 */  0,
  /*  424 */  0,
  /*  425 */  0,
  /*  426 */  0,
  /*  427 */  0,
  /*  428 */  iRegIorL2I_rule,
  /*  429 */  iRegIorL2I_rule,
  /*  430 */  iRegIorL2I_rule,
  /*  431 */  iRegL_rule,
  /*  432 */  iRegP_rule,
  /*  433 */  iRegN_rule,
  /*  434 */  vRegF_rule,
  /*  435 */  vRegD_rule,
  /*  436 */  0,
  /*  437 */  0,
  /*  438 */  0,
  /*  439 */  0,
  /*  440 */  0,
  /*  441 */  0,
  /*  442 */  0,
  /*  443 */  0,
  /*  444 */  0,
  /*  445 */  0,
  /*  446 */  0,
  /*  447 */  0,
  /*  448 */  0,
  /*  449 */  0,
  /*  450 */  0,
  /*  451 */  0,
  /*  452 */  0,
  /*  453 */  0,
  /*  454 */  0,
  /*  455 */  0,
  /*  456 */  0,
  /*  457 */  0,
  /*  458 */  0,
  /*  459 */  0,
  /*  460 */  0,
  /*  461 */  0,
  /*  462 */  0,
  /*  463 */  0,
  /*  464 */  0,
  /*  465 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  466 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  467 */  _Binary_iRegP_iRegP_rule,
  /*  468 */  _Binary_iRegP_iRegP_rule,
  /*  469 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  470 */  _Binary_iRegN_iRegN_rule,
  /*  471 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  472 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  473 */  _Binary_iRegP_iRegP_rule,
  /*  474 */  _Binary_iRegP_iRegP_rule,
  /*  475 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  476 */  _Binary_iRegN_iRegN_rule,
  /*  477 */  iRegI_rule,
  /*  478 */  iRegL_rule,
  /*  479 */  iRegN_rule,
  /*  480 */  iRegP_rule,
  /*  481 */  iRegL_rule,
  /*  482 */  iRegL_rule,
  /*  483 */  immLAddSub_rule,
  /*  484 */  immLAddSub_rule,
  /*  485 */  iRegIorL2I_rule,
  /*  486 */  iRegIorL2I_rule,
  /*  487 */  immIAddSub_rule,
  /*  488 */  immIAddSub_rule,
  /*  489 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  490 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  491 */  _Binary_immI0_iRegIorL2I_rule,
  /*  492 */  _Binary_immI0_iRegIorL2I_rule,
  /*  493 */  _Binary_iRegIorL2I_immI0_rule,
  /*  494 */  _Binary_iRegIorL2I_immI0_rule,
  /*  495 */  _Binary_immI_1_immI0_rule,
  /*  496 */  _Binary_immI_1_immI0_rule,
  /*  497 */  _Binary_iRegL_iRegL_rule,
  /*  498 */  _Binary_iRegL_iRegL_rule,
  /*  499 */  _Binary_iRegL_immL0_rule,
  /*  500 */  _Binary_iRegL_immL0_rule,
  /*  501 */  _Binary_immL0_iRegL_rule,
  /*  502 */  _Binary_immL0_iRegL_rule,
  /*  503 */  _Binary_iRegP_iRegP_rule,
  /*  504 */  _Binary_iRegP_iRegP_rule,
  /*  505 */  _Binary_iRegP_immP0_rule,
  /*  506 */  _Binary_iRegP_immP0_rule,
  /*  507 */  _Binary_immP0_iRegP_rule,
  /*  508 */  _Binary_immP0_iRegP_rule,
  /*  509 */  _Binary_iRegN_iRegN_rule,
  /*  510 */  _Binary_iRegN_iRegN_rule,
  /*  511 */  _Binary_iRegN_immN0_rule,
  /*  512 */  _Binary_iRegN_immN0_rule,
  /*  513 */  _Binary_immN0_iRegN_rule,
  /*  514 */  _Binary_immN0_iRegN_rule,
  /*  515 */  _Binary_vRegF_vRegF_rule,
  /*  516 */  _Binary_vRegF_vRegF_rule,
  /*  517 */  _Binary_vRegD_vRegD_rule,
  /*  518 */  _Binary_vRegD_vRegD_rule,
  /*  519 */  iRegIorL2I_rule,
  /*  520 */  immIAddSub_rule,
  /*  521 */  immIAddSub_rule,
  /*  522 */  iRegL_rule,
  /*  523 */  _ConvI2L_iRegIorL2I__rule,
  /*  524 */  _LShiftL_iRegL_immIScale_rule,
  /*  525 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  526 */  immI_rule,
  /*  527 */  immLAddSub_rule,
  /*  528 */  iRegL_rule,
  /*  529 */  immLAddSub_rule,
  /*  530 */  iRegIorL2I_rule,
  /*  531 */  immIAddSub_rule,
  /*  532 */  iRegL_rule,
  /*  533 */  immLAddSub_rule,
  /*  534 */  iRegIorL2I_rule,
  /*  535 */  iRegIorL2I_rule,
  /*  536 */  iRegIorL2I_rule,
  /*  537 */  _ConvI2L_iRegIorL2I__rule,
  /*  538 */  _ConvI2L_iRegIorL2I__rule,
  /*  539 */  iRegL_rule,
  /*  540 */  iRegL_rule,
  /*  541 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  542 */  iRegIorL2I_rule,
  /*  543 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  544 */  _MulL_iRegL_iRegL_rule,
  /*  545 */  iRegL_rule,
  /*  546 */  _MulL_iRegL_iRegL_rule,
  /*  547 */  iRegIorL2I_rule,
  /*  548 */  immI_31_rule,
  /*  549 */  _URShiftI__RShiftI_iRegIorL2I_immI_31_immI_31_rule,
  /*  550 */  iRegIorL2I_rule,
  /*  551 */  iRegL_rule,
  /*  552 */  immL_63_rule,
  /*  553 */  _URShiftL__RShiftL_iRegL_immL_63_immL_63_rule,
  /*  554 */  iRegL_rule,
  /*  555 */  iRegIorL2I_rule,
  /*  556 */  iRegL_rule,
  /*  557 */  iRegIorL2I_rule,
  /*  558 */  immI_rule,
  /*  559 */  iRegIorL2I_rule,
  /*  560 */  immI_rule,
  /*  561 */  iRegIorL2I_rule,
  /*  562 */  immI_rule,
  /*  563 */  iRegIorL2I_rule,
  /*  564 */  immI_rule,
  /*  565 */  iRegIorL2I_rule,
  /*  566 */  immI_rule,
  /*  567 */  immI_rule,
  /*  568 */  iRegIorL2I_rule,
  /*  569 */  immI_rule,
  /*  570 */  immL_M1_rule,
  /*  571 */  immI_M1_rule,
  /*  572 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  573 */  iRegIorL2I_rule,
  /*  574 */  _XorL_iRegL_immL_M1_rule,
  /*  575 */  iRegL_rule,
  /*  576 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  577 */  iRegIorL2I_rule,
  /*  578 */  _XorL_iRegL_immL_M1_rule,
  /*  579 */  iRegL_rule,
  /*  580 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  581 */  immI_M1_rule,
  /*  582 */  _XorL_iRegL_iRegL_rule,
  /*  583 */  immL_M1_rule,
  /*  584 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  585 */  iRegIorL2I_rule,
  /*  586 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  587 */  iRegL_rule,
  /*  588 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  589 */  iRegIorL2I_rule,
  /*  590 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  591 */  iRegL_rule,
  /*  592 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  593 */  iRegIorL2I_rule,
  /*  594 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  595 */  iRegL_rule,
  /*  596 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  597 */  immI_M1_rule,
  /*  598 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  599 */  immI_M1_rule,
  /*  600 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  601 */  immL_M1_rule,
  /*  602 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  603 */  immL_M1_rule,
  /*  604 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  605 */  immI_M1_rule,
  /*  606 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  607 */  immI_M1_rule,
  /*  608 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  609 */  immL_M1_rule,
  /*  610 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  611 */  immL_M1_rule,
  /*  612 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  613 */  immI_M1_rule,
  /*  614 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  615 */  immI_M1_rule,
  /*  616 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  617 */  immL_M1_rule,
  /*  618 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  619 */  immL_M1_rule,
  /*  620 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  621 */  iRegIorL2I_rule,
  /*  622 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  623 */  iRegL_rule,
  /*  624 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  625 */  iRegIorL2I_rule,
  /*  626 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  627 */  iRegL_rule,
  /*  628 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  629 */  iRegIorL2I_rule,
  /*  630 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  631 */  iRegL_rule,
  /*  632 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  633 */  iRegIorL2I_rule,
  /*  634 */  _URShiftL_iRegL_immI_rule,
  /*  635 */  iRegL_rule,
  /*  636 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  637 */  iRegIorL2I_rule,
  /*  638 */  _RShiftL_iRegL_immI_rule,
  /*  639 */  iRegL_rule,
  /*  640 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  641 */  iRegIorL2I_rule,
  /*  642 */  _LShiftL_iRegL_immI_rule,
  /*  643 */  iRegL_rule,
  /*  644 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  645 */  iRegIorL2I_rule,
  /*  646 */  _URShiftL_iRegL_immI_rule,
  /*  647 */  iRegL_rule,
  /*  648 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  649 */  iRegIorL2I_rule,
  /*  650 */  _RShiftL_iRegL_immI_rule,
  /*  651 */  iRegL_rule,
  /*  652 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  653 */  iRegIorL2I_rule,
  /*  654 */  _LShiftL_iRegL_immI_rule,
  /*  655 */  iRegL_rule,
  /*  656 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  657 */  iRegIorL2I_rule,
  /*  658 */  _URShiftL_iRegL_immI_rule,
  /*  659 */  iRegL_rule,
  /*  660 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  661 */  iRegIorL2I_rule,
  /*  662 */  _RShiftL_iRegL_immI_rule,
  /*  663 */  iRegL_rule,
  /*  664 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  665 */  iRegIorL2I_rule,
  /*  666 */  _LShiftL_iRegL_immI_rule,
  /*  667 */  iRegL_rule,
  /*  668 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  669 */  iRegIorL2I_rule,
  /*  670 */  _URShiftL_iRegL_immI_rule,
  /*  671 */  iRegL_rule,
  /*  672 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  673 */  iRegIorL2I_rule,
  /*  674 */  _RShiftL_iRegL_immI_rule,
  /*  675 */  iRegL_rule,
  /*  676 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  677 */  iRegIorL2I_rule,
  /*  678 */  _LShiftL_iRegL_immI_rule,
  /*  679 */  iRegL_rule,
  /*  680 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  681 */  _URShiftL_iRegL_immI_rule,
  /*  682 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  683 */  _RShiftL_iRegL_immI_rule,
  /*  684 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  685 */  _LShiftL_iRegL_immI_rule,
  /*  686 */  immI_rule,
  /*  687 */  immI_rule,
  /*  688 */  immI_rule,
  /*  689 */  immI_rule,
  /*  690 */  immI_bitmask_rule,
  /*  691 */  immL_bitmask_rule,
  /*  692 */  0,
  /*  693 */  _URShiftL_iRegL_immI_rule,
  /*  694 */  _LShiftL_iRegL_immI_rule,
  /*  695 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  696 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  697 */  _URShiftL_iRegL_immI_rule,
  /*  698 */  _LShiftL_iRegL_immI_rule,
  /*  699 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  700 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  701 */  0,
  /*  702 */  0,
  /*  703 */  _URShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  704 */  _LShiftL_iRegL_iRegI_rule,
  /*  705 */  _URShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  706 */  _LShiftL_iRegL_iRegI_rule,
  /*  707 */  _URShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  708 */  _LShiftI_iRegI_iRegI_rule,
  /*  709 */  _URShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  710 */  _LShiftI_iRegI_iRegI_rule,
  /*  711 */  0,
  /*  712 */  0,
  /*  713 */  _LShiftL_iRegL__SubI_immI_64_iRegI_rule,
  /*  714 */  _URShiftL_iRegL_iRegI_rule,
  /*  715 */  _LShiftL_iRegL__SubI_immI0_iRegI_rule,
  /*  716 */  _URShiftL_iRegL_iRegI_rule,
  /*  717 */  _LShiftI_iRegI__SubI_immI_32_iRegI_rule,
  /*  718 */  _URShiftI_iRegI_iRegI_rule,
  /*  719 */  _LShiftI_iRegI__SubI_immI0_iRegI_rule,
  /*  720 */  _URShiftI_iRegI_iRegI_rule,
  /*  721 */  _ConvI2L_iRegIorL2I__rule,
  /*  722 */  iRegL_rule,
  /*  723 */  _ConvI2L_iRegIorL2I__rule,
  /*  724 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  725 */  iRegIorL2I_rule,
  /*  726 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  727 */  iRegIorL2I_rule,
  /*  728 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  729 */  iRegIorL2I_rule,
  /*  730 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  731 */  iRegL_rule,
  /*  732 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  733 */  iRegL_rule,
  /*  734 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  735 */  iRegL_rule,
  /*  736 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  737 */  iRegL_rule,
  /*  738 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  739 */  iRegIorL2I_rule,
  /*  740 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  741 */  iRegIorL2I_rule,
  /*  742 */  _AndL_iRegL_immL_255_rule,
  /*  743 */  iRegL_rule,
  /*  744 */  _AndL_iRegL_immL_65535_rule,
  /*  745 */  iRegL_rule,
  /*  746 */  _AndL_iRegL_immL_4294967295_rule,
  /*  747 */  iRegL_rule,
  /*  748 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  749 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  750 */  _AndL_iRegL_immL_255_rule,
  /*  751 */  _AndL_iRegL_immL_65535_rule,
  /*  752 */  _AndL_iRegL_immL_4294967295_rule,
  /*  753 */  vRegF_rule,
  /*  754 */  vRegD_rule,
  /*  755 */  vRegF_rule,
  /*  756 */  vRegD_rule,
  /*  757 */  vRegF_rule,
  /*  758 */  vRegD_rule,
  /*  759 */  vRegF_rule,
  /*  760 */  vRegD_rule,
  /*  761 */  0,
  /*  762 */  0,
  /*  763 */  iRegIorL2I_rule,
  /*  764 */  immILog_rule,
  /*  765 */  iRegIorL2I_rule,
  /*  766 */  immILog_rule,
  /*  767 */  iRegIorL2I_rule,
  /*  768 */  immILog_rule,
  /*  769 */  iRegL_rule,
  /*  770 */  immLLog_rule,
  /*  771 */  iRegL_rule,
  /*  772 */  immLLog_rule,
  /*  773 */  iRegL_rule,
  /*  774 */  immLLog_rule,
  /*  775 */  0,
  /*  776 */  immL_32bits_rule,
  /*  777 */  0,
  /*  778 */  0,
  /*  779 */  0,
  /*  780 */  0,
  /*  781 */  0,
  /*  782 */  0,
  /*  783 */  0,
  /*  784 */  0,
  /*  785 */  0,
  /*  786 */  0,
  /*  787 */  0,
  /*  788 */  0,
  /*  789 */  0,
  /*  790 */  0,
  /*  791 */  0,
  /*  792 */  0,
  /*  793 */  0,
  /*  794 */  iRegP_R10_rule,
  /*  795 */  iRegP_R10_rule,
  /*  796 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /*  797 */  _OverflowMulL_iRegL_iRegL_rule,
  /*  798 */  vRegF_rule,
  /*  799 */  vRegD_rule,
  /*  800 */  immF0_rule,
  /*  801 */  immD0_rule,
  /*  802 */  iRegL_rule,
  /*  803 */  iRegIorL2I_rule,
  /*  804 */  immI0_rule,
  /*  805 */  iRegI_rule,
  /*  806 */  iRegI_rule,
  /*  807 */  0,
  /*  808 */  rFlagsReg_rule,
  /*  809 */  rFlagsRegU_rule,
  /*  810 */  _CmpI_iRegIorL2I_immI0_rule,
  /*  811 */  _CmpL_iRegL_immL0_rule,
  /*  812 */  _CmpP_iRegP_immP0_rule,
  /*  813 */  _CmpN_iRegN_immN0_rule,
  /*  814 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /*  815 */  _CmpU_iRegIorL2I_immI0_rule,
  /*  816 */  _CmpUL_iRegL_immL0_rule,
  /*  817 */  _CmpL_iRegL_immL0_rule,
  /*  818 */  _CmpI_iRegIorL2I_immI0_rule,
  /*  819 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /*  820 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /*  821 */  _CmpL_iRegL_immL0_rule,
  /*  822 */  _CmpI_iRegIorL2I_immI0_rule,
  /*  823 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /*  824 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /*  825 */  rFlagsReg_rule,
  /*  826 */  rFlagsRegU_rule,
  /*  827 */  0,
  /*  828 */  0,
  /*  829 */  0,
  /*  830 */  0,
  /*  831 */  0,
  /*  832 */  0,
  /*  833 */  0,
  /*  834 */  inline_cache_RegP_rule,
  /*  835 */  iRegP_R0_rule,
  /*  836 */  0,
  /*  837 */  0,
  /*  838 */  0,
  /*  839 */  0,
  /*  840 */  iRegP_R0_rule,
  /*  841 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /*  842 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /*  843 */  _Binary_iRegP_R3_immI_le_4_rule,
  /*  844 */  iRegI_R4_rule,
  /*  845 */  iRegP_R2_rule,
  /*  846 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /*  847 */  0,
  /*  848 */  0,
  /*  849 */  0,
  /*  850 */  vecD_rule,
  /*  851 */  vecD_rule,
  /*  852 */  vecX_rule,
  /*  853 */  0,
  /*  854 */  0,
  /*  855 */  0,
  /*  856 */  0,
  /*  857 */  0,
  /*  858 */  0,
  /*  859 */  0,
  /*  860 */  0,
  /*  861 */  0,
  /*  862 */  0,
  /*  863 */  0,
  /*  864 */  0,
  /*  865 */  0,
  /*  866 */  0,
  /*  867 */  0,
  /*  868 */  0,
  /*  869 */  0,
  /*  870 */  vecD_rule,
  /*  871 */  vecX_rule,
  /*  872 */  vecD_rule,
  /*  873 */  vecX_rule,
  /*  874 */  vecD_rule,
  /*  875 */  vecX_rule,
  /*  876 */  vecX_rule,
  /*  877 */  vecD_rule,
  /*  878 */  vecX_rule,
  /*  879 */  vecX_rule,
  /*  880 */  vecD_rule,
  /*  881 */  vecX_rule,
  /*  882 */  vecD_rule,
  /*  883 */  vecX_rule,
  /*  884 */  vecD_rule,
  /*  885 */  vecX_rule,
  /*  886 */  vecX_rule,
  /*  887 */  vecD_rule,
  /*  888 */  vecX_rule,
  /*  889 */  vecX_rule,
  /*  890 */  vecD_rule,
  /*  891 */  vecX_rule,
  /*  892 */  vecD_rule,
  /*  893 */  vecX_rule,
  /*  894 */  vecD_rule,
  /*  895 */  vecX_rule,
  /*  896 */  vecX_rule,
  /*  897 */  _MulVS_vecD_vecD_rule,
  /*  898 */  _MulVS_vecX_vecX_rule,
  /*  899 */  _MulVI_vecD_vecD_rule,
  /*  900 */  _MulVI_vecX_vecX_rule,
  /*  901 */  _MulVS_vecD_vecD_rule,
  /*  902 */  _MulVS_vecX_vecX_rule,
  /*  903 */  _MulVI_vecD_vecD_rule,
  /*  904 */  _MulVI_vecX_vecX_rule,
  /*  905 */  vecD_rule,
  /*  906 */  vecX_rule,
  /*  907 */  vecX_rule,
  /*  908 */  vecD_rule,
  /*  909 */  vecX_rule,
  /*  910 */  vecD_rule,
  /*  911 */  vecX_rule,
  /*  912 */  vecD_rule,
  /*  913 */  vecX_rule,
  /*  914 */  vecD_rule,
  /*  915 */  vecX_rule,
  /*  916 */  vecD_rule,
  /*  917 */  vecX_rule,
  /*  918 */  vecD_rule,
  /*  919 */  vecX_rule,
  /*  920 */  immI_rule,
  /*  921 */  immI_rule,
  /*  922 */  immI_rule,
  /*  923 */  immI_rule,
  /*  924 */  immI_rule,
  /*  925 */  immI_rule,
  /*  926 */  vecD_rule,
  /*  927 */  vecX_rule,
  /*  928 */  vecD_rule,
  /*  929 */  vecX_rule,
  /*  930 */  vecD_rule,
  /*  931 */  vecX_rule,
  /*  932 */  immI_rule,
  /*  933 */  immI_rule,
  /*  934 */  immI_rule,
  /*  935 */  immI_rule,
  /*  936 */  immI_rule,
  /*  937 */  immI_rule,
  /*  938 */  vecD_rule,
  /*  939 */  vecX_rule,
  /*  940 */  vecD_rule,
  /*  941 */  vecX_rule,
  /*  942 */  vecD_rule,
  /*  943 */  vecX_rule,
  /*  944 */  immI_rule,
  /*  945 */  immI_rule,
  /*  946 */  immI_rule,
  /*  947 */  immI_rule,
  /*  948 */  immI_rule,
  /*  949 */  immI_rule,
  /*  950 */  vecX_rule,
  /*  951 */  vecX_rule,
  /*  952 */  vecX_rule,
  /*  953 */  immI_rule,
  /*  954 */  immI_rule,
  /*  955 */  immI_rule,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMI",
  /*    9 */  "IMMI0",
  /*   10 */  "IMMI_1",
  /*   11 */  "IMMI_M1",
  /*   12 */  "IMMI_LE_4",
  /*   13 */  "IMMI_31",
  /*   14 */  "IMMI_8",
  /*   15 */  "IMMI_16",
  /*   16 */  "IMMI_24",
  /*   17 */  "IMMI_32",
  /*   18 */  "IMMI_48",
  /*   19 */  "IMMI_56",
  /*   20 */  "IMMI_64",
  /*   21 */  "IMMI_255",
  /*   22 */  "IMMI_65535",
  /*   23 */  "IMML_63",
  /*   24 */  "IMML_255",
  /*   25 */  "IMML_65535",
  /*   26 */  "IMML_4294967295",
  /*   27 */  "IMML_BITMASK",
  /*   28 */  "IMMI_BITMASK",
  /*   29 */  "IMMISCALE",
  /*   30 */  "IMMI26",
  /*   31 */  "IMMI19",
  /*   32 */  "IMMIU12",
  /*   33 */  "IMMLU12",
  /*   34 */  "IMMIOFFSET",
  /*   35 */  "IMMIOFFSET4",
  /*   36 */  "IMMIOFFSET8",
  /*   37 */  "IMMIOFFSET16",
  /*   38 */  "IMMLOFFSET",
  /*   39 */  "IMMLOFFSET4",
  /*   40 */  "IMMLOFFSET8",
  /*   41 */  "IMMLOFFSET16",
  /*   42 */  "IMMIADDSUB",
  /*   43 */  "IMMILOG",
  /*   44 */  "IMML",
  /*   45 */  "IMML0",
  /*   46 */  "IMML_1",
  /*   47 */  "IMML_M1",
  /*   48 */  "IMML_PC_OFF",
  /*   49 */  "IMMLADDSUB",
  /*   50 */  "IMMLLOG",
  /*   51 */  "IMML_32BITS",
  /*   52 */  "IMMP",
  /*   53 */  "IMMP0",
  /*   54 */  "IMMP_1",
  /*   55 */  "IMMPOLLPAGE",
  /*   56 */  "IMMBYTEMAPBASE",
  /*   57 */  "IMMP_M1",
  /*   58 */  "IMMP_M2",
  /*   59 */  "IMMD",
  /*   60 */  "IMMD0",
  /*   61 */  "IMMDPACKED",
  /*   62 */  "IMMF",
  /*   63 */  "IMMF0",
  /*   64 */  "IMMFPACKED",
  /*   65 */  "IMMN",
  /*   66 */  "IMMN0",
  /*   67 */  "IMMNKLASS",
  /*   68 */  "IREGI",
  /*   69 */  "IREGINOSP",
  /*   70 */  "IREGL",
  /*   71 */  "IREGLNOSP",
  /*   72 */  "IREGP",
  /*   73 */  "IREGPNOSP",
  /*   74 */  "IREGP_R0",
  /*   75 */  "IREGP_R1",
  /*   76 */  "IREGP_R2",
  /*   77 */  "IREGP_R3",
  /*   78 */  "IREGP_R4",
  /*   79 */  "IREGP_R5",
  /*   80 */  "IREGP_R10",
  /*   81 */  "IREGL_R11",
  /*   82 */  "IREGP_FP",
  /*   83 */  "IREGI_R0",
  /*   84 */  "IREGI_R2",
  /*   85 */  "IREGI_R3",
  /*   86 */  "IREGI_R4",
  /*   87 */  "IREGN",
  /*   88 */  "IREGNNOSP",
  /*   89 */  "IREGIHEAPBASE",
  /*   90 */  "VREGF",
  /*   91 */  "VREGD",
  /*   92 */  "VECD",
  /*   93 */  "VECX",
  /*   94 */  "VREGD_V0",
  /*   95 */  "VREGD_V1",
  /*   96 */  "VREGD_V2",
  /*   97 */  "VREGD_V3",
  /*   98 */  "RFLAGSREG",
  /*   99 */  "RFLAGSREGU",
  /*  100 */  "INLINE_CACHE_REGP",
  /*  101 */  "INTERPRETER_METHOD_OOP_REGP",
  /*  102 */  "THREAD_REGP",
  /*  103 */  "LR_REGP",
  /*  104 */  "INDIRECT",
  /*  105 */  "INDINDEXSCALEDOFFSETI",
  /*  106 */  "INDINDEXSCALEDOFFSETL",
  /*  107 */  "INDINDEXOFFSETI2L",
  /*  108 */  "INDINDEXSCALEDOFFSETI2L",
  /*  109 */  "INDINDEXSCALEDI2L",
  /*  110 */  "INDINDEXSCALED",
  /*  111 */  "INDINDEX",
  /*  112 */  "INDOFFI",
  /*  113 */  "INDOFFI4",
  /*  114 */  "INDOFFI8",
  /*  115 */  "INDOFFI16",
  /*  116 */  "INDOFFL",
  /*  117 */  "INDOFFL4",
  /*  118 */  "INDOFFL8",
  /*  119 */  "INDOFFL16",
  /*  120 */  "INDIRECTN",
  /*  121 */  "INDINDEXSCALEDOFFSETIN",
  /*  122 */  "INDINDEXSCALEDOFFSETLN",
  /*  123 */  "INDINDEXOFFSETI2LN",
  /*  124 */  "INDINDEXSCALEDOFFSETI2LN",
  /*  125 */  "INDINDEXSCALEDI2LN",
  /*  126 */  "INDINDEXSCALEDN",
  /*  127 */  "INDINDEXN",
  /*  128 */  "INDOFFIN",
  /*  129 */  "INDOFFLN",
  /*  130 */  "THREAD_ANCHOR_PC",
  /*  131 */  "STACKSLOTP",
  /*  132 */  "STACKSLOTI",
  /*  133 */  "STACKSLOTF",
  /*  134 */  "STACKSLOTD",
  /*  135 */  "STACKSLOTL",
  /*  136 */  "CMPOP",
  /*  137 */  "CMPOPU",
  /*  138 */  "IREGL2I",
  // last operand
  /*  139 */  "VMEM4",
  /*  140 */  "VMEM8",
  /*  141 */  "VMEM16",
  /*  142 */  "MEMORY",
  /*  143 */  "IREGIORL2I",
  // last operand class
  /*  144 */  "_LShiftL_iRegL_immIScale",
  /*  145 */  "_AddP_iRegP__LShiftL_iRegL_immIScale",
  /*  146 */  "_ConvI2L_iRegI_",
  /*  147 */  "_AddP_iRegP__ConvI2L_iRegI_",
  /*  148 */  "_LShiftL__ConvI2L_iRegI__immIScale",
  /*  149 */  "_AddP_iRegP__LShiftL__ConvI2L_iRegI__immIScale",
  /*  150 */  "_DecodeN_iRegN_",
  /*  151 */  "_AddP__DecodeN_iRegN___LShiftL_iRegL_immIScale",
  /*  152 */  "_AddP__DecodeN_iRegN___ConvI2L_iRegI_",
  /*  153 */  "_AddP__DecodeN_iRegN___LShiftL__ConvI2L_iRegI__immIScale",
  /*  154 */  "_LoadB_memory_",
  /*  155 */  "_LoadUB_memory_",
  /*  156 */  "_LoadS_memory_",
  /*  157 */  "_LoadUS_memory_",
  /*  158 */  "_LoadI_memory_",
  /*  159 */  "_ConvI2L__LoadI_memory__",
  /*  160 */  "_LoadB_indirect_",
  /*  161 */  "_LoadUB_indirect_",
  /*  162 */  "_LoadUS_indirect_",
  /*  163 */  "_LoadS_indirect_",
  /*  164 */  "_LoadI_indirect_",
  /*  165 */  "_ConvI2L__LoadI_indirect__",
  /*  166 */  "_LoadL_memory_",
  /*  167 */  "_CastP2X_iRegP_",
  /*  168 */  "_CastP2X__DecodeN_iRegN__",
  /*  169 */  "_Binary_iRegP_iRegP",
  /*  170 */  "_Binary_iRegLNoSp_iRegLNoSp",
  /*  171 */  "_Binary_iRegINoSp_iRegINoSp",
  /*  172 */  "_Binary_iRegNNoSp_iRegNNoSp",
  /*  173 */  "_Binary_iRegN_iRegN",
  /*  174 */  "_Binary_cmpOp_rFlagsReg",
  /*  175 */  "_Binary_iRegIorL2I_iRegIorL2I",
  /*  176 */  "_Binary_cmpOpU_rFlagsRegU",
  /*  177 */  "_Binary_immI0_iRegIorL2I",
  /*  178 */  "_Binary_iRegIorL2I_immI0",
  /*  179 */  "_Binary_immI_1_immI0",
  /*  180 */  "_Binary_iRegL_iRegL",
  /*  181 */  "_Binary_iRegL_immL0",
  /*  182 */  "_Binary_immL0_iRegL",
  /*  183 */  "_Binary_iRegP_immP0",
  /*  184 */  "_Binary_immP0_iRegP",
  /*  185 */  "_Binary_iRegN_immN0",
  /*  186 */  "_Binary_immN0_iRegN",
  /*  187 */  "_Binary_vRegF_vRegF",
  /*  188 */  "_Binary_vRegD_vRegD",
  /*  189 */  "_ConvL2I_iRegL_",
  /*  190 */  "_ConvI2L_iRegIorL2I_",
  /*  191 */  "_LShiftL__ConvI2L_iRegIorL2I__immIScale",
  /*  192 */  "_MulI_iRegIorL2I_iRegIorL2I",
  /*  193 */  "_MulL_iRegL_iRegL",
  /*  194 */  "_RShiftI_iRegIorL2I_immI_31",
  /*  195 */  "_URShiftI__RShiftI_iRegIorL2I_immI_31_immI_31",
  /*  196 */  "_RShiftL_iRegL_immL_63",
  /*  197 */  "_URShiftL__RShiftL_iRegL_immL_63_immL_63",
  /*  198 */  "_XorI_iRegIorL2I_immI_M1",
  /*  199 */  "_XorL_iRegL_immL_M1",
  /*  200 */  "_XorI_iRegIorL2I_iRegIorL2I",
  /*  201 */  "_XorL_iRegL_iRegL",
  /*  202 */  "_URShiftI_iRegIorL2I_immI",
  /*  203 */  "_XorI__URShiftI_iRegIorL2I_immI_immI_M1",
  /*  204 */  "_URShiftL_iRegL_immI",
  /*  205 */  "_XorL__URShiftL_iRegL_immI_immL_M1",
  /*  206 */  "_RShiftI_iRegIorL2I_immI",
  /*  207 */  "_XorI__RShiftI_iRegIorL2I_immI_immI_M1",
  /*  208 */  "_RShiftL_iRegL_immI",
  /*  209 */  "_XorL__RShiftL_iRegL_immI_immL_M1",
  /*  210 */  "_LShiftI_iRegIorL2I_immI",
  /*  211 */  "_XorI__LShiftI_iRegIorL2I_immI_immI_M1",
  /*  212 */  "_LShiftL_iRegL_immI",
  /*  213 */  "_XorL__LShiftL_iRegL_immI_immL_M1",
  /*  214 */  "_XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  215 */  "_XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI",
  /*  216 */  "_XorL__URShiftL_iRegL_immI_iRegL",
  /*  217 */  "_XorL_iRegL__URShiftL_iRegL_immI",
  /*  218 */  "_XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  219 */  "_XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI",
  /*  220 */  "_XorL__RShiftL_iRegL_immI_iRegL",
  /*  221 */  "_XorL_iRegL__RShiftL_iRegL_immI",
  /*  222 */  "_XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  223 */  "_XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI",
  /*  224 */  "_XorL__LShiftL_iRegL_immI_iRegL",
  /*  225 */  "_XorL_iRegL__LShiftL_iRegL_immI",
  /*  226 */  "_AndI__URShiftI_iRegIorL2I_immI_immI_bitmask",
  /*  227 */  "_LShiftL_iRegL_iRegI",
  /*  228 */  "_SubI_immI_64_iRegI",
  /*  229 */  "_URShiftL_iRegL__SubI_immI_64_iRegI",
  /*  230 */  "_SubI_immI0_iRegI",
  /*  231 */  "_URShiftL_iRegL__SubI_immI0_iRegI",
  /*  232 */  "_LShiftI_iRegI_iRegI",
  /*  233 */  "_SubI_immI_32_iRegI",
  /*  234 */  "_URShiftI_iRegI__SubI_immI_32_iRegI",
  /*  235 */  "_URShiftI_iRegI__SubI_immI0_iRegI",
  /*  236 */  "_URShiftL_iRegL_iRegI",
  /*  237 */  "_LShiftL_iRegL__SubI_immI_64_iRegI",
  /*  238 */  "_LShiftL_iRegL__SubI_immI0_iRegI",
  /*  239 */  "_URShiftI_iRegI_iRegI",
  /*  240 */  "_LShiftI_iRegI__SubI_immI_32_iRegI",
  /*  241 */  "_LShiftI_iRegI__SubI_immI0_iRegI",
  /*  242 */  "_LShiftI_iRegIorL2I_immI_16",
  /*  243 */  "_RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16",
  /*  244 */  "_LShiftI_iRegIorL2I_immI_24",
  /*  245 */  "_RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  246 */  "_URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  247 */  "_LShiftL_iRegL_immI_48",
  /*  248 */  "_RShiftL__LShiftL_iRegL_immI_48_immI_48",
  /*  249 */  "_LShiftL_iRegL_immI_32",
  /*  250 */  "_RShiftL__LShiftL_iRegL_immI_32_immI_32",
  /*  251 */  "_LShiftL_iRegL_immI_56",
  /*  252 */  "_RShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  253 */  "_URShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  254 */  "_AndI_iRegIorL2I_immI_255",
  /*  255 */  "_AndI_iRegIorL2I_immI_65535",
  /*  256 */  "_AndL_iRegL_immL_255",
  /*  257 */  "_AndL_iRegL_immL_65535",
  /*  258 */  "_AndL_iRegL_immL_4294967295",
  /*  259 */  "_ConvF2D_vRegF_",
  /*  260 */  "_SqrtD__ConvF2D_vRegF__",
  /*  261 */  "_OverflowMulI_iRegIorL2I_iRegIorL2I",
  /*  262 */  "_OverflowMulL_iRegL_iRegL",
  /*  263 */  "_CmpI_iRegIorL2I_immI0",
  /*  264 */  "_CmpL_iRegL_immL0",
  /*  265 */  "_CmpP_iRegP_immP0",
  /*  266 */  "_CmpN_iRegN_immN0",
  /*  267 */  "_CmpP__DecodeN_iRegN__immP0",
  /*  268 */  "_CmpU_iRegIorL2I_immI0",
  /*  269 */  "_CmpUL_iRegL_immL0",
  /*  270 */  "_AndL_iRegL_immL",
  /*  271 */  "_CmpL__AndL_iRegL_immL_immL0",
  /*  272 */  "_AndI_iRegIorL2I_immI",
  /*  273 */  "_CmpI__AndI_iRegIorL2I_immI_immI0",
  /*  274 */  "_AndL_iRegL_iRegL",
  /*  275 */  "_AndI_iRegIorL2I_iRegIorL2I",
  /*  276 */  "_PartialSubtypeCheck_iRegP_R4_iRegP_R0",
  /*  277 */  "_Binary_iRegP_R1_iRegI_R2",
  /*  278 */  "_Binary_iRegP_R3_iRegI_R4",
  /*  279 */  "_Binary_iRegP_R1_iRegI_R4",
  /*  280 */  "_Binary_iRegP_R3_iRegI_R2",
  /*  281 */  "_Binary_iRegP_R3_immI_le_4",
  /*  282 */  "_Binary_iRegP_R1_iRegP_R3",
  /*  283 */  "_Binary_iRegP_R1_iRegI_R3",
  /*  284 */  "_MulVS_vecD_vecD",
  /*  285 */  "_MulVS_vecX_vecX",
  /*  286 */  "_MulVI_vecD_vecD",
  /*  287 */  "_MulVI_vecX_vecX",
  // last internally defined operand
  /*  288 */  "loadConI",
  /*  289 */  "loadConL",
  /*  290 */  "loadConP",
  /*  291 */  "loadConP0",
  /*  292 */  "loadConP1",
  /*  293 */  "loadConPollPage",
  /*  294 */  "loadByteMapBase",
  /*  295 */  "loadConN",
  /*  296 */  "loadConN0",
  /*  297 */  "loadConNKlass",
  /*  298 */  "loadConF_packed",
  /*  299 */  "loadConF",
  /*  300 */  "loadConD_packed",
  /*  301 */  "loadConD",
  /*  302 */  "countLeadingZerosI",
  /*  303 */  "countLeadingZerosL",
  /*  304 */  "countTrailingZerosI",
  /*  305 */  "countTrailingZerosL",
  /*  306 */  "castX2P",
  /*  307 */  "castP2X",
  /*  308 */  "checkCastPP",
  /*  309 */  "castPP",
  /*  310 */  "castII",
  /*  311 */  "storePConditional",
  /*  312 */  "storeLConditional",
  /*  313 */  "storeIConditional",
  /*  314 */  "negF_reg_reg",
  /*  315 */  "negD_reg_reg",
  /*  316 */  "absF_reg",
  /*  317 */  "absD_reg",
  /*  318 */  "MoveF2I_stack_reg",
  /*  319 */  "MoveI2F_stack_reg",
  /*  320 */  "MoveD2L_stack_reg",
  /*  321 */  "MoveL2D_stack_reg",
  /*  322 */  "MoveF2I_reg_reg",
  /*  323 */  "MoveI2F_reg_reg",
  /*  324 */  "MoveD2L_reg_reg",
  /*  325 */  "MoveL2D_reg_reg",
  /*  326 */  "overflowAddI_reg_reg",
  /*  327 */  "overflowAddI_reg_imm",
  /*  328 */  "overflowAddL_reg_reg",
  /*  329 */  "overflowAddL_reg_imm",
  /*  330 */  "overflowSubI_reg_reg",
  /*  331 */  "overflowSubI_reg_imm",
  /*  332 */  "overflowSubL_reg_reg",
  /*  333 */  "overflowSubL_reg_imm",
  /*  334 */  "overflowNegI_reg",
  /*  335 */  "overflowNegL_reg",
  /*  336 */  "overflowMulI_reg",
  /*  337 */  "overflowMulL_reg",
  /*  338 */  "compI_reg_reg",
  /*  339 */  "compI_reg_immI0",
  /*  340 */  "compI_reg_immIAddSub",
  /*  341 */  "compI_reg_immI",
  /*  342 */  "compU_reg_reg",
  /*  343 */  "compU_reg_immI0",
  /*  344 */  "compU_reg_immIAddSub",
  /*  345 */  "compU_reg_immI",
  /*  346 */  "compL_reg_reg",
  /*  347 */  "compL_reg_immL0",
  /*  348 */  "compL_reg_immLAddSub",
  /*  349 */  "compL_reg_immL",
  /*  350 */  "compUL_reg_reg",
  /*  351 */  "compUL_reg_immL0",
  /*  352 */  "compUL_reg_immLAddSub",
  /*  353 */  "compUL_reg_immL",
  /*  354 */  "compP_reg_reg",
  /*  355 */  "compN_reg_reg",
  /*  356 */  "testP_reg",
  /*  357 */  "testN_reg",
  /*  358 */  "compF_reg_reg",
  /*  359 */  "compF_reg_zero",
  /*  360 */  "compD_reg_reg",
  /*  361 */  "compD_reg_zero",
  /*  362 */  "cmpL_and",
  /*  363 */  "cmpI_and",
  /*  364 */  "cmpL_and_reg",
  /*  365 */  "cmpI_and_reg",
  /*  366 */  "cmpFastLock",
  /*  367 */  "cmpFastUnlock",
  /*  368 */  "partialSubtypeCheckVsZero",
  /*  369 */  "tlsLoadP",
  /*  370 */  "vshiftcnt8B",
  /*  371 */  "vshiftcnt8B_0",
  /*  372 */  "vshiftcnt16B",
  /*  373 */  "vshiftcnt16B_0",
  /*  374 */  "loadB",
  /*  375 */  "loadB2L",
  /*  376 */  "loadUB",
  /*  377 */  "loadUB2L",
  /*  378 */  "loadS",
  /*  379 */  "loadS2L",
  /*  380 */  "loadUS",
  /*  381 */  "loadUS2L",
  /*  382 */  "loadI",
  /*  383 */  "loadI2L",
  /*  384 */  "loadUI2L",
  /*  385 */  "loadL",
  /*  386 */  "loadRange",
  /*  387 */  "loadP",
  /*  388 */  "loadN",
  /*  389 */  "loadKlass",
  /*  390 */  "loadNKlass",
  /*  391 */  "loadF",
  /*  392 */  "loadD",
  /*  393 */  "storeimmCM0",
  /*  394 */  "storeimmCM0_ordered",
  /*  395 */  "storeB",
  /*  396 */  "storeimmB0",
  /*  397 */  "storeC",
  /*  398 */  "storeimmC0",
  /*  399 */  "storeI",
  /*  400 */  "storeimmI0",
  /*  401 */  "storeL",
  /*  402 */  "storeimmL0",
  /*  403 */  "storeP",
  /*  404 */  "storeimmP0",
  /*  405 */  "storeN",
  /*  406 */  "storeImmN0",
  /*  407 */  "storeF",
  /*  408 */  "storeD",
  /*  409 */  "storeNKlass",
  /*  410 */  "prefetchr",
  /*  411 */  "prefetchw",
  /*  412 */  "prefetchnta",
  /*  413 */  "loadB_volatile",
  /*  414 */  "loadB2L_volatile",
  /*  415 */  "loadUB_volatile",
  /*  416 */  "loadUB2L_volatile",
  /*  417 */  "loadS_volatile",
  /*  418 */  "loadUS_volatile",
  /*  419 */  "loadUS2L_volatile",
  /*  420 */  "loadS2L_volatile",
  /*  421 */  "loadI_volatile",
  /*  422 */  "loadUI2L_volatile",
  /*  423 */  "loadL_volatile",
  /*  424 */  "loadP_volatile",
  /*  425 */  "loadN_volatile",
  /*  426 */  "loadF_volatile",
  /*  427 */  "loadD_volatile",
  /*  428 */  "storeB_volatile",
  /*  429 */  "storeC_volatile",
  /*  430 */  "storeI_volatile",
  /*  431 */  "storeL_volatile",
  /*  432 */  "storeP_volatile",
  /*  433 */  "storeN_volatile",
  /*  434 */  "storeF_volatile",
  /*  435 */  "storeD_volatile",
  /*  436 */  "bytes_reverse_int",
  /*  437 */  "bytes_reverse_long",
  /*  438 */  "bytes_reverse_unsigned_short",
  /*  439 */  "bytes_reverse_short",
  /*  440 */  "popCountI",
  /*  441 */  "popCountI_mem",
  /*  442 */  "popCountL",
  /*  443 */  "popCountL_mem",
  /*  444 */  "load_fence",
  /*  445 */  "unnecessary_membar_acquire",
  /*  446 */  "membar_acquire",
  /*  447 */  "membar_acquire_lock",
  /*  448 */  "store_fence",
  /*  449 */  "unnecessary_membar_release",
  /*  450 */  "membar_release",
  /*  451 */  "membar_storestore",
  /*  452 */  "membar_release_lock",
  /*  453 */  "unnecessary_membar_volatile",
  /*  454 */  "membar_volatile",
  /*  455 */  "convP2I",
  /*  456 */  "convN2I",
  /*  457 */  "shenandoahRB",
  /*  458 */  "encodeHeapOop",
  /*  459 */  "encodeHeapOop_not_null",
  /*  460 */  "decodeHeapOop",
  /*  461 */  "decodeHeapOop_not_null",
  /*  462 */  "encodeKlass_not_null",
  /*  463 */  "decodeKlass_not_null",
  /*  464 */  "loadPLocked",
  /*  465 */  "compareAndSwapI",
  /*  466 */  "compareAndSwapL",
  /*  467 */  "compareAndSwapP",
  /*  468 */  "compareAndSwapP_shenandoah",
  /*  469 */  "compareAndSwapN",
  /*  470 */  "compareAndSwapN_shenandoah",
  /*  471 */  "compareAndSwapIAcq",
  /*  472 */  "compareAndSwapLAcq",
  /*  473 */  "compareAndSwapPAcq",
  /*  474 */  "compareAndSwapPAcq_shenandoah",
  /*  475 */  "compareAndSwapNAcq",
  /*  476 */  "compareAndSwapNAcq_shenandoah",
  /*  477 */  "get_and_setI",
  /*  478 */  "get_and_setL",
  /*  479 */  "get_and_setN",
  /*  480 */  "get_and_setP",
  /*  481 */  "get_and_addL",
  /*  482 */  "get_and_addL_no_res",
  /*  483 */  "get_and_addLi",
  /*  484 */  "get_and_addLi_no_res",
  /*  485 */  "get_and_addI",
  /*  486 */  "get_and_addI_no_res",
  /*  487 */  "get_and_addIi",
  /*  488 */  "get_and_addIi_no_res",
  /*  489 */  "cmovI_reg_reg",
  /*  490 */  "cmovUI_reg_reg",
  /*  491 */  "cmovI_zero_reg",
  /*  492 */  "cmovUI_zero_reg",
  /*  493 */  "cmovI_reg_zero",
  /*  494 */  "cmovUI_reg_zero",
  /*  495 */  "cmovI_reg_zero_one",
  /*  496 */  "cmovUI_reg_zero_one",
  /*  497 */  "cmovL_reg_reg",
  /*  498 */  "cmovUL_reg_reg",
  /*  499 */  "cmovL_reg_zero",
  /*  500 */  "cmovUL_reg_zero",
  /*  501 */  "cmovL_zero_reg",
  /*  502 */  "cmovUL_zero_reg",
  /*  503 */  "cmovP_reg_reg",
  /*  504 */  "cmovUP_reg_reg",
  /*  505 */  "cmovP_reg_zero",
  /*  506 */  "cmovUP_reg_zero",
  /*  507 */  "cmovP_zero_reg",
  /*  508 */  "cmovUP_zero_reg",
  /*  509 */  "cmovN_reg_reg",
  /*  510 */  "cmovUN_reg_reg",
  /*  511 */  "cmovN_reg_zero",
  /*  512 */  "cmovUN_reg_zero",
  /*  513 */  "cmovN_zero_reg",
  /*  514 */  "cmovUN_zero_reg",
  /*  515 */  "cmovF_reg",
  /*  516 */  "cmovUF_reg",
  /*  517 */  "cmovD_reg",
  /*  518 */  "cmovUD_reg",
  /*  519 */  "addI_reg_reg",
  /*  520 */  "addI_reg_imm",
  /*  521 */  "addI_reg_imm_i2l",
  /*  522 */  "addP_reg_reg",
  /*  523 */  "addP_reg_reg_ext",
  /*  524 */  "addP_reg_reg_lsl",
  /*  525 */  "addP_reg_reg_ext_shift",
  /*  526 */  "lshift_ext",
  /*  527 */  "addP_reg_imm",
  /*  528 */  "addL_reg_reg",
  /*  529 */  "addL_reg_imm",
  /*  530 */  "subI_reg_reg",
  /*  531 */  "subI_reg_imm",
  /*  532 */  "subL_reg_reg",
  /*  533 */  "subL_reg_imm",
  /*  534 */  "negI_reg",
  /*  535 */  "negL_reg",
  /*  536 */  "mulI",
  /*  537 */  "smulI",
  /*  538 */  "smulI_0",
  /*  539 */  "mulL",
  /*  540 */  "mulHiL_rReg",
  /*  541 */  "maddI",
  /*  542 */  "maddI_0",
  /*  543 */  "msubI",
  /*  544 */  "maddL",
  /*  545 */  "maddL_0",
  /*  546 */  "msubL",
  /*  547 */  "divI",
  /*  548 */  "signExtract",
  /*  549 */  "div2Round",
  /*  550 */  "div2Round_0",
  /*  551 */  "divL",
  /*  552 */  "signExtractL",
  /*  553 */  "div2RoundL",
  /*  554 */  "div2RoundL_0",
  /*  555 */  "modI",
  /*  556 */  "modL",
  /*  557 */  "lShiftI_reg_reg",
  /*  558 */  "lShiftI_reg_imm",
  /*  559 */  "urShiftI_reg_reg",
  /*  560 */  "urShiftI_reg_imm",
  /*  561 */  "rShiftI_reg_reg",
  /*  562 */  "rShiftI_reg_imm",
  /*  563 */  "lShiftL_reg_reg",
  /*  564 */  "lShiftL_reg_imm",
  /*  565 */  "urShiftL_reg_reg",
  /*  566 */  "urShiftL_reg_imm",
  /*  567 */  "urShiftP_reg_imm",
  /*  568 */  "rShiftL_reg_reg",
  /*  569 */  "rShiftL_reg_imm",
  /*  570 */  "regL_not_reg",
  /*  571 */  "regI_not_reg",
  /*  572 */  "AndI_reg_not_reg",
  /*  573 */  "AndI_reg_not_reg_0",
  /*  574 */  "AndL_reg_not_reg",
  /*  575 */  "AndL_reg_not_reg_0",
  /*  576 */  "OrI_reg_not_reg",
  /*  577 */  "OrI_reg_not_reg_0",
  /*  578 */  "OrL_reg_not_reg",
  /*  579 */  "OrL_reg_not_reg_0",
  /*  580 */  "XorI_reg_not_reg",
  /*  581 */  "XorI_reg_not_reg_0",
  /*  582 */  "XorL_reg_not_reg",
  /*  583 */  "XorL_reg_not_reg_0",
  /*  584 */  "AndI_reg_URShift_not_reg",
  /*  585 */  "AndI_reg_URShift_not_reg_0",
  /*  586 */  "AndL_reg_URShift_not_reg",
  /*  587 */  "AndL_reg_URShift_not_reg_0",
  /*  588 */  "AndI_reg_RShift_not_reg",
  /*  589 */  "AndI_reg_RShift_not_reg_0",
  /*  590 */  "AndL_reg_RShift_not_reg",
  /*  591 */  "AndL_reg_RShift_not_reg_0",
  /*  592 */  "AndI_reg_LShift_not_reg",
  /*  593 */  "AndI_reg_LShift_not_reg_0",
  /*  594 */  "AndL_reg_LShift_not_reg",
  /*  595 */  "AndL_reg_LShift_not_reg_0",
  /*  596 */  "XorI_reg_URShift_not_reg",
  /*  597 */  "XorI_reg_URShift_not_reg_1",
  /*  598 */  "XorI_reg_URShift_not_reg_0",
  /*  599 */  "XorI_reg_URShift_not_reg_2",
  /*  600 */  "XorL_reg_URShift_not_reg",
  /*  601 */  "XorL_reg_URShift_not_reg_1",
  /*  602 */  "XorL_reg_URShift_not_reg_0",
  /*  603 */  "XorL_reg_URShift_not_reg_2",
  /*  604 */  "XorI_reg_RShift_not_reg",
  /*  605 */  "XorI_reg_RShift_not_reg_1",
  /*  606 */  "XorI_reg_RShift_not_reg_0",
  /*  607 */  "XorI_reg_RShift_not_reg_2",
  /*  608 */  "XorL_reg_RShift_not_reg",
  /*  609 */  "XorL_reg_RShift_not_reg_1",
  /*  610 */  "XorL_reg_RShift_not_reg_0",
  /*  611 */  "XorL_reg_RShift_not_reg_2",
  /*  612 */  "XorI_reg_LShift_not_reg",
  /*  613 */  "XorI_reg_LShift_not_reg_1",
  /*  614 */  "XorI_reg_LShift_not_reg_0",
  /*  615 */  "XorI_reg_LShift_not_reg_2",
  /*  616 */  "XorL_reg_LShift_not_reg",
  /*  617 */  "XorL_reg_LShift_not_reg_1",
  /*  618 */  "XorL_reg_LShift_not_reg_0",
  /*  619 */  "XorL_reg_LShift_not_reg_2",
  /*  620 */  "OrI_reg_URShift_not_reg",
  /*  621 */  "OrI_reg_URShift_not_reg_0",
  /*  622 */  "OrL_reg_URShift_not_reg",
  /*  623 */  "OrL_reg_URShift_not_reg_0",
  /*  624 */  "OrI_reg_RShift_not_reg",
  /*  625 */  "OrI_reg_RShift_not_reg_0",
  /*  626 */  "OrL_reg_RShift_not_reg",
  /*  627 */  "OrL_reg_RShift_not_reg_0",
  /*  628 */  "OrI_reg_LShift_not_reg",
  /*  629 */  "OrI_reg_LShift_not_reg_0",
  /*  630 */  "OrL_reg_LShift_not_reg",
  /*  631 */  "OrL_reg_LShift_not_reg_0",
  /*  632 */  "AndI_reg_URShift_reg",
  /*  633 */  "AndI_reg_URShift_reg_0",
  /*  634 */  "AndL_reg_URShift_reg",
  /*  635 */  "AndL_reg_URShift_reg_0",
  /*  636 */  "AndI_reg_RShift_reg",
  /*  637 */  "AndI_reg_RShift_reg_0",
  /*  638 */  "AndL_reg_RShift_reg",
  /*  639 */  "AndL_reg_RShift_reg_0",
  /*  640 */  "AndI_reg_LShift_reg",
  /*  641 */  "AndI_reg_LShift_reg_0",
  /*  642 */  "AndL_reg_LShift_reg",
  /*  643 */  "AndL_reg_LShift_reg_0",
  /*  644 */  "XorI_reg_URShift_reg",
  /*  645 */  "XorI_reg_URShift_reg_0",
  /*  646 */  "XorL_reg_URShift_reg",
  /*  647 */  "XorL_reg_URShift_reg_0",
  /*  648 */  "XorI_reg_RShift_reg",
  /*  649 */  "XorI_reg_RShift_reg_0",
  /*  650 */  "XorL_reg_RShift_reg",
  /*  651 */  "XorL_reg_RShift_reg_0",
  /*  652 */  "XorI_reg_LShift_reg",
  /*  653 */  "XorI_reg_LShift_reg_0",
  /*  654 */  "XorL_reg_LShift_reg",
  /*  655 */  "XorL_reg_LShift_reg_0",
  /*  656 */  "OrI_reg_URShift_reg",
  /*  657 */  "OrI_reg_URShift_reg_0",
  /*  658 */  "OrL_reg_URShift_reg",
  /*  659 */  "OrL_reg_URShift_reg_0",
  /*  660 */  "OrI_reg_RShift_reg",
  /*  661 */  "OrI_reg_RShift_reg_0",
  /*  662 */  "OrL_reg_RShift_reg",
  /*  663 */  "OrL_reg_RShift_reg_0",
  /*  664 */  "OrI_reg_LShift_reg",
  /*  665 */  "OrI_reg_LShift_reg_0",
  /*  666 */  "OrL_reg_LShift_reg",
  /*  667 */  "OrL_reg_LShift_reg_0",
  /*  668 */  "AddI_reg_URShift_reg",
  /*  669 */  "AddI_reg_URShift_reg_0",
  /*  670 */  "AddL_reg_URShift_reg",
  /*  671 */  "AddL_reg_URShift_reg_0",
  /*  672 */  "AddI_reg_RShift_reg",
  /*  673 */  "AddI_reg_RShift_reg_0",
  /*  674 */  "AddL_reg_RShift_reg",
  /*  675 */  "AddL_reg_RShift_reg_0",
  /*  676 */  "AddI_reg_LShift_reg",
  /*  677 */  "AddI_reg_LShift_reg_0",
  /*  678 */  "AddL_reg_LShift_reg",
  /*  679 */  "AddL_reg_LShift_reg_0",
  /*  680 */  "SubI_reg_URShift_reg",
  /*  681 */  "SubL_reg_URShift_reg",
  /*  682 */  "SubI_reg_RShift_reg",
  /*  683 */  "SubL_reg_RShift_reg",
  /*  684 */  "SubI_reg_LShift_reg",
  /*  685 */  "SubL_reg_LShift_reg",
  /*  686 */  "sbfmL",
  /*  687 */  "sbfmwI",
  /*  688 */  "ubfmL",
  /*  689 */  "ubfmwI",
  /*  690 */  "ubfxwI",
  /*  691 */  "ubfxL",
  /*  692 */  "ubfxIConvI2L",
  /*  693 */  "extrOrL",
  /*  694 */  "extrOrL_0",
  /*  695 */  "extrOrI",
  /*  696 */  "extrOrI_0",
  /*  697 */  "extrAddL",
  /*  698 */  "extrAddL_0",
  /*  699 */  "extrAddI",
  /*  700 */  "extrAddI_0",
  /*  701 */  "rolL_rReg",
  /*  702 */  "rolI_rReg",
  /*  703 */  "rolL_rReg_Var_C_64",
  /*  704 */  "rolL_rReg_Var_C_64_0",
  /*  705 */  "rolL_rReg_Var_C0",
  /*  706 */  "rolL_rReg_Var_C0_0",
  /*  707 */  "rolI_rReg_Var_C_32",
  /*  708 */  "rolI_rReg_Var_C_32_0",
  /*  709 */  "rolI_rReg_Var_C0",
  /*  710 */  "rolI_rReg_Var_C0_0",
  /*  711 */  "rorL_rReg",
  /*  712 */  "rorI_rReg",
  /*  713 */  "rorL_rReg_Var_C_64",
  /*  714 */  "rorL_rReg_Var_C_64_0",
  /*  715 */  "rorL_rReg_Var_C0",
  /*  716 */  "rorL_rReg_Var_C0_0",
  /*  717 */  "rorI_rReg_Var_C_32",
  /*  718 */  "rorI_rReg_Var_C_32_0",
  /*  719 */  "rorI_rReg_Var_C0",
  /*  720 */  "rorI_rReg_Var_C0_0",
  /*  721 */  "AddExtI",
  /*  722 */  "AddExtI_0",
  /*  723 */  "SubExtI",
  /*  724 */  "AddExtI_sxth",
  /*  725 */  "AddExtI_sxth_0",
  /*  726 */  "AddExtI_sxtb",
  /*  727 */  "AddExtI_sxtb_0",
  /*  728 */  "AddExtI_uxtb",
  /*  729 */  "AddExtI_uxtb_0",
  /*  730 */  "AddExtL_sxth",
  /*  731 */  "AddExtL_sxth_0",
  /*  732 */  "AddExtL_sxtw",
  /*  733 */  "AddExtL_sxtw_0",
  /*  734 */  "AddExtL_sxtb",
  /*  735 */  "AddExtL_sxtb_0",
  /*  736 */  "AddExtL_uxtb",
  /*  737 */  "AddExtL_uxtb_0",
  /*  738 */  "AddExtI_uxtb_and",
  /*  739 */  "AddExtI_uxtb_and_0",
  /*  740 */  "AddExtI_uxth_and",
  /*  741 */  "AddExtI_uxth_and_0",
  /*  742 */  "AddExtL_uxtb_and",
  /*  743 */  "AddExtL_uxtb_and_0",
  /*  744 */  "AddExtL_uxth_and",
  /*  745 */  "AddExtL_uxth_and_0",
  /*  746 */  "AddExtL_uxtw_and",
  /*  747 */  "AddExtL_uxtw_and_0",
  /*  748 */  "SubExtI_uxtb_and",
  /*  749 */  "SubExtI_uxth_and",
  /*  750 */  "SubExtL_uxtb_and",
  /*  751 */  "SubExtL_uxth_and",
  /*  752 */  "SubExtL_uxtw_and",
  /*  753 */  "addF_reg_reg",
  /*  754 */  "addD_reg_reg",
  /*  755 */  "subF_reg_reg",
  /*  756 */  "subD_reg_reg",
  /*  757 */  "mulF_reg_reg",
  /*  758 */  "mulD_reg_reg",
  /*  759 */  "divF_reg_reg",
  /*  760 */  "divD_reg_reg",
  /*  761 */  "sqrtD_reg",
  /*  762 */  "sqrtF_reg",
  /*  763 */  "andI_reg_reg",
  /*  764 */  "andI_reg_imm",
  /*  765 */  "orI_reg_reg",
  /*  766 */  "orI_reg_imm",
  /*  767 */  "xorI_reg_reg",
  /*  768 */  "xorI_reg_imm",
  /*  769 */  "andL_reg_reg",
  /*  770 */  "andL_reg_imm",
  /*  771 */  "orL_reg_reg",
  /*  772 */  "orL_reg_imm",
  /*  773 */  "xorL_reg_reg",
  /*  774 */  "xorL_reg_imm",
  /*  775 */  "convI2L_reg_reg",
  /*  776 */  "convUI2L_reg_reg",
  /*  777 */  "convL2I_reg",
  /*  778 */  "convI2B",
  /*  779 */  "convP2B",
  /*  780 */  "convD2F_reg",
  /*  781 */  "convF2D_reg",
  /*  782 */  "convF2I_reg_reg",
  /*  783 */  "convF2L_reg_reg",
  /*  784 */  "convI2F_reg_reg",
  /*  785 */  "convL2F_reg_reg",
  /*  786 */  "convD2I_reg_reg",
  /*  787 */  "convD2L_reg_reg",
  /*  788 */  "convI2D_reg_reg",
  /*  789 */  "convL2D_reg_reg",
  /*  790 */  "MoveF2I_reg_stack",
  /*  791 */  "MoveI2F_reg_stack",
  /*  792 */  "MoveD2L_reg_stack",
  /*  793 */  "MoveL2D_reg_stack",
  /*  794 */  "clearArray_reg_reg",
  /*  795 */  "clearArray_imm_reg",
  /*  796 */  "overflowMulI_reg_branch",
  /*  797 */  "overflowMulL_reg_branch",
  /*  798 */  "compF3_reg_reg",
  /*  799 */  "compD3_reg_reg",
  /*  800 */  "compF3_reg_immF0",
  /*  801 */  "compD3_reg_immD0",
  /*  802 */  "cmpL3_reg_reg",
  /*  803 */  "cmpLTMask_reg_reg",
  /*  804 */  "cmpLTMask_reg_zero",
  /*  805 */  "minI_rReg",
  /*  806 */  "maxI_rReg",
  /*  807 */  "branch",
  /*  808 */  "branchCon",
  /*  809 */  "branchConU",
  /*  810 */  "cmpI_imm0_branch",
  /*  811 */  "cmpL_imm0_branch",
  /*  812 */  "cmpP_imm0_branch",
  /*  813 */  "cmpN_imm0_branch",
  /*  814 */  "cmpP_narrowOop_imm0_branch",
  /*  815 */  "cmpUI_imm0_branch",
  /*  816 */  "cmpUL_imm0_branch",
  /*  817 */  "cmpL_branch_sign",
  /*  818 */  "cmpI_branch_sign",
  /*  819 */  "cmpL_branch_bit",
  /*  820 */  "cmpI_branch_bit",
  /*  821 */  "far_cmpL_branch_sign",
  /*  822 */  "far_cmpI_branch_sign",
  /*  823 */  "far_cmpL_branch_bit",
  /*  824 */  "far_cmpI_branch_bit",
  /*  825 */  "branchLoopEnd",
  /*  826 */  "branchLoopEndU",
  /*  827 */  "safePoint",
  /*  828 */  "CallStaticJavaDirect",
  /*  829 */  "CallStaticJavaDirectHandle",
  /*  830 */  "CallDynamicJavaDirect",
  /*  831 */  "CallRuntimeDirect",
  /*  832 */  "CallLeafDirect",
  /*  833 */  "CallLeafNoFPDirect",
  /*  834 */  "TailCalljmpInd",
  /*  835 */  "TailjmpInd",
  /*  836 */  "CreateException",
  /*  837 */  "RethrowException",
  /*  838 */  "Ret",
  /*  839 */  "ShouldNotReachHere",
  /*  840 */  "partialSubtypeCheck",
  /*  841 */  "string_compare",
  /*  842 */  "string_indexof",
  /*  843 */  "string_indexof_con",
  /*  844 */  "string_equals",
  /*  845 */  "array_equals",
  /*  846 */  "encode_iso_array",
  /*  847 */  "loadV4",
  /*  848 */  "loadV8",
  /*  849 */  "loadV16",
  /*  850 */  "storeV4",
  /*  851 */  "storeV8",
  /*  852 */  "storeV16",
  /*  853 */  "replicate8B",
  /*  854 */  "replicate16B",
  /*  855 */  "replicate8B_imm",
  /*  856 */  "replicate16B_imm",
  /*  857 */  "replicate4S",
  /*  858 */  "replicate8S",
  /*  859 */  "replicate4S_imm",
  /*  860 */  "replicate8S_imm",
  /*  861 */  "replicate2I",
  /*  862 */  "replicate4I",
  /*  863 */  "replicate2I_imm",
  /*  864 */  "replicate4I_imm",
  /*  865 */  "replicate2L",
  /*  866 */  "replicate2L_zero",
  /*  867 */  "replicate2F",
  /*  868 */  "replicate4F",
  /*  869 */  "replicate2D",
  /*  870 */  "vadd8B",
  /*  871 */  "vadd16B",
  /*  872 */  "vadd4S",
  /*  873 */  "vadd8S",
  /*  874 */  "vadd2I",
  /*  875 */  "vadd4I",
  /*  876 */  "vadd2L",
  /*  877 */  "vadd2F",
  /*  878 */  "vadd4F",
  /*  879 */  "vadd2D",
  /*  880 */  "vsub8B",
  /*  881 */  "vsub16B",
  /*  882 */  "vsub4S",
  /*  883 */  "vsub8S",
  /*  884 */  "vsub2I",
  /*  885 */  "vsub4I",
  /*  886 */  "vsub2L",
  /*  887 */  "vsub2F",
  /*  888 */  "vsub4F",
  /*  889 */  "vsub2D",
  /*  890 */  "vmul4S",
  /*  891 */  "vmul8S",
  /*  892 */  "vmul2I",
  /*  893 */  "vmul4I",
  /*  894 */  "vmul2F",
  /*  895 */  "vmul4F",
  /*  896 */  "vmul2D",
  /*  897 */  "vmla4S",
  /*  898 */  "vmla8S",
  /*  899 */  "vmla2I",
  /*  900 */  "vmla4I",
  /*  901 */  "vmls4S",
  /*  902 */  "vmls8S",
  /*  903 */  "vmls2I",
  /*  904 */  "vmls4I",
  /*  905 */  "vdiv2F",
  /*  906 */  "vdiv4F",
  /*  907 */  "vdiv2D",
  /*  908 */  "vand8B",
  /*  909 */  "vand16B",
  /*  910 */  "vor8B",
  /*  911 */  "vor16B",
  /*  912 */  "vxor8B",
  /*  913 */  "vxor16B",
  /*  914 */  "vsll8B",
  /*  915 */  "vsll16B",
  /*  916 */  "vsra8B",
  /*  917 */  "vsra16B",
  /*  918 */  "vsrl8B",
  /*  919 */  "vsrl16B",
  /*  920 */  "vsll8B_imm",
  /*  921 */  "vsll16B_imm",
  /*  922 */  "vsra8B_imm",
  /*  923 */  "vsra16B_imm",
  /*  924 */  "vsrl8B_imm",
  /*  925 */  "vsrl16B_imm",
  /*  926 */  "vsll4S",
  /*  927 */  "vsll8S",
  /*  928 */  "vsra4S",
  /*  929 */  "vsra8S",
  /*  930 */  "vsrl4S",
  /*  931 */  "vsrl8S",
  /*  932 */  "vsll4S_imm",
  /*  933 */  "vsll8S_imm",
  /*  934 */  "vsra4S_imm",
  /*  935 */  "vsra8S_imm",
  /*  936 */  "vsrl4S_imm",
  /*  937 */  "vsrl8S_imm",
  /*  938 */  "vsll2I",
  /*  939 */  "vsll4I",
  /*  940 */  "vsra2I",
  /*  941 */  "vsra4I",
  /*  942 */  "vsrl2I",
  /*  943 */  "vsrl4I",
  /*  944 */  "vsll2I_imm",
  /*  945 */  "vsll4I_imm",
  /*  946 */  "vsra2I_imm",
  /*  947 */  "vsra4I_imm",
  /*  948 */  "vsrl2I_imm",
  /*  949 */  "vsrl4I_imm",
  /*  950 */  "vsll2L",
  /*  951 */  "vsra2L",
  /*  952 */  "vsrl2L",
  /*  953 */  "vsll2L_imm",
  /*  954 */  "vsra2L_imm",
  /*  955 */  "vsrl2L_imm",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  true,
  /*   44 */  true,
  /*   45 */  true,
  /*   46 */  true,
  /*   47 */  true,
  /*   48 */  true,
  /*   49 */  true,
  /*   50 */  true,
  /*   51 */  true,
  /*   52 */  true,
  /*   53 */  true,
  /*   54 */  true,
  /*   55 */  true,
  /*   56 */  true,
  /*   57 */  true,
  /*   58 */  true,
  /*   59 */  true,
  /*   60 */  true,
  /*   61 */  true,
  /*   62 */  true,
  /*   63 */  true,
  /*   64 */  true,
  /*   65 */  true,
  /*   66 */  true,
  /*   67 */  true,
  /*   68 */  false,
  /*   69 */  false,
  /*   70 */  false,
  /*   71 */  false,
  /*   72 */  false,
  /*   73 */  false,
  /*   74 */  false,
  /*   75 */  false,
  /*   76 */  false,
  /*   77 */  false,
  /*   78 */  false,
  /*   79 */  false,
  /*   80 */  false,
  /*   81 */  false,
  /*   82 */  false,
  /*   83 */  false,
  /*   84 */  false,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  false,
  /*   99 */  false,
  /*  100 */  false,
  /*  101 */  false,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  /*  106 */  false,
  /*  107 */  false,
  /*  108 */  false,
  /*  109 */  false,
  /*  110 */  false,
  /*  111 */  false,
  /*  112 */  false,
  /*  113 */  false,
  /*  114 */  false,
  /*  115 */  false,
  /*  116 */  false,
  /*  117 */  false,
  /*  118 */  false,
  /*  119 */  false,
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  true,
  /*  137 */  true,
  /*  138 */  false,
  // last operand
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  // last operand class
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  false,
  /*  173 */  false,
  /*  174 */  false,
  /*  175 */  false,
  /*  176 */  false,
  /*  177 */  false,
  /*  178 */  false,
  /*  179 */  false,
  /*  180 */  false,
  /*  181 */  false,
  /*  182 */  false,
  /*  183 */  false,
  /*  184 */  false,
  /*  185 */  false,
  /*  186 */  false,
  /*  187 */  false,
  /*  188 */  false,
  /*  189 */  false,
  /*  190 */  false,
  /*  191 */  false,
  /*  192 */  false,
  /*  193 */  false,
  /*  194 */  false,
  /*  195 */  false,
  /*  196 */  false,
  /*  197 */  false,
  /*  198 */  false,
  /*  199 */  false,
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  /*  207 */  false,
  /*  208 */  false,
  /*  209 */  false,
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  // last internally defined operand
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  /*  653 */  false,
  /*  654 */  false,
  /*  655 */  false,
  /*  656 */  false,
  /*  657 */  false,
  /*  658 */  false,
  /*  659 */  false,
  /*  660 */  false,
  /*  661 */  false,
  /*  662 */  false,
  /*  663 */  false,
  /*  664 */  false,
  /*  665 */  false,
  /*  666 */  false,
  /*  667 */  false,
  /*  668 */  false,
  /*  669 */  false,
  /*  670 */  false,
  /*  671 */  false,
  /*  672 */  false,
  /*  673 */  false,
  /*  674 */  false,
  /*  675 */  false,
  /*  676 */  false,
  /*  677 */  false,
  /*  678 */  false,
  /*  679 */  false,
  /*  680 */  false,
  /*  681 */  false,
  /*  682 */  false,
  /*  683 */  false,
  /*  684 */  false,
  /*  685 */  false,
  /*  686 */  false,
  /*  687 */  false,
  /*  688 */  false,
  /*  689 */  false,
  /*  690 */  false,
  /*  691 */  false,
  /*  692 */  false,
  /*  693 */  false,
  /*  694 */  false,
  /*  695 */  false,
  /*  696 */  false,
  /*  697 */  false,
  /*  698 */  false,
  /*  699 */  false,
  /*  700 */  false,
  /*  701 */  false,
  /*  702 */  false,
  /*  703 */  false,
  /*  704 */  false,
  /*  705 */  false,
  /*  706 */  false,
  /*  707 */  false,
  /*  708 */  false,
  /*  709 */  false,
  /*  710 */  false,
  /*  711 */  false,
  /*  712 */  false,
  /*  713 */  false,
  /*  714 */  false,
  /*  715 */  false,
  /*  716 */  false,
  /*  717 */  false,
  /*  718 */  false,
  /*  719 */  false,
  /*  720 */  false,
  /*  721 */  false,
  /*  722 */  false,
  /*  723 */  false,
  /*  724 */  false,
  /*  725 */  false,
  /*  726 */  false,
  /*  727 */  false,
  /*  728 */  false,
  /*  729 */  false,
  /*  730 */  false,
  /*  731 */  false,
  /*  732 */  false,
  /*  733 */  false,
  /*  734 */  false,
  /*  735 */  false,
  /*  736 */  false,
  /*  737 */  false,
  /*  738 */  false,
  /*  739 */  false,
  /*  740 */  false,
  /*  741 */  false,
  /*  742 */  false,
  /*  743 */  false,
  /*  744 */  false,
  /*  745 */  false,
  /*  746 */  false,
  /*  747 */  false,
  /*  748 */  false,
  /*  749 */  false,
  /*  750 */  false,
  /*  751 */  false,
  /*  752 */  false,
  /*  753 */  false,
  /*  754 */  false,
  /*  755 */  false,
  /*  756 */  false,
  /*  757 */  false,
  /*  758 */  false,
  /*  759 */  false,
  /*  760 */  false,
  /*  761 */  false,
  /*  762 */  false,
  /*  763 */  false,
  /*  764 */  false,
  /*  765 */  false,
  /*  766 */  false,
  /*  767 */  false,
  /*  768 */  false,
  /*  769 */  false,
  /*  770 */  false,
  /*  771 */  false,
  /*  772 */  false,
  /*  773 */  false,
  /*  774 */  false,
  /*  775 */  false,
  /*  776 */  false,
  /*  777 */  false,
  /*  778 */  false,
  /*  779 */  false,
  /*  780 */  false,
  /*  781 */  false,
  /*  782 */  false,
  /*  783 */  false,
  /*  784 */  false,
  /*  785 */  false,
  /*  786 */  false,
  /*  787 */  false,
  /*  788 */  false,
  /*  789 */  false,
  /*  790 */  false,
  /*  791 */  false,
  /*  792 */  false,
  /*  793 */  false,
  /*  794 */  false,
  /*  795 */  false,
  /*  796 */  false,
  /*  797 */  false,
  /*  798 */  false,
  /*  799 */  false,
  /*  800 */  false,
  /*  801 */  false,
  /*  802 */  false,
  /*  803 */  false,
  /*  804 */  false,
  /*  805 */  false,
  /*  806 */  false,
  /*  807 */  false,
  /*  808 */  false,
  /*  809 */  false,
  /*  810 */  false,
  /*  811 */  false,
  /*  812 */  false,
  /*  813 */  false,
  /*  814 */  false,
  /*  815 */  false,
  /*  816 */  false,
  /*  817 */  false,
  /*  818 */  false,
  /*  819 */  false,
  /*  820 */  false,
  /*  821 */  false,
  /*  822 */  false,
  /*  823 */  false,
  /*  824 */  false,
  /*  825 */  false,
  /*  826 */  false,
  /*  827 */  false,
  /*  828 */  false,
  /*  829 */  false,
  /*  830 */  false,
  /*  831 */  false,
  /*  832 */  false,
  /*  833 */  false,
  /*  834 */  false,
  /*  835 */  false,
  /*  836 */  false,
  /*  837 */  false,
  /*  838 */  false,
  /*  839 */  false,
  /*  840 */  false,
  /*  841 */  false,
  /*  842 */  false,
  /*  843 */  false,
  /*  844 */  false,
  /*  845 */  false,
  /*  846 */  false,
  /*  847 */  false,
  /*  848 */  false,
  /*  849 */  false,
  /*  850 */  false,
  /*  851 */  false,
  /*  852 */  false,
  /*  853 */  false,
  /*  854 */  false,
  /*  855 */  false,
  /*  856 */  false,
  /*  857 */  false,
  /*  858 */  false,
  /*  859 */  false,
  /*  860 */  false,
  /*  861 */  false,
  /*  862 */  false,
  /*  863 */  false,
  /*  864 */  false,
  /*  865 */  false,
  /*  866 */  false,
  /*  867 */  false,
  /*  868 */  false,
  /*  869 */  false,
  /*  870 */  false,
  /*  871 */  false,
  /*  872 */  false,
  /*  873 */  false,
  /*  874 */  false,
  /*  875 */  false,
  /*  876 */  false,
  /*  877 */  false,
  /*  878 */  false,
  /*  879 */  false,
  /*  880 */  false,
  /*  881 */  false,
  /*  882 */  false,
  /*  883 */  false,
  /*  884 */  false,
  /*  885 */  false,
  /*  886 */  false,
  /*  887 */  false,
  /*  888 */  false,
  /*  889 */  false,
  /*  890 */  false,
  /*  891 */  false,
  /*  892 */  false,
  /*  893 */  false,
  /*  894 */  false,
  /*  895 */  false,
  /*  896 */  false,
  /*  897 */  false,
  /*  898 */  false,
  /*  899 */  false,
  /*  900 */  false,
  /*  901 */  false,
  /*  902 */  false,
  /*  903 */  false,
  /*  904 */  false,
  /*  905 */  false,
  /*  906 */  false,
  /*  907 */  false,
  /*  908 */  false,
  /*  909 */  false,
  /*  910 */  false,
  /*  911 */  false,
  /*  912 */  false,
  /*  913 */  false,
  /*  914 */  false,
  /*  915 */  false,
  /*  916 */  false,
  /*  917 */  false,
  /*  918 */  false,
  /*  919 */  false,
  /*  920 */  false,
  /*  921 */  false,
  /*  922 */  false,
  /*  923 */  false,
  /*  924 */  false,
  /*  925 */  false,
  /*  926 */  false,
  /*  927 */  false,
  /*  928 */  false,
  /*  929 */  false,
  /*  930 */  false,
  /*  931 */  false,
  /*  932 */  false,
  /*  933 */  false,
  /*  934 */  false,
  /*  935 */  false,
  /*  936 */  false,
  /*  937 */  false,
  /*  938 */  false,
  /*  939 */  false,
  /*  940 */  false,
  /*  941 */  false,
  /*  942 */  false,
  /*  943 */  false,
  /*  944 */  false,
  /*  945 */  false,
  /*  946 */  false,
  /*  947 */  false,
  /*  948 */  false,
  /*  949 */  false,
  /*  950 */  false,
  /*  951 */  false,
  /*  952 */  false,
  /*  953 */  false,
  /*  954 */  false,
  /*  955 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // RegFlags: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // _last_machine_leaf: 13
  0, // AbsD: 14
  0, // AbsF: 15
  0, // AbsI: 16
  0, // AddD: 17
  0, // AddF: 18
  0, // AddI: 19
  0, // AddL: 20
  0, // AddP: 21
  0, // Allocate: 22
  0, // AllocateArray: 23
  0, // AndI: 24
  0, // AndL: 25
  0, // AryEq: 26
  0, // AtanD: 27
  1, // Binary: 28
  1, // Bool: 29
  0, // BoxLock: 30
  0, // ReverseBytesI: 31
  0, // ReverseBytesL: 32
  0, // ReverseBytesUS: 33
  0, // ReverseBytesS: 34
  0, // CProj: 35
  0, // CallDynamicJava: 36
  0, // CallJava: 37
  0, // CallLeaf: 38
  0, // CallLeafNoFP: 39
  0, // CallRuntime: 40
  0, // CallStaticJava: 41
  0, // CastII: 42
  0, // CastX2P: 43
  0, // CastP2X: 44
  0, // CastPP: 45
  0, // Catch: 46
  0, // CatchProj: 47
  0, // CheckCastPP: 48
  0, // ClearArray: 49
  0, // ConstraintCast: 50
  0, // CMoveD: 51
  0, // CMoveF: 52
  0, // CMoveI: 53
  0, // CMoveL: 54
  0, // CMoveP: 55
  0, // CMoveN: 56
  1, // CmpN: 57
  1, // CmpD: 58
  0, // CmpD3: 59
  1, // CmpF: 60
  0, // CmpF3: 61
  1, // CmpI: 62
  1, // CmpL: 63
  0, // CmpL3: 64
  0, // CmpLTMask: 65
  1, // CmpP: 66
  1, // CmpU: 67
  1, // CmpUL: 68
  0, // CompareAndSwapI: 69
  0, // CompareAndSwapL: 70
  0, // CompareAndSwapP: 71
  0, // CompareAndSwapN: 72
  0, // GetAndAddI: 73
  0, // GetAndAddL: 74
  0, // GetAndSetI: 75
  0, // GetAndSetL: 76
  0, // GetAndSetP: 77
  0, // GetAndSetN: 78
  0, // Con: 79
  0, // ConN: 80
  0, // ConNKlass: 81
  0, // ConD: 82
  0, // ConF: 83
  0, // ConI: 84
  0, // ConL: 85
  0, // ConP: 86
  0, // Conv2B: 87
  0, // ConvD2F: 88
  0, // ConvD2I: 89
  0, // ConvD2L: 90
  0, // ConvF2D: 91
  0, // ConvF2I: 92
  0, // ConvF2L: 93
  0, // ConvI2D: 94
  0, // ConvI2F: 95
  0, // ConvI2L: 96
  0, // ConvL2D: 97
  0, // ConvL2F: 98
  0, // ConvL2I: 99
  0, // CosD: 100
  0, // CountedLoop: 101
  0, // CountedLoopEnd: 102
  0, // CountLeadingZerosI: 103
  0, // CountLeadingZerosL: 104
  0, // CountTrailingZerosI: 105
  0, // CountTrailingZerosL: 106
  0, // CreateEx: 107
  0, // DecodeN: 108
  0, // DecodeNKlass: 109
  0, // DivD: 110
  0, // DivF: 111
  0, // DivI: 112
  0, // DivL: 113
  0, // DivMod: 114
  0, // DivModI: 115
  0, // DivModL: 116
  0, // EncodeISOArray: 117
  0, // EncodeP: 118
  0, // EncodePKlass: 119
  0, // ExpD: 120
  1, // FastLock: 121
  1, // FastUnlock: 122
  0, // Goto: 123
  0, // Halt: 124
  0, // If: 125
  0, // IfFalse: 126
  0, // IfTrue: 127
  0, // Initialize: 128
  0, // JProj: 129
  0, // Jump: 130
  0, // JumpProj: 131
  0, // LShiftI: 132
  0, // LShiftL: 133
  0, // LoadB: 134
  0, // LoadUB: 135
  0, // LoadUS: 136
  0, // LoadD: 137
  0, // LoadD_unaligned: 138
  0, // LoadF: 139
  0, // LoadI: 140
  0, // LoadKlass: 141
  0, // LoadNKlass: 142
  0, // LoadL: 143
  0, // LoadL_unaligned: 144
  0, // LoadPLocked: 145
  0, // LoadP: 146
  0, // LoadN: 147
  0, // LoadRange: 148
  0, // LoadS: 149
  0, // Lock: 150
  0, // LogD: 151
  0, // Log10D: 152
  0, // Loop: 153
  0, // LoopLimit: 154
  0, // Mach: 155
  0, // MachProj: 156
  0, // MaxI: 157
  0, // MemBarAcquire: 158
  0, // LoadFence: 159
  0, // MemBarAcquireLock: 160
  0, // MemBarCPUOrder: 161
  0, // MemBarRelease: 162
  0, // StoreFence: 163
  0, // MemBarReleaseLock: 164
  0, // MemBarVolatile: 165
  0, // MemBarStoreStore: 166
  0, // MergeMem: 167
  0, // MinI: 168
  0, // ModD: 169
  0, // ModF: 170
  0, // ModI: 171
  0, // ModL: 172
  0, // MoveI2F: 173
  0, // MoveF2I: 174
  0, // MoveL2D: 175
  0, // MoveD2L: 176
  0, // MulD: 177
  0, // MulF: 178
  0, // MulHiL: 179
  0, // MulI: 180
  0, // MulL: 181
  0, // Multi: 182
  0, // NegD: 183
  0, // NegF: 184
  0, // NeverBranch: 185
  0, // Opaque1: 186
  0, // Opaque2: 187
  0, // Opaque3: 188
  0, // ProfileBoolean: 189
  0, // OrI: 190
  0, // OrL: 191
  1, // OverflowAddI: 192
  1, // OverflowSubI: 193
  1, // OverflowMulI: 194
  1, // OverflowAddL: 195
  1, // OverflowSubL: 196
  1, // OverflowMulL: 197
  0, // PCTable: 198
  0, // Parm: 199
  0, // PartialSubtypeCheck: 200
  0, // Phi: 201
  0, // PopCountI: 202
  0, // PopCountL: 203
  0, // PowD: 204
  0, // PrefetchAllocation: 205
  0, // PrefetchRead: 206
  0, // PrefetchWrite: 207
  0, // Proj: 208
  0, // RShiftI: 209
  0, // RShiftL: 210
  0, // Region: 211
  0, // Rethrow: 212
  0, // Return: 213
  0, // Root: 214
  0, // RoundDouble: 215
  0, // RoundFloat: 216
  0, // SafePoint: 217
  0, // SafePointScalarObject: 218
  0, // ShenandoahReadBarrier: 219
  0, // ShenandoahWriteBarrier: 220
  0, // ShenandoahWBMemProj: 221
  0, // SCMemProj: 222
  0, // SinD: 223
  0, // SqrtD: 224
  0, // Start: 225
  0, // StartOSR: 226
  0, // StoreB: 227
  0, // StoreC: 228
  0, // StoreCM: 229
  0, // StorePConditional: 230
  0, // StoreIConditional: 231
  0, // StoreLConditional: 232
  0, // StoreD: 233
  0, // StoreF: 234
  0, // StoreI: 235
  0, // StoreL: 236
  0, // StoreP: 237
  0, // StoreN: 238
  0, // StoreNKlass: 239
  0, // StrComp: 240
  0, // StrEquals: 241
  0, // StrIndexOf: 242
  0, // SubD: 243
  0, // SubF: 244
  0, // SubI: 245
  0, // SubL: 246
  0, // TailCall: 247
  0, // TailJump: 248
  0, // TanD: 249
  0, // ThreadLocal: 250
  0, // Unlock: 251
  0, // URShiftI: 252
  0, // URShiftL: 253
  0, // XorI: 254
  0, // XorL: 255
  0, // Vector: 256
  0, // AddVB: 257
  0, // AddVS: 258
  0, // AddVI: 259
  0, // AddVL: 260
  0, // AddVF: 261
  0, // AddVD: 262
  0, // SubVB: 263
  0, // SubVS: 264
  0, // SubVI: 265
  0, // SubVL: 266
  0, // SubVF: 267
  0, // SubVD: 268
  0, // MulVS: 269
  0, // MulVI: 270
  0, // MulVF: 271
  0, // MulVD: 272
  0, // DivVF: 273
  0, // DivVD: 274
  0, // LShiftCntV: 275
  0, // RShiftCntV: 276
  0, // LShiftVB: 277
  0, // LShiftVS: 278
  0, // LShiftVI: 279
  0, // LShiftVL: 280
  0, // RShiftVB: 281
  0, // RShiftVS: 282
  0, // RShiftVI: 283
  0, // RShiftVL: 284
  0, // URShiftVB: 285
  0, // URShiftVS: 286
  0, // URShiftVI: 287
  0, // URShiftVL: 288
  0, // AndV: 289
  0, // OrV: 290
  0, // XorV: 291
  0, // LoadVector: 292
  0, // StoreVector: 293
  0, // Pack: 294
  0, // PackB: 295
  0, // PackS: 296
  0, // PackI: 297
  0, // PackL: 298
  0, // PackF: 299
  0, // PackD: 300
  0, // Pack2L: 301
  0, // Pack2D: 302
  0, // ReplicateB: 303
  0, // ReplicateS: 304
  0, // ReplicateI: 305
  0, // ReplicateL: 306
  0, // ReplicateF: 307
  0, // ReplicateD: 308
  0, // Extract: 309
  0, // ExtractB: 310
  0, // ExtractUB: 311
  0, // ExtractC: 312
  0, // ExtractS: 313
  0, // ExtractI: 314
  0, // ExtractL: 315
  0, // ExtractF: 316
  0 // no trailing comma // ExtractD: 317
};
//  The following instructions can cisc-spill



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "R10",
  "R10_H",
  "R11",
  "R11_H",
  "R12",
  "R12_H",
  "R13",
  "R13_H",
  "R14",
  "R14_H",
  "R15",
  "R15_H",
  "R16",
  "R16_H",
  "R17",
  "R17_H",
  "R18",
  "R18_H",
  "R0",
  "R0_H",
  "R1",
  "R1_H",
  "R2",
  "R2_H",
  "R3",
  "R3_H",
  "R4",
  "R4_H",
  "R5",
  "R5_H",
  "R6",
  "R6_H",
  "R7",
  "R7_H",
  "R19",
  "R19_H",
  "R20",
  "R20_H",
  "R21",
  "R21_H",
  "R22",
  "R22_H",
  "R23",
  "R23_H",
  "R24",
  "R24_H",
  "R25",
  "R25_H",
  "R26",
  "R26_H",
  "R27",
  "R27_H",
  "R28",
  "R28_H",
  "R29",
  "R29_H",
  "R30",
  "R30_H",
  "R31",
  "R31_H",
  "V16",
  "V16_H",
  "V16_J",
  "V16_K",
  "V17",
  "V17_H",
  "V17_J",
  "V17_K",
  "V18",
  "V18_H",
  "V18_J",
  "V18_K",
  "V19",
  "V19_H",
  "V19_J",
  "V19_K",
  "V20",
  "V20_H",
  "V20_J",
  "V20_K",
  "V21",
  "V21_H",
  "V21_J",
  "V21_K",
  "V22",
  "V22_H",
  "V22_J",
  "V22_K",
  "V23",
  "V23_H",
  "V23_J",
  "V23_K",
  "V24",
  "V24_H",
  "V24_J",
  "V24_K",
  "V25",
  "V25_H",
  "V25_J",
  "V25_K",
  "V26",
  "V26_H",
  "V26_J",
  "V26_K",
  "V27",
  "V27_H",
  "V27_J",
  "V27_K",
  "V28",
  "V28_H",
  "V28_J",
  "V28_K",
  "V29",
  "V29_H",
  "V29_J",
  "V29_K",
  "V30",
  "V30_H",
  "V30_J",
  "V30_K",
  "V31",
  "V31_H",
  "V31_J",
  "V31_K",
  "V0",
  "V0_H",
  "V0_J",
  "V0_K",
  "V1",
  "V1_H",
  "V1_J",
  "V1_K",
  "V2",
  "V2_H",
  "V2_J",
  "V2_K",
  "V3",
  "V3_H",
  "V3_J",
  "V3_K",
  "V4",
  "V4_H",
  "V4_J",
  "V4_K",
  "V5",
  "V5_H",
  "V5_J",
  "V5_K",
  "V6",
  "V6_H",
  "V6_J",
  "V6_K",
  "V7",
  "V7_H",
  "V7_J",
  "V7_K",
  "V8",
  "V8_H",
  "V8_J",
  "V8_K",
  "V9",
  "V9_H",
  "V9_J",
  "V9_K",
  "V10",
  "V10_H",
  "V10_J",
  "V10_K",
  "V11",
  "V11_H",
  "V11_J",
  "V11_K",
  "V12",
  "V12_H",
  "V12_J",
  "V12_K",
  "V13",
  "V13_H",
  "V13_J",
  "V13_K",
  "V14",
  "V14_H",
  "V14_J",
  "V14_K",
  "V15",
  "V15_H",
  "V15_J",
  "V15_K",
  "RFLAGS" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	r10->as_VMReg()        ,
	r10->as_VMReg()->next(),
	r11->as_VMReg()        ,
	r11->as_VMReg()->next(),
	r12->as_VMReg()        ,
	r12->as_VMReg()->next(),
	r13->as_VMReg()        ,
	r13->as_VMReg()->next(),
	r14->as_VMReg()        ,
	r14->as_VMReg()->next(),
	r15->as_VMReg()        ,
	r15->as_VMReg()->next(),
	r16->as_VMReg()        ,
	r16->as_VMReg()->next(),
	r17->as_VMReg()        ,
	r17->as_VMReg()->next(),
	r18->as_VMReg()        ,
	r18->as_VMReg()->next(),
	r0->as_VMReg()         ,
	r0->as_VMReg()->next() ,
	r1->as_VMReg()         ,
	r1->as_VMReg()->next() ,
	r2->as_VMReg()         ,
	r2->as_VMReg()->next() ,
	r3->as_VMReg()         ,
	r3->as_VMReg()->next() ,
	r4->as_VMReg()         ,
	r4->as_VMReg()->next() ,
	r5->as_VMReg()         ,
	r5->as_VMReg()->next() ,
	r6->as_VMReg()         ,
	r6->as_VMReg()->next() ,
	r7->as_VMReg()         ,
	r7->as_VMReg()->next() ,
	r19->as_VMReg()        ,
	r19->as_VMReg()->next(),
	r20->as_VMReg()        ,
	r20->as_VMReg()->next(),
	r21->as_VMReg()        ,
	r21->as_VMReg()->next(),
	r22->as_VMReg()        ,
	r22->as_VMReg()->next(),
	r23->as_VMReg()        ,
	r23->as_VMReg()->next(),
	r24->as_VMReg()        ,
	r24->as_VMReg()->next(),
	r25->as_VMReg()        ,
	r25->as_VMReg()->next(),
	r26->as_VMReg()        ,
	r26->as_VMReg()->next(),
	r27->as_VMReg()        ,
	r27->as_VMReg()->next(),
	r28->as_VMReg()        ,
	r28->as_VMReg()->next(),
	r29->as_VMReg()        ,
	r29->as_VMReg()->next(),
	r30->as_VMReg()        ,
	r30->as_VMReg()->next(),
	r31_sp->as_VMReg()     ,
	r31_sp->as_VMReg()->next(),
	v16->as_VMReg()         ,
	v16->as_VMReg()->next() ,
	v16->as_VMReg()->next(2),
	v16->as_VMReg()->next(3),
	v17->as_VMReg()         ,
	v17->as_VMReg()->next() ,
	v17->as_VMReg()->next(2),
	v17->as_VMReg()->next(3),
	v18->as_VMReg()         ,
	v18->as_VMReg()->next() ,
	v18->as_VMReg()->next(2),
	v18->as_VMReg()->next(3),
	v19->as_VMReg()         ,
	v19->as_VMReg()->next() ,
	v19->as_VMReg()->next(2),
	v19->as_VMReg()->next(3),
	v20->as_VMReg()         ,
	v20->as_VMReg()->next() ,
	v20->as_VMReg()->next(2),
	v20->as_VMReg()->next(3),
	v21->as_VMReg()         ,
	v21->as_VMReg()->next() ,
	v21->as_VMReg()->next(2),
	v21->as_VMReg()->next(3),
	v22->as_VMReg()         ,
	v22->as_VMReg()->next() ,
	v22->as_VMReg()->next(2),
	v22->as_VMReg()->next(3),
	v23->as_VMReg()         ,
	v23->as_VMReg()->next() ,
	v23->as_VMReg()->next(2),
	v23->as_VMReg()->next(3),
	v24->as_VMReg()         ,
	v24->as_VMReg()->next() ,
	v24->as_VMReg()->next(2),
	v24->as_VMReg()->next(3),
	v25->as_VMReg()         ,
	v25->as_VMReg()->next() ,
	v25->as_VMReg()->next(2),
	v25->as_VMReg()->next(3),
	v26->as_VMReg()         ,
	v26->as_VMReg()->next() ,
	v26->as_VMReg()->next(2),
	v26->as_VMReg()->next(3),
	v27->as_VMReg()         ,
	v27->as_VMReg()->next() ,
	v27->as_VMReg()->next(2),
	v27->as_VMReg()->next(3),
	v28->as_VMReg()         ,
	v28->as_VMReg()->next() ,
	v28->as_VMReg()->next(2),
	v28->as_VMReg()->next(3),
	v29->as_VMReg()         ,
	v29->as_VMReg()->next() ,
	v29->as_VMReg()->next(2),
	v29->as_VMReg()->next(3),
	v30->as_VMReg()         ,
	v30->as_VMReg()->next() ,
	v30->as_VMReg()->next(2),
	v30->as_VMReg()->next(3),
	v31->as_VMReg()         ,
	v31->as_VMReg()->next() ,
	v31->as_VMReg()->next(2),
	v31->as_VMReg()->next(3),
	v0->as_VMReg()          ,
	v0->as_VMReg()->next()  ,
	v0->as_VMReg()->next(2) ,
	v0->as_VMReg()->next(3) ,
	v1->as_VMReg()          ,
	v1->as_VMReg()->next()  ,
	v1->as_VMReg()->next(2) ,
	v1->as_VMReg()->next(3) ,
	v2->as_VMReg()          ,
	v2->as_VMReg()->next()  ,
	v2->as_VMReg()->next(2) ,
	v2->as_VMReg()->next(3) ,
	v3->as_VMReg()          ,
	v3->as_VMReg()->next()  ,
	v3->as_VMReg()->next(2) ,
	v3->as_VMReg()->next(3) ,
	v4->as_VMReg()          ,
	v4->as_VMReg()->next()  ,
	v4->as_VMReg()->next(2) ,
	v4->as_VMReg()->next(3) ,
	v5->as_VMReg()          ,
	v5->as_VMReg()->next()  ,
	v5->as_VMReg()->next(2) ,
	v5->as_VMReg()->next(3) ,
	v6->as_VMReg()          ,
	v6->as_VMReg()->next()  ,
	v6->as_VMReg()->next(2) ,
	v6->as_VMReg()->next(3) ,
	v7->as_VMReg()          ,
	v7->as_VMReg()->next()  ,
	v7->as_VMReg()->next(2) ,
	v7->as_VMReg()->next(3) ,
	v8->as_VMReg()          ,
	v8->as_VMReg()->next()  ,
	v8->as_VMReg()->next(2) ,
	v8->as_VMReg()->next(3) ,
	v9->as_VMReg()          ,
	v9->as_VMReg()->next()  ,
	v9->as_VMReg()->next(2) ,
	v9->as_VMReg()->next(3) ,
	v10->as_VMReg()         ,
	v10->as_VMReg()->next() ,
	v10->as_VMReg()->next(2),
	v10->as_VMReg()->next(3),
	v11->as_VMReg()         ,
	v11->as_VMReg()->next() ,
	v11->as_VMReg()->next(2),
	v11->as_VMReg()->next(3),
	v12->as_VMReg()         ,
	v12->as_VMReg()->next() ,
	v12->as_VMReg()->next(2),
	v12->as_VMReg()->next(3),
	v13->as_VMReg()         ,
	v13->as_VMReg()->next() ,
	v13->as_VMReg()->next(2),
	v13->as_VMReg()->next(3),
	v14->as_VMReg()         ,
	v14->as_VMReg()->next() ,
	v14->as_VMReg()->next(2),
	v14->as_VMReg()->next(3),
	v15->as_VMReg()         ,
	v15->as_VMReg()->next() ,
	v15->as_VMReg()->next(2),
	v15->as_VMReg()->next(3),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\xA',  // R10
  (unsigned char)'\xA',  // R10_H
  (unsigned char)'\xB',  // R11
  (unsigned char)'\xB',  // R11_H
  (unsigned char)'\xC',  // R12
  (unsigned char)'\xC',  // R12_H
  (unsigned char)'\xD',  // R13
  (unsigned char)'\xD',  // R13_H
  (unsigned char)'\xE',  // R14
  (unsigned char)'\xE',  // R14_H
  (unsigned char)'\xF',  // R15
  (unsigned char)'\xF',  // R15_H
  (unsigned char)'\x10',  // R16
  (unsigned char)'\x10',  // R16_H
  (unsigned char)'\x11',  // R17
  (unsigned char)'\x11',  // R17_H
  (unsigned char)'\x12',  // R18
  (unsigned char)'\x12',  // R18_H
  (unsigned char)'\x0',  // R0
  (unsigned char)'\x0',  // R0_H
  (unsigned char)'\x1',  // R1
  (unsigned char)'\x1',  // R1_H
  (unsigned char)'\x2',  // R2
  (unsigned char)'\x2',  // R2_H
  (unsigned char)'\x3',  // R3
  (unsigned char)'\x3',  // R3_H
  (unsigned char)'\x4',  // R4
  (unsigned char)'\x4',  // R4_H
  (unsigned char)'\x5',  // R5
  (unsigned char)'\x5',  // R5_H
  (unsigned char)'\x6',  // R6
  (unsigned char)'\x6',  // R6_H
  (unsigned char)'\x7',  // R7
  (unsigned char)'\x7',  // R7_H
  (unsigned char)'\x13',  // R19
  (unsigned char)'\x13',  // R19_H
  (unsigned char)'\x14',  // R20
  (unsigned char)'\x14',  // R20_H
  (unsigned char)'\x15',  // R21
  (unsigned char)'\x15',  // R21_H
  (unsigned char)'\x16',  // R22
  (unsigned char)'\x16',  // R22_H
  (unsigned char)'\x17',  // R23
  (unsigned char)'\x17',  // R23_H
  (unsigned char)'\x18',  // R24
  (unsigned char)'\x18',  // R24_H
  (unsigned char)'\x19',  // R25
  (unsigned char)'\x19',  // R25_H
  (unsigned char)'\x1A',  // R26
  (unsigned char)'\x1A',  // R26_H
  (unsigned char)'\x1B',  // R27
  (unsigned char)'\x1B',  // R27_H
  (unsigned char)'\x1C',  // R28
  (unsigned char)'\x1C',  // R28_H
  (unsigned char)'\x1D',  // R29
  (unsigned char)'\x1D',  // R29_H
  (unsigned char)'\x1E',  // R30
  (unsigned char)'\x1E',  // R30_H
  (unsigned char)'\x1F',  // R31
  (unsigned char)'\x1F',  // R31_H
  (unsigned char)'\x10',  // V16
  (unsigned char)'\x10',  // V16_H
  (unsigned char)'\x10',  // V16_J
  (unsigned char)'\x10',  // V16_K
  (unsigned char)'\x11',  // V17
  (unsigned char)'\x11',  // V17_H
  (unsigned char)'\x11',  // V17_J
  (unsigned char)'\x11',  // V17_K
  (unsigned char)'\x12',  // V18
  (unsigned char)'\x12',  // V18_H
  (unsigned char)'\x12',  // V18_J
  (unsigned char)'\x12',  // V18_K
  (unsigned char)'\x13',  // V19
  (unsigned char)'\x13',  // V19_H
  (unsigned char)'\x13',  // V19_J
  (unsigned char)'\x13',  // V19_K
  (unsigned char)'\x14',  // V20
  (unsigned char)'\x14',  // V20_H
  (unsigned char)'\x14',  // V20_J
  (unsigned char)'\x14',  // V20_K
  (unsigned char)'\x15',  // V21
  (unsigned char)'\x15',  // V21_H
  (unsigned char)'\x15',  // V21_J
  (unsigned char)'\x15',  // V21_K
  (unsigned char)'\x16',  // V22
  (unsigned char)'\x16',  // V22_H
  (unsigned char)'\x16',  // V22_J
  (unsigned char)'\x16',  // V22_K
  (unsigned char)'\x17',  // V23
  (unsigned char)'\x17',  // V23_H
  (unsigned char)'\x17',  // V23_J
  (unsigned char)'\x17',  // V23_K
  (unsigned char)'\x18',  // V24
  (unsigned char)'\x18',  // V24_H
  (unsigned char)'\x18',  // V24_J
  (unsigned char)'\x18',  // V24_K
  (unsigned char)'\x19',  // V25
  (unsigned char)'\x19',  // V25_H
  (unsigned char)'\x19',  // V25_J
  (unsigned char)'\x19',  // V25_K
  (unsigned char)'\x1A',  // V26
  (unsigned char)'\x1A',  // V26_H
  (unsigned char)'\x1A',  // V26_J
  (unsigned char)'\x1A',  // V26_K
  (unsigned char)'\x1B',  // V27
  (unsigned char)'\x1B',  // V27_H
  (unsigned char)'\x1B',  // V27_J
  (unsigned char)'\x1B',  // V27_K
  (unsigned char)'\x1C',  // V28
  (unsigned char)'\x1C',  // V28_H
  (unsigned char)'\x1C',  // V28_J
  (unsigned char)'\x1C',  // V28_K
  (unsigned char)'\x1D',  // V29
  (unsigned char)'\x1D',  // V29_H
  (unsigned char)'\x1D',  // V29_J
  (unsigned char)'\x1D',  // V29_K
  (unsigned char)'\x1E',  // V30
  (unsigned char)'\x1E',  // V30_H
  (unsigned char)'\x1E',  // V30_J
  (unsigned char)'\x1E',  // V30_K
  (unsigned char)'\x1F',  // V31
  (unsigned char)'\x1F',  // V31_H
  (unsigned char)'\x1F',  // V31_J
  (unsigned char)'\x1F',  // V31_K
  (unsigned char)'\x0',  // V0
  (unsigned char)'\x0',  // V0_H
  (unsigned char)'\x0',  // V0_J
  (unsigned char)'\x0',  // V0_K
  (unsigned char)'\x1',  // V1
  (unsigned char)'\x1',  // V1_H
  (unsigned char)'\x1',  // V1_J
  (unsigned char)'\x1',  // V1_K
  (unsigned char)'\x2',  // V2
  (unsigned char)'\x2',  // V2_H
  (unsigned char)'\x2',  // V2_J
  (unsigned char)'\x2',  // V2_K
  (unsigned char)'\x3',  // V3
  (unsigned char)'\x3',  // V3_H
  (unsigned char)'\x3',  // V3_J
  (unsigned char)'\x3',  // V3_K
  (unsigned char)'\x4',  // V4
  (unsigned char)'\x4',  // V4_H
  (unsigned char)'\x4',  // V4_J
  (unsigned char)'\x4',  // V4_K
  (unsigned char)'\x5',  // V5
  (unsigned char)'\x5',  // V5_H
  (unsigned char)'\x5',  // V5_J
  (unsigned char)'\x5',  // V5_K
  (unsigned char)'\x6',  // V6
  (unsigned char)'\x6',  // V6_H
  (unsigned char)'\x6',  // V6_J
  (unsigned char)'\x6',  // V6_K
  (unsigned char)'\x7',  // V7
  (unsigned char)'\x7',  // V7_H
  (unsigned char)'\x7',  // V7_J
  (unsigned char)'\x7',  // V7_K
  (unsigned char)'\x8',  // V8
  (unsigned char)'\x8',  // V8_H
  (unsigned char)'\x8',  // V8_J
  (unsigned char)'\x8',  // V8_K
  (unsigned char)'\x9',  // V9
  (unsigned char)'\x9',  // V9_H
  (unsigned char)'\x9',  // V9_J
  (unsigned char)'\x9',  // V9_K
  (unsigned char)'\xA',  // V10
  (unsigned char)'\xA',  // V10_H
  (unsigned char)'\xA',  // V10_J
  (unsigned char)'\xA',  // V10_K
  (unsigned char)'\xB',  // V11
  (unsigned char)'\xB',  // V11_H
  (unsigned char)'\xB',  // V11_J
  (unsigned char)'\xB',  // V11_K
  (unsigned char)'\xC',  // V12
  (unsigned char)'\xC',  // V12_H
  (unsigned char)'\xC',  // V12_J
  (unsigned char)'\xC',  // V12_K
  (unsigned char)'\xD',  // V13
  (unsigned char)'\xD',  // V13_H
  (unsigned char)'\xD',  // V13_J
  (unsigned char)'\xD',  // V13_K
  (unsigned char)'\xE',  // V14
  (unsigned char)'\xE',  // V14_H
  (unsigned char)'\xE',  // V14_J
  (unsigned char)'\xE',  // V14_K
  (unsigned char)'\xF',  // V15
  (unsigned char)'\xF',  // V15_H
  (unsigned char)'\xF',  // V15_J
  (unsigned char)'\xF',  // V15_K
  (unsigned char)'\x20' // no trailing comma  // RFLAGS
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone(Compile* C) const {
  return  new (C) labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone(Compile* C) const {
  return  new (C) methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *iRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegINoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *iRegLNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG_mask();
}

const RegMask *iRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *iRegPNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_PTR_REG_mask();
}

const RegMask *iRegP_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegP_R1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R1_REG_mask();
}

const RegMask *iRegP_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegP_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegP_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R4_REG_mask();
}

const RegMask *iRegP_R5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R5_REG_mask();
}

const RegMask *iRegP_R10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R10_REG_mask();
}

const RegMask *iRegL_R11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R11_REG_mask();
}

const RegMask *iRegP_FPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_REG_mask();
}

const RegMask *iRegI_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R0_REG_mask();
}

const RegMask *iRegI_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R2_REG_mask();
}

const RegMask *iRegI_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R3_REG_mask();
}

const RegMask *iRegI_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R4_REG_mask();
}

const RegMask *iRegNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegNNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegIHeapbaseOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &HEAPBASE_REG_mask();
}

const RegMask *vRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLOAT_REG_mask();
}

const RegMask *vRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DOUBLE_REG_mask();
}

const RegMask *vecDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORD_REG_mask();
}

const RegMask *vecXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORX_REG_mask();
}

const RegMask *vRegD_V0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V0_REG_mask();
}

const RegMask *vRegD_V1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V1_REG_mask();
}

const RegMask *vRegD_V2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V2_REG_mask();
}

const RegMask *vRegD_V3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V3_REG_mask();
}

const RegMask *rFlagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *rFlagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *inline_cache_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &METHOD_REG_mask();
}

const RegMask *interpreter_method_oop_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &METHOD_REG_mask();
}

const RegMask *thread_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &THREAD_REG_mask();
}

const RegMask *lr_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LR_REG_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indIndexScaledOffsetIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledOffsetLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexOffsetI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledOffsetI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indirectNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledOffsetINOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledOffsetLNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexOffsetI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledOffsetI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffINOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indOffLNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *thread_anchor_pcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *iRegL2IOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

//------------------Define members for classes derived from MachNode----------
// Build short branch version of this instruction
MachNode *far_cmpL_branch_signNode::short_branch_version(Compile* C) {
  cmpL_branch_signNode *node = new (C) cmpL_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_signNode::short_branch_version(Compile* C) {
  cmpI_branch_signNode *node = new (C) cmpI_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpL_branch_bitNode::short_branch_version(Compile* C) {
  cmpL_branch_bitNode *node = new (C) cmpL_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_bitNode::short_branch_version(Compile* C) {
  cmpI_branch_bitNode *node = new (C) cmpI_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}


// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode( MachNode* node, Compile* C) const {
  // New node must use same node index
  node->set_idx( _idx );
  // Copy machine-independent inputs
  for( uint j = 0; j < req(); j++ ) {
    node->add_req(in(j));
  }
  // Copy my operands, except for cisc position
  int nopnds = num_opnds();
  assert( node->num_opnds() == (uint)nopnds, "Must have same number of operands");
  MachOper **to = node->_opnds;
  for( int i = 0; i < nopnds; i++ ) {
    if( i != cisc_operand() ) 
      to[i] = _opnds[i]->clone(C);
  }
}

void overflowMulI_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulI_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void overflowMulL_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulL_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpN_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpN_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_narrowOop_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_narrowOop_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallStaticJavaDirectHandleNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int loadBNode::reloc() const {
  return 1;
}

int loadB2LNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS2LNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadNNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadNKlassNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConP0Node::reloc() const {
  return 1;
}

int loadConP1Node::reloc() const {
  return 1;
}

int loadConPollPageNode::reloc() const {
  return 1;
}

int loadByteMapBaseNode::reloc() const {
  return 1;
}

int loadConF_packedNode::reloc() const {
  return 2;
}

int loadConFNode::reloc() const {
  return 2;
}

int loadConD_packedNode::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 2;
}

int storeimmCM0Node::reloc() const {
  return 2;
}

int storeimmCM0_orderedNode::reloc() const {
  return 2;
}

int storeBNode::reloc() const {
  return 3;
}

int storeimmB0Node::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 3;
}

int storeimmC0Node::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 3;
}

int storeimmI0Node::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storeimmL0Node::reloc() const {
  return 2;
}

int storePNode::reloc() const {
  return 2;
}

int storeimmP0Node::reloc() const {
  return 3;
}

int storeNNode::reloc() const {
  return 2;
}

int storeImmN0Node::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int storeDNode::reloc() const {
  return 2;
}

int storeNKlassNode::reloc() const {
  return 2;
}

int prefetchrNode::reloc() const {
  return 1;
}

int prefetchwNode::reloc() const {
  return 1;
}

int prefetchntaNode::reloc() const {
  return 1;
}

int storeB_volatileNode::reloc() const {
  return 1;
}

int storeC_volatileNode::reloc() const {
  return 1;
}

int storeI_volatileNode::reloc() const {
  return 1;
}

int bytes_reverse_intNode::reloc() const {
  return 1;
}

int bytes_reverse_unsigned_shortNode::reloc() const {
  return 1;
}

int bytes_reverse_shortNode::reloc() const {
  return 1;
}

int countLeadingZerosINode::reloc() const {
  return 1;
}

int countTrailingZerosINode::reloc() const {
  return 1;
}

int popCountINode::reloc() const {
  return 1;
}

int popCountI_memNode::reloc() const {
  return 1;
}

int popCountL_memNode::reloc() const {
  return 1;
}

int storePConditionalNode::reloc() const {
  return 1;
}

int get_and_addINode::reloc() const {
  return 1;
}

int get_and_addI_no_resNode::reloc() const {
  return 1;
}

int cmovI_reg_regNode::reloc() const {
  return 2;
}

int cmovUI_reg_regNode::reloc() const {
  return 2;
}

int cmovI_zero_regNode::reloc() const {
  return 1;
}

int cmovUI_zero_regNode::reloc() const {
  return 1;
}

int cmovI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_zero_regNode::reloc() const {
  return 1;
}

int cmovUP_zero_regNode::reloc() const {
  return 1;
}

int addI_reg_regNode::reloc() const {
  return 2;
}

int addI_reg_immNode::reloc() const {
  return 1;
}

int addP_reg_reg_extNode::reloc() const {
  return 1;
}

int addP_reg_reg_ext_shiftNode::reloc() const {
  return 1;
}

int lshift_extNode::reloc() const {
  return 1;
}

int subI_reg_regNode::reloc() const {
  return 2;
}

int subI_reg_immNode::reloc() const {
  return 1;
}

int negI_regNode::reloc() const {
  return 1;
}

int negL_regNode::reloc() const {
  return 1;
}

int mulINode::reloc() const {
  return 2;
}

int smulINode::reloc() const {
  return 2;
}

int smulI_0Node::reloc() const {
  return 2;
}

int maddINode::reloc() const {
  return 3;
}

int maddI_0Node::reloc() const {
  return 3;
}

int msubINode::reloc() const {
  return 3;
}

int divINode::reloc() const {
  return 2;
}

int signExtractNode::reloc() const {
  return 1;
}

int div2RoundNode::reloc() const {
  return 2;
}

int div2Round_0Node::reloc() const {
  return 2;
}

int modINode::reloc() const {
  return 2;
}

int lShiftI_reg_regNode::reloc() const {
  return 2;
}

int lShiftI_reg_immNode::reloc() const {
  return 1;
}

int urShiftI_reg_regNode::reloc() const {
  return 2;
}

int urShiftI_reg_immNode::reloc() const {
  return 1;
}

int rShiftI_reg_regNode::reloc() const {
  return 2;
}

int rShiftI_reg_immNode::reloc() const {
  return 1;
}

int lShiftL_reg_regNode::reloc() const {
  return 1;
}

int urShiftL_reg_regNode::reloc() const {
  return 1;
}

int rShiftL_reg_regNode::reloc() const {
  return 1;
}

int regI_not_regNode::reloc() const {
  return 1;
}

int AndI_reg_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_2Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int SubI_reg_URShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_RShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_LShift_regNode::reloc() const {
  return 2;
}

int sbfmwINode::reloc() const {
  return 1;
}

int ubfmwINode::reloc() const {
  return 1;
}

int ubfxwINode::reloc() const {
  return 1;
}

int ubfxIConvI2LNode::reloc() const {
  return 1;
}

int extrOrINode::reloc() const {
  return 2;
}

int extrOrI_0Node::reloc() const {
  return 2;
}

int extrAddINode::reloc() const {
  return 2;
}

int extrAddI_0Node::reloc() const {
  return 2;
}

int AddExtINode::reloc() const {
  return 1;
}

int AddExtI_0Node::reloc() const {
  return 1;
}

int SubExtINode::reloc() const {
  return 1;
}

int AddExtI_sxthNode::reloc() const {
  return 2;
}

int AddExtI_sxth_0Node::reloc() const {
  return 2;
}

int AddExtI_sxtbNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtbNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtb_andNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_andNode::reloc() const {
  return 2;
}

int SubExtI_uxth_andNode::reloc() const {
  return 2;
}

int andI_reg_regNode::reloc() const {
  return 2;
}

int andI_reg_immNode::reloc() const {
  return 1;
}

int orI_reg_regNode::reloc() const {
  return 2;
}

int orI_reg_immNode::reloc() const {
  return 1;
}

int xorI_reg_regNode::reloc() const {
  return 2;
}

int xorI_reg_immNode::reloc() const {
  return 1;
}

int convI2L_reg_regNode::reloc() const {
  return 1;
}

int convUI2L_reg_regNode::reloc() const {
  return 1;
}

int convI2BNode::reloc() const {
  return 1;
}

int convI2F_reg_regNode::reloc() const {
  return 1;
}

int convI2D_reg_regNode::reloc() const {
  return 1;
}

int overflowAddI_reg_regNode::reloc() const {
  return 2;
}

int overflowAddI_reg_immNode::reloc() const {
  return 1;
}

int overflowSubI_reg_regNode::reloc() const {
  return 2;
}

int overflowSubI_reg_immNode::reloc() const {
  return 1;
}

int overflowNegI_regNode::reloc() const {
  return 1;
}

int overflowMulI_regNode::reloc() const {
  return 2;
}

int overflowMulI_reg_branchNode::reloc() const {
  return 2;
}

int testP_regNode::reloc() const {
  return 1;
}

int compF_reg_zeroNode::reloc() const {
  return 1;
}

int compD_reg_zeroNode::reloc() const {
  return 1;
}

int compF3_reg_immF0Node::reloc() const {
  return 1;
}

int compD3_reg_immD0Node::reloc() const {
  return 1;
}

int cmpLTMask_reg_regNode::reloc() const {
  return 2;
}

int cmpLTMask_reg_zeroNode::reloc() const {
  return 1;
}

int cmpI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_narrowOop_imm0_branchNode::reloc() const {
  return 1;
}

int cmpUI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpI_branch_signNode::reloc() const {
  return 1;
}

int cmpI_branch_bitNode::reloc() const {
  return 1;
}

int far_cmpI_branch_signNode::reloc() const {
  return 1;
}

int far_cmpI_branch_bitNode::reloc() const {
  return 1;
}

int cmpI_andNode::reloc() const {
  return 1;
}

int cmpI_and_regNode::reloc() const {
  return 2;
}

int safePointNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectHandleNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirectNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int TailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int partialSubtypeCheckVsZeroNode::reloc() const {
  return 1;
}

int loadV4Node::reloc() const {
  return 1;
}

int loadV8Node::reloc() const {
  return 1;
}

int loadV16Node::reloc() const {
  return 1;
}

int storeV4Node::reloc() const {
  return 2;
}

int storeV8Node::reloc() const {
  return 2;
}

int storeV16Node::reloc() const {
  return 2;
}

int replicate8BNode::reloc() const {
  return 1;
}

int replicate16BNode::reloc() const {
  return 1;
}

int replicate4SNode::reloc() const {
  return 1;
}

int replicate8SNode::reloc() const {
  return 1;
}

int replicate2INode::reloc() const {
  return 1;
}

int replicate4INode::reloc() const {
  return 1;
}

int vshiftcnt8BNode::reloc() const {
  return 1;
}

int vshiftcnt8B_0Node::reloc() const {
  return 1;
}

int vshiftcnt16BNode::reloc() const {
  return 1;
}

int vshiftcnt16B_0Node::reloc() const {
  return 1;
}


void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2288 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrsbw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9374 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2294 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrsb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9391 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2306 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9408 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2306 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9425 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2312 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrshw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9442 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2318 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrsh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9459 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2330 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9476 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2330 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9493 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2342 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9510 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2348 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrsw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9527 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 2342 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9545 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2354 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9562 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2342 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9579 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2354 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9596 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2342 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9613 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2354 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9630 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2342 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9647 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2360 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrs, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9664 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2366 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrd, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9681 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2868 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    u_int32_t con = (u_int32_t)opnd_array(1)->constant();
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (con == 0) {
      __ movw(dst_reg, zr);
    } else {
      __ movw(dst_reg, con);
    }
  
#line 9703 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2879 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    u_int64_t con = (u_int64_t)opnd_array(1)->constantL();
    if (con == 0) {
      __ mov(dst_reg, zr);
    } else {
      __ mov(dst_reg, con);
    }
  
#line 9725 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 2890 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL || con == (address)1) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      if (rtype == relocInfo::oop_type) {
        __ movoop(dst_reg, (jobject)con, /*immediate*/true);
      } else if (rtype == relocInfo::metadata_type) {
        __ mov_metadata(dst_reg, (Metadata*)con);
      } else {
        assert(rtype == relocInfo::none, "unexpected reloc type");
	if (con < (address)(uintptr_t)os::vm_page_size()) {
	  __ mov(dst_reg, con);
	} else {
	  unsigned long offset;
	  __ adrp(dst_reg, con, offset);
	  __ add(dst_reg, dst_reg, offset);
	}
      }
    }
  
#line 9761 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 2915 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 9778 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConP1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 2921 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, (u_int64_t)1);
  
#line 9795 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConPollPageNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 2927 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    address page = (address)opnd_array(1)->constant();
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    unsigned long off;
    __ adrp(dst_reg, Address(page, relocInfo::poll_type), off);
    assert(off == 0, "assumed offset == 0");
  
#line 9815 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadByteMapBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 2936 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    __ load_byte_map_base(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 9831 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 2941 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::oop_type, "unexpected reloc type");
      __ set_narrow_oop(dst_reg, (jobject)con);
    }
  
#line 9855 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 2954 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 9872 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 2960 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::metadata_type, "unexpected reloc type");
      __ set_narrow_klass(dst_reg, (Klass *)con);
    }
  
#line 9896 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConF_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6693 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), (double)opnd_array(1)->constantF());
  
#line 9912 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6711 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 9928 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConFNode::eval_constant(Compile* C) {
  {

#line 6712 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 9937 "../generated/adfiles/ad_aarch64.cpp"
  }
}
void loadConD_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6724 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->constantD());
  
#line 9952 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 6741 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 9968 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadConDNode::eval_constant(Compile* C) {
  {

#line 6742 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 9977 "../generated/adfiles/ad_aarch64.cpp"
  }
}
void storeimmCM0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2396 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 9994 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeimmCM0_orderedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2402 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    __ membar(Assembler::StoreStore);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10013 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2390 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strb, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10031 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeimmB0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2396 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10049 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2409 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strh, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10067 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeimmC0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2415 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strh, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10085 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2421 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10103 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeimmI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2427 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10121 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2433 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10147 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeimmL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2447 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10165 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6899 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int opcode = opnd_array(1)->opcode();
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int size = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    Register reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);

    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (reg == r31_sp) {
      MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      reg = rscratch2;
    }
    Address::extend scale;

    // Hooboy, this is fugly.  We need a way to communicate to the
    // encoder that the index needs to be sign extended, so we have to
    // enumerate all the cases.
    switch (opcode) {
    case INDINDEXSCALEDOFFSETI2L:
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDOFFSETI2LN:
    case INDINDEXSCALEDI2LN:
    case INDINDEXOFFSETI2L:
    case INDINDEXOFFSETI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    Address adr;
    if (index == -1) {
      adr = Address(base, disp);
    } else {
      if (disp == 0) {
        adr = Address(base, as_Register(index), scale);
      } else {
        __ lea(rscratch1, Address(base, disp));
        adr = Address(rscratch1, as_Register(index), scale);
      }
    }

    __ str(reg, adr);
  
#line 10227 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeimmP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2447 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10245 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2421 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10263 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeImmN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2421 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(R27_enc);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10281 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2453 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strs, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10299 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2459 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strd, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10317 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2421 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 10335 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void prefetchrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {

#line 2808 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
      __ prfm(Address(base, disp), PLDL1KEEP);
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ prfm(Address(base, index_reg, Address::lsl(scale)), PLDL1KEEP);
      } else {
        __ lea(rscratch1, Address(base, disp));
	__ prfm(Address(rscratch1, index_reg, Address::lsl(scale)), PLDL1KEEP);
      }
    }
  
#line 10365 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void prefetchwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {

#line 2827 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
      __ prfm(Address(base, disp), PSTL1KEEP);
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ prfm(Address(base, index_reg, Address::lsl(scale)), PSTL1KEEP);
      } else {
        __ lea(rscratch1, Address(base, disp));
	__ prfm(Address(rscratch1, index_reg, Address::lsl(scale)), PSTL1KEEP);
      }
    }
  
#line 10395 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void prefetchntaNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {

#line 2846 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
      __ prfm(Address(base, disp), PSTL1STRM);
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ prfm(Address(base, index_reg, Address::lsl(scale)), PSTL1STRM);
        __ nop();
      } else {
        __ lea(rscratch1, Address(base, disp));
	__ prfm(Address(rscratch1, index_reg, Address::lsl(scale)), PSTL1STRM);
      }
    }
  
#line 10426 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2578 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 10444 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2578 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 10462 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2590 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarb);
  
#line 10478 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2590 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarb);
  
#line 10494 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2595 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarh);
    __ sxthw(dst_reg, dst_reg);
  
#line 10512 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2609 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarh);
  
#line 10528 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2614 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarh);
  
#line 10544 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2602 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarh);
    __ sxth(dst_reg, dst_reg);
  
#line 10562 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2624 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarw);
  
#line 10578 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadUI2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 2624 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarw);
  
#line 10595 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2629 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldar);
  
#line 10611 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2629 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldar);
  
#line 10627 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2624 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarw);
  
#line 10643 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2634 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldarw);
    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 10660 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2640 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
	     rscratch1, ldar);
    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 10677 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2549 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
		 rscratch1, stlrb);
    if (VM_Version::cpu_cpuFeatures() & VM_Version::CPU_DMB_ATOMICS)
      __ dmb(__ ISH);
  
#line 10696 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeC_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2556 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
		 rscratch1, stlrh);
    if (VM_Version::cpu_cpuFeatures() & VM_Version::CPU_DMB_ATOMICS)
      __ dmb(__ ISH);
  
#line 10715 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2563 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
		 rscratch1, stlrw);
    if (VM_Version::cpu_cpuFeatures() & VM_Version::CPU_DMB_ATOMICS)
      __ dmb(__ ISH);
  
#line 10734 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2646 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
 	MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
		 rscratch1, stlr);
    if (VM_Version::cpu_cpuFeatures() & VM_Version::CPU_DMB_ATOMICS)
      __ dmb(__ ISH);
  
#line 10762 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2646 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
 	MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
		 rscratch1, stlr);
    if (VM_Version::cpu_cpuFeatures() & VM_Version::CPU_DMB_ATOMICS)
      __ dmb(__ ISH);
  
#line 10790 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2563 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
		 rscratch1, stlrw);
    if (VM_Version::cpu_cpuFeatures() & VM_Version::CPU_DMB_ATOMICS)
      __ dmb(__ ISH);
  
#line 10809 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2662 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    {
      MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovs(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
		 rscratch1, stlrw);
    if (VM_Version::cpu_cpuFeatures() & VM_Version::CPU_DMB_ATOMICS)
      __ dmb(__ ISH);
  
#line 10833 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2674 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    {
      MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovd(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
		 rscratch1, stlr);
    if (VM_Version::cpu_cpuFeatures() & VM_Version::CPU_DMB_ATOMICS)
      __ dmb(__ ISH);
  
#line 10857 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7393 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ revw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 10873 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7406 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ rev(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 10889 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7419 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 10905 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7433 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */), 0U, 15U);
  
#line 10922 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7449 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 10938 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7461 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 10954 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7474 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ rbitw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 10971 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7488 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ rbit(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 10988 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 7510 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ movw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */); // ensure top 32 bits 0
    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 11009 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void popCountI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 7531 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrs, tmp_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 11031 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 7554 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 11051 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void popCountL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 7574 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldrd, tmp_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 11073 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void load_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7595 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 11089 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void unnecessary_membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7608 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ block_comment("membar_acquire (elided)");
  
#line 11105 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7621 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ block_comment("membar_acquire");
    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 11122 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7636 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ block_comment("membar_acquire_lock (elided)");
  
#line 11138 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void store_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7649 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 11154 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void unnecessary_membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7662 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ block_comment("membar_release (elided)");
  
#line 11170 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7674 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ block_comment("membar_release");
    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 11187 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7687 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ membar(Assembler::StoreStore);
  
#line 11203 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7699 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ block_comment("membar_release_lock (elided)");
  
#line 11219 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7713 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ block_comment("membar_volatile (elided)");
  
#line 11235 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7726 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ block_comment("membar_volatile");
    __ membar(Assembler::StoreLoad);
    
#line 11252 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7743 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 11270 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7758 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 11288 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convP2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7773 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 11304 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convN2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7789 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 11320 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void shenandoahRBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7799 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

#if INCLUDE_ALL_GCS
    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ ldr(d, Address(s, ShenandoahBrooksPointer::byte_offset()));
#else
    ShouldNotReachHere();
#endif
  
#line 11342 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void encodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7818 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ encode_heap_oop(d, s);
  
#line 11360 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void encodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7831 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ encode_heap_oop_not_null(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 11376 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void decodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7843 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop(d, s);
  
#line 11394 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void decodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7857 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop_not_null(d, s);
  
#line 11412 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void encodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7875 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ encode_klass_not_null(dst_reg, src_reg);
  
#line 11430 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void decodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7890 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (dst_reg != src_reg) {
      __ decode_klass_not_null(dst_reg, src_reg);
    } else {
      __ decode_klass_not_null(dst_reg);
    }
  
#line 11452 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castIINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadPLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2688 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {      
        __ lea(rscratch1, Address(base, disp));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ ldaxr(dst_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch1, Address(base, index_reg, Address::lsl(scale)));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        __ lea(rscratch1, Address(base, disp));
        __ lea(rscratch1, Address(rscratch1, index_reg, Address::lsl(scale)));
	__ ldaxr(dst_reg, rscratch1);
      }
    }
  
#line 11531 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storePConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// heap_top_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2717 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register src_reg = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* newval */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {      
        __ lea(rscratch2, Address(base, disp));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ stlxr(rscratch1, src_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch2, Address(base, index_reg, Address::lsl(scale)));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        __ lea(rscratch2, Address(base, disp));
        __ lea(rscratch2, Address(rscratch2, index_reg, Address::lsl(scale)));
	__ stlxr(rscratch1, src_reg, rscratch2);
      }
    }
    __ cmpw(rscratch1, zr);
  
#line 11574 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeLConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2775 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true);
  
#line 11594 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeIConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2782 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true);
  
#line 11614 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2754 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true);
  
#line 11634 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 2800 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 11644 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2747 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true);
  
#line 11664 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 2800 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 11674 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2747 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true);
  
#line 11694 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 2800 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 11704 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 2762 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    __ cmpxchg_oop_shenandoah(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                              /*acquire*/ false, /*release*/ true, /*weak*/ false, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 11727 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2754 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true);
  
#line 11747 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 2800 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 11757 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 8149 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    __ cmpxchg_oop_shenandoah(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ false, /*release*/ true, /*weak*/ false, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 11778 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2782 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true);
  
#line 11798 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 2800 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 11808 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2775 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true);
  
#line 11828 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 2800 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 11838 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2775 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true);
  
#line 11858 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 2800 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 11868 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapPAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 2789 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    __ cmpxchg_oop_shenandoah(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                              /*acquire*/ true, /*release*/ true, /*weak*/ false, /*is_cae*/ false,
                              opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 11892 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 2782 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true);
  
#line 11912 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 2800 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 11922 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compareAndSwapNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 8265 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    __ cmpxchg_oop_shenandoah(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ true, /*release*/ true, /*weak*/ false, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 11943 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_setINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 8277 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 11960 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_setLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 8286 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 11977 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_setNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 8295 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 11994 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_setPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    MacroAssembler _masm(&cbuf);

#line 8304 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 12011 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 8315 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 12028 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_addL_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 8326 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 12045 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_addLiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 8336 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 12062 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 8347 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 12079 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 8357 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 12096 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_addI_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 8368 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 12113 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_addIiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 8378 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 12130 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    MacroAssembler _masm(&cbuf);

#line 8389 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 12147 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8414 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12169 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8430 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12191 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8455 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12213 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8471 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12235 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8487 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12257 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8503 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12279 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8524 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	     zr,
	     zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12304 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8543 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	     zr,
	     zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12329 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8562 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12351 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8578 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12373 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8596 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12395 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8612 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12417 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8628 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12439 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8644 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12461 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8660 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12483 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8676 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12505 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8694 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12527 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8710 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12549 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8726 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12571 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8742 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12593 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8758 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12615 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8774 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12637 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8792 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12659 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 8808 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12681 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8824 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12703 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8840 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 12725 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8857 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 12748 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8875 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 12771 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8893 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 12794 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmovUD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8911 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 12817 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8940 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 12836 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2975 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 12862 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addI_reg_imm_i2lNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2975 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 12888 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8984 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 12907 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addP_reg_reg_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8999 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
  
#line 12926 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addP_reg_reg_lslNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    MacroAssembler _masm(&cbuf);

#line 9014 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	   Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
		   Address::lsl(opnd_array(3)->constant())));
  
#line 12946 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addP_reg_reg_ext_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    MacroAssembler _masm(&cbuf);

#line 9029 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	   Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
		   Address::sxtw(opnd_array(3)->constant())));
  
#line 12966 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void lshift_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// scale
  {
    MacroAssembler _masm(&cbuf);

#line 9044 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sbfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
          opnd_array(2)->constant()& 63, MIN(32, (-opnd_array(2)->constant()) & 63));
  
#line 12985 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2989 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 13011 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9078 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13030 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2989 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 13056 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void subI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9109 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13075 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void subI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2975 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 13101 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void subL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9141 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13120 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void subL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 2989 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 13146 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void negI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9173 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	    as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 13164 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void negL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9189 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	   as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 13182 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void mulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9205 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mulw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13201 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void smulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9220 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	     as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
	     as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13220 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void smulI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9220 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	     as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
	     as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 13239 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void mulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9237 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mul(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13258 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void mulHiL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9253 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ smulh(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
	     as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13277 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void maddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9270 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 13298 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void maddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 9270 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 13319 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void msubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9286 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ msubw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 13340 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void maddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9304 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 13361 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void maddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 9304 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 13382 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void msubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9320 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ msub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 13403 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void divINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3003 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 13423 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void signExtractNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// div2
  {
    MacroAssembler _masm(&cbuf);

#line 9346 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lsrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 31);
  
#line 13441 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void div2RoundNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// div2
  {
    MacroAssembler _masm(&cbuf);

#line 9357 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	      as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
	      as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
	      Assembler::LSR, 31);
  
#line 13462 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void div2Round_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// div2
  {
    MacroAssembler _masm(&cbuf);

#line 9357 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	      as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
	      as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
	      Assembler::LSR, 31);
  
#line 13483 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void divLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3011 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 13503 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void signExtractLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// div2
  {
    MacroAssembler _masm(&cbuf);

#line 9382 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 63);
  
#line 13521 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void div2RoundLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// div2
  {
    MacroAssembler _masm(&cbuf);

#line 9393 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	      as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
	      as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
	      Assembler::LSR, 63);
  
#line 13542 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void div2RoundL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// div1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// div2
  {
    MacroAssembler _masm(&cbuf);

#line 9393 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	      as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
	      as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
	      Assembler::LSR, 63);
  
#line 13563 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void modINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3019 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 13583 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void modLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3027 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 13603 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void lShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9437 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lslvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13622 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void lShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9453 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lslw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 13641 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void urShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9469 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lsrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13660 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void urShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9485 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lsrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 13679 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void rShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9501 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ asrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13698 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void rShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9517 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 13717 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void lShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9538 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lslv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13736 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void lShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9554 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lsl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x3f);
  
#line 13755 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void urShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9570 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lsrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13774 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void urShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9586 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 13793 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void urShiftP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9602 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 13812 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void rShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9618 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ asrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 13831 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void rShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9634 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ asr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 13850 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void regL_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 9652 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 13870 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void regI_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 9668 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 13890 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 9685 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 13911 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9685 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 13932 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 9702 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 13953 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9702 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 13974 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 9719 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 13995 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9719 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 14016 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 9736 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 14037 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9736 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 14058 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9753 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 14079 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 9753 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 14100 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9770 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 14121 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    MacroAssembler _masm(&cbuf);

#line 9770 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 14142 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9787 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 14165 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9787 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 14188 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9805 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 14211 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9805 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 14234 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9823 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 14257 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9823 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 14280 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9841 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 14303 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9841 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 14326 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9859 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 14349 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9859 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 14372 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9877 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 14395 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9877 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 14418 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9895 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 14441 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9895 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 14464 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 9895 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x1f);
  
#line 14487 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9895 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 14510 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9913 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 14533 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9913 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 14556 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 9913 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x3f);
  
#line 14579 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9913 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 14602 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9931 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 14625 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9931 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 14648 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 9931 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x1f);
  
#line 14671 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9931 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 14694 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9949 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 14717 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9949 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 14740 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 9949 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x3f);
  
#line 14763 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9949 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 14786 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9967 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 14809 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9967 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 14832 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 9967 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x1f);
  
#line 14855 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9967 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 14878 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 9985 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 14901 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9985 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 14924 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 9985 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x3f);
  
#line 14947 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 9985 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 14970 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 10003 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 14993 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10003 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 15016 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 10021 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 15039 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10021 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 15062 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 10039 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 15085 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10039 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 15108 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 10057 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 15131 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10057 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 15154 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 10075 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 15177 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10075 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 15200 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    MacroAssembler _masm(&cbuf);

#line 10093 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 15223 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10093 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 15246 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10112 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 15268 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10112 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 15290 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10131 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 15312 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10131 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 15334 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10150 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 15356 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10150 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 15378 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10169 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 15400 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10169 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 15422 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10188 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 15444 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10188 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 15466 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10207 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 15488 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10207 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 15510 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10226 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 15532 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10226 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 15554 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10245 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 15576 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10245 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 15598 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10264 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 15620 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10264 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 15642 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10283 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 15664 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10283 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 15686 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10302 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 15708 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10302 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 15730 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10321 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 15752 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10321 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 15774 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10340 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 15796 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10340 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 15818 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10359 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 15840 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10359 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 15862 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10378 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 15884 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10378 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 15906 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10397 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 15928 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10397 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 15950 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10416 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 15972 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10416 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 15994 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10435 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 16016 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10435 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 16038 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10454 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 16060 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10454 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 16082 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10473 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 16104 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10473 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 16126 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10492 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 16148 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10492 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 16170 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10511 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 16192 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10511 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 16214 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10530 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 16236 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10530 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 16258 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10549 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 16280 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 10549 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 16302 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10568 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 16324 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10587 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 16346 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10606 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 16368 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10625 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 16390 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10644 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 16412 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 10663 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 16434 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void sbfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    MacroAssembler _masm(&cbuf);

#line 10687 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int lshift = opnd_array(2)->constant(), rshift = opnd_array(3)->constant();
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ sbfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 16457 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void sbfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    MacroAssembler _masm(&cbuf);

#line 10710 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int lshift = opnd_array(2)->constant(), rshift = opnd_array(3)->constant();
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 16480 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void ubfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    MacroAssembler _masm(&cbuf);

#line 10733 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int lshift = opnd_array(2)->constant(), rshift = opnd_array(3)->constant();
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ ubfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 16503 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void ubfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    MacroAssembler _masm(&cbuf);

#line 10756 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int lshift = opnd_array(2)->constant(), rshift = opnd_array(3)->constant();
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ ubfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 16526 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void ubfxwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 10775 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int rshift = opnd_array(2)->constant();
    long mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfxw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 16548 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void ubfxLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 10790 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int rshift = opnd_array(2)->constant();
    long mask = opnd_array(3)->constantL();
    int width = exact_log2(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 16570 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void ubfxIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 10808 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int rshift = opnd_array(2)->constant();
    long mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 16592 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void extrOrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 10828 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 16612 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void extrOrL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 10828 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 16632 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void extrOrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 10843 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 16652 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void extrOrI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 10843 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 16672 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void extrAddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 10858 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 16692 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void extrAddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 10858 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 16712 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void extrAddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 10873 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 16732 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void extrAddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 10873 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 16752 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void rolL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 10889 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            rscratch1);
    
#line 16771 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void rolI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 10905 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            rscratch1);
    
#line 16790 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void rorL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 10957 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    
#line 16808 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void rorI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 10972 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    
#line 16826 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11023 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 16844 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11023 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 16862 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11036 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 16880 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 11050 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 16900 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11050 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 16920 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 11063 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 16940 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11063 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 16960 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 11076 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 16980 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11076 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 17000 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 11089 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 17020 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11089 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 17040 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_sxtwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 11102 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 17060 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11102 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 17080 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 11115 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 17100 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11115 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 17120 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 11128 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 17140 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11128 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 17160 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11142 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 17179 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11142 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 17198 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11155 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 17217 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11155 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 17236 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11168 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 17255 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11168 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 17274 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11181 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 17293 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11181 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 17312 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11194 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 17331 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 11194 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw);
   
#line 17350 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11207 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 17369 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11220 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 17388 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11233 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 17407 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11246 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 17426 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11259 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 17445 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11277 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17464 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11292 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ faddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17483 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11307 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17502 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11322 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17521 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11337 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmuls(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17540 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11352 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmuld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17559 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11500 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fdivs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17578 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11515 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fdivd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17597 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void negF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11530 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fnegs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 17614 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void negD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11544 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fnegd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 17631 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11557 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fabss(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 17648 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11570 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fabsd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 17665 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11583 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fsqrtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 17682 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11596 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fsqrts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 17699 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void andI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11618 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	    as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
	    as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17718 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void andI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11633 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	    as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
	    (unsigned long)(opnd_array(2)->constant()));
  
#line 17737 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void orI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11650 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17756 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void orI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11665 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (unsigned long)(opnd_array(2)->constant()));
  
#line 17775 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void xorI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11682 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17794 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void xorI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11697 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (unsigned long)(opnd_array(2)->constant()));
  
#line 17813 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void andL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11715 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
	    as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
	    as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17832 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void andL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11730 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (unsigned long)(opnd_array(2)->constantL()));
  
#line 17851 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void orL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11747 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17870 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void orL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11762 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (unsigned long)(opnd_array(2)->constantL()));
  
#line 17889 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void xorL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11779 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 17908 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void xorL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 11794 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (unsigned long)(opnd_array(2)->constantL()));
  
#line 17927 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11809 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sbfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 17943 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convUI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11822 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ubfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 17960 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11835 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ movw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 17976 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11852 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 17993 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convP2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11870 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 18010 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11884 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcvtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18026 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11897 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcvts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18042 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11910 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcvtzsw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18058 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convF2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11923 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcvtzs(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18074 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11936 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ scvtfws(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18090 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convL2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11949 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ scvtfs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18106 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11962 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcvtzdw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18122 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11975 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcvtzd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18138 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convI2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11988 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ scvtfwd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18154 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void convL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12001 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ scvtfd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18170 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12020 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ldrw(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 18186 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveI2F_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12038 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 18202 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12056 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 18218 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveL2D_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12074 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 18234 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveF2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12092 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ strs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 18250 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12110 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ strw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 18266 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveD2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12128 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ strd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 18282 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12146 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ str(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 18298 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12164 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmovs(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18314 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12182 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 18330 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12200 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18346 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void MoveL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 12218 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 18362 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void clearArray_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 12237 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
  
#line 18379 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void clearArray_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 12252 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, (u_int64_t)opnd_array(1)->constantL());
  
#line 18397 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowAddI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12268 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 18414 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowAddI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12281 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 18431 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowAddL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12294 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmn(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 18448 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowAddL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12307 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmn(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 18465 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowSubI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12320 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 18482 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowSubI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12333 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 18499 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowSubL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12346 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 18516 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowSubL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12359 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 18533 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowNegI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    MacroAssembler _masm(&cbuf);

#line 12372 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmpw(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 18550 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowNegL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    MacroAssembler _masm(&cbuf);

#line 12385 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmp(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 18567 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowMulI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12402 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ smull(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 18588 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowMulI_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 12424 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ smull(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 18611 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowMulL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    MacroAssembler _masm(&cbuf);

#line 12446 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mul(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 31);    // Top is pure sign ext
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 18633 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void overflowMulL_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 12470 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ mul(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 31);    // Top is pure sign ext
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 18657 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3037 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 18676 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compI_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3044 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 18699 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compI_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3044 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 18722 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compI_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3055 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    u_int32_t val = (u_int32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 18742 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compU_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3037 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 18761 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compU_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3044 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 18784 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compU_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3044 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 18807 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compU_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3055 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    u_int32_t val = (u_int32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 18827 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3063 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 18846 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3070 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (u_int64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 18873 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3070 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (u_int64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 18900 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3085 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    u_int64_t val = (u_int64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 18920 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3063 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 18939 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compUL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3070 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (u_int64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 18966 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compUL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3070 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (u_int64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 18993 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compUL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3085 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    u_int64_t val = (u_int64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 19013 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3093 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 19032 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3100 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 19051 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void testP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3107 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmp(reg, zr);
  
#line 19069 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void testN_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3113 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmpw(reg, zr);
  
#line 19087 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12781 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19104 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compF_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12795 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0D);
  
#line 19121 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12810 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19138 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compD_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12824 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0D);
  
#line 19155 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compF3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12842 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 19181 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compD3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12870 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 19207 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compF3_reg_immF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 12897 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, 0.0D);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 19232 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void compD3_reg_immD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 12924 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, 0.0D);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 19257 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 12953 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 19276 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {
    MacroAssembler _masm(&cbuf);

#line 12974 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* p */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* q */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::LT);
    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), zr, as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 19295 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 12992 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 31);
  
#line 19312 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void minI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13015 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::LT);
  
#line 19334 "../generated/adfiles/ad_aarch64.cpp"
  }
}

uint minI_rRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void maxI_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 13041 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::GT);
  
#line 19361 "../generated/adfiles/ad_aarch64.cpp"
  }
}

uint maxI_rRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3119 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(1)->label();
    __ b(*L);
  
#line 19383 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void branchConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3125 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 19402 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void branchConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3131 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 19421 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 13125 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 19445 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 13144 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 19469 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpP_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 13163 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 19493 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpN_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 13182 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 19517 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpP_narrowOop_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 13201 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
  
#line 19541 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpUI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 13222 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 19565 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpUL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 13243 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 19589 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 13265 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L);
  
#line 19611 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 13283 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L);
  
#line 19633 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 13302 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 19656 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 13321 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2(opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 19679 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void far_cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 13340 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L, /*far*/true);
  
#line 19701 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void far_cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 13357 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L, /*far*/true);
  
#line 19723 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void far_cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 13375 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 19746 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void far_cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 13393 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2(opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 19769 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpL_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    MacroAssembler _masm(&cbuf);

#line 13411 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 19787 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpI_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    MacroAssembler _masm(&cbuf);

#line 13424 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 19805 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpL_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    MacroAssembler _masm(&cbuf);

#line 13435 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 19823 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpI_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    MacroAssembler _masm(&cbuf);

#line 13446 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 19841 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void branchLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3125 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 19860 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void branchLoopEndUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3131 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 19879 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3291 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;
    Label cas_failed;

    assert_different_registers(oop, box, tmp, disp_hdr);

    // Load markOop from object into displaced_header.
    __ ldr(disp_hdr, Address(oop, oopDesc::mark_offset_in_bytes()));

    // Always do locking in runtime.
    if (EmitSync & 0x01) {
      __ cmp(oop, zr);
      return;
    }
    
    if (UseBiasedLocking && !UseOptoBiasInlining) {
      __ biased_locking_enter(box, oop, disp_hdr, tmp, true, cont);
    }

    // Handle existing monitor
    if ((EmitSync & 0x02) == 0) {
      __ tbnz(disp_hdr, exact_log2(markOopDesc::monitor_value), object_has_monitor);
    }

    // Set displaced_header to be (markOop of object | UNLOCK_VALUE).
    __ orr(disp_hdr, disp_hdr, markOopDesc::unlocked_value);

    // Load Compare Value application register.

    // Initialize the box. (Must happen before we update the object mark!)
    __ str(disp_hdr, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    // Compare object markOop with mark and if equal exchange scratch1
    // with object markOop.
    if (UseLSE) {
      __ mov(tmp, disp_hdr);
      __ casal(Assembler::xword, tmp, box, oop);
      __ cmp(tmp, disp_hdr);
      __ br(Assembler::EQ, cont);
    } else {
      Label retry_load;
      if ((VM_Version::cpu_cpuFeatures() & VM_Version::CPU_STXR_PREFETCH))
        __ prfm(Address(oop), PSTL1STRM);
      __ bind(retry_load);
      __ ldaxr(tmp, oop);
      __ cmp(tmp, disp_hdr);
      __ br(Assembler::NE, cas_failed);
      // use stlxr to ensure update is immediately visible
      __ stlxr(tmp, box, oop);
      __ cbzw(tmp, cont);
      __ b(retry_load);
    }

    assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

    // If the compare-and-exchange succeeded, then we found an unlocked
    // object, will have now locked it will continue at label cont

    __ bind(cas_failed);
    // We did not see an unlocked object so try the fast recursive case.

    // Check if the owner is self by comparing the value in the
    // markOop of object (disp_hdr) with the stack pointer.
    __ mov(rscratch1, sp);
    __ sub(disp_hdr, disp_hdr, rscratch1);
    __ mov(tmp, (address) (~(os::vm_page_size()-1) | markOopDesc::lock_mask_in_place));
    // If condition is true we are cont and hence we can store 0 as the
    // displaced header in the box, which indicates that it is a recursive lock.
    __ ands(tmp/*==0?*/, disp_hdr, tmp);
    __ str(tmp/*==0, perhaps*/, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    // Handle existing monitor.
    if ((EmitSync & 0x02) == 0) {
      __ b(cont);

      __ bind(object_has_monitor);
      // The object's monitor m is unlocked iff m->owner == NULL,
      // otherwise m->owner may contain a thread or a stack address.
      //
      // Try to CAS m->owner from NULL to current thread.
      __ add(tmp, disp_hdr, (ObjectMonitor::owner_offset_in_bytes()-markOopDesc::monitor_value));
      __ mov(disp_hdr, zr);

      if (UseLSE) {
        __ mov(rscratch1, disp_hdr);
        __ casal(Assembler::xword, rscratch1, rthread, tmp);
        __ cmp(rscratch1, disp_hdr);
      } else {
	Label retry_load, fail;
        if ((VM_Version::cpu_cpuFeatures() & VM_Version::CPU_STXR_PREFETCH))
          __ prfm(Address(tmp), PSTL1STRM);
	__ bind(retry_load);
        __ ldaxr(rscratch1, tmp);
	__ cmp(disp_hdr, rscratch1);
	__ br(Assembler::NE, fail);
        // use stlxr to ensure update is immediately visible
	__ stlxr(rscratch1, rthread, tmp);
	__ cbnzw(rscratch1, retry_load);
	__ bind(fail);
      }

      // Store a non-null value into the box to avoid looking like a re-entrant
      // lock. The fast-path monitor unlock code checks for
      // markOopDesc::monitor_value so use markOopDesc::unused_mark which has the
      // relevant bit set, and also matches ObjectSynchronizer::slow_enter.
      __ mov(tmp, (address)markOopDesc::unused_mark());
      __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));
    }

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 20013 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3411 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;

    assert_different_registers(oop, box, tmp, disp_hdr);

    // Always do locking in runtime.
    if (EmitSync & 0x01) {
      __ cmp(oop, zr); // Oop can't be 0 here => always false.
      return;
    }

    if (UseBiasedLocking && !UseOptoBiasInlining) {
      __ biased_locking_exit(oop, tmp, cont);
    }

    // Find the lock address and load the displaced header from the stack.
    __ ldr(disp_hdr, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    // If the displaced header is 0, we have a recursive unlock.
    __ cmp(disp_hdr, zr);
    __ br(Assembler::EQ, cont);

    // Handle existing monitor.
    if ((EmitSync & 0x02) == 0) {
      __ ldr(tmp, Address(oop, oopDesc::mark_offset_in_bytes()));
      __ tbnz(disp_hdr, exact_log2(markOopDesc::monitor_value), object_has_monitor);
    }

    // Check if it is still a light weight lock, this is is true if we
    // see the stack address of the basicLock in the markOop of the
    // object.

    if (UseLSE) {
      __ mov(tmp, box);
      __ casl(Assembler::xword, tmp, disp_hdr, oop);
      __ cmp(tmp, box);
      __ b(cont);
    } else {
      Label retry_load;
      if ((VM_Version::cpu_cpuFeatures() & VM_Version::CPU_STXR_PREFETCH))
        __ prfm(Address(oop), PSTL1STRM);
      __ bind(retry_load);
      __ ldxr(tmp, oop);
      __ cmp(box, tmp);
      __ br(Assembler::NE, cont);
      // use stlxr to ensure update is immediately visible
      __ stlxr(tmp, disp_hdr, oop);
      __ cbzw(tmp, cont);
      __ b(retry_load);
    }

    assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

    // Handle existing monitor.
    if ((EmitSync & 0x02) == 0) {
      __ bind(object_has_monitor);
      __ add(tmp, tmp, -markOopDesc::monitor_value); // monitor
      __ ldr(rscratch1, Address(tmp, ObjectMonitor::owner_offset_in_bytes()));
      __ ldr(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));
      __ eor(rscratch1, rscratch1, rthread); // Will be 0 if we are the owner.
      __ orr(rscratch1, rscratch1, disp_hdr); // Will be 0 if there are 0 recursions
      __ cmp(rscratch1, zr);
      __ br(Assembler::NE, cont);

      __ ldr(rscratch1, Address(tmp, ObjectMonitor::EntryList_offset_in_bytes()));
      __ ldr(disp_hdr, Address(tmp, ObjectMonitor::cxq_offset_in_bytes()));
      __ orr(rscratch1, rscratch1, disp_hdr); // Will be 0 if both are 0.
      __ cmp(rscratch1, zr);
      __ br(Assembler::NE, cont);
      // need a release store here
      __ lea(tmp, Address(tmp, ObjectMonitor::owner_offset_in_bytes()));
      __ stlr(zr, tmp); // set unowned
    }

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 20112 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void safePointNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// cr
  {
    MacroAssembler _masm(&cbuf);

#line 13541 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ read_polling_page(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* poll */), relocInfo::poll_type);
  
#line 20128 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3155 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);

    address mark = __ pc();
    address addr = (address)opnd_array(1)->method();
    address call;
    if (!_method) {
      // A call to a runtime wrapper, e.g. new, new_typeArray_Java, uncommon_trap.
      call = __ trampoline_call(Address(addr, relocInfo::runtime_call_type), &cbuf);
    } else if (_optimized_virtual) {
      call = __ trampoline_call(Address(addr, relocInfo::opt_virtual_call_type), &cbuf);
    } else {
      call = __ trampoline_call(Address(addr, relocInfo::static_call_type), &cbuf);
    }
    if (call == NULL) {
      ciEnv::current()->record_failure("CodeCache is full"); 
      return;
    }

    if (_method) {
      // Emit stub for static call
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf, mark);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full"); 
        return;
      }
    }
  
#line 20168 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 3230 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 20180 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void CallStaticJavaDirectHandleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// reg_mh_save
  {

#line 3184 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    relocInfo::relocType reloc;

    // RFP is preserved across all calls, even compiled calls.
    // Use it to preserve SP.
    __ mov(rfp, sp);

    address mark = __ pc();
    address addr = (address)opnd_array(1)->method();
    address call;
    if (!_method) {
      // A call to a runtime wrapper, e.g. new, new_typeArray_Java, uncommon_trap.
      call = __ trampoline_call(Address(addr, relocInfo::runtime_call_type), &cbuf);
    } else if (_optimized_virtual) {
      call = __ trampoline_call(Address(addr, relocInfo::opt_virtual_call_type), &cbuf);
    } else {
      call = __ trampoline_call(Address(addr, relocInfo::static_call_type), &cbuf);
    }
    if (call == NULL) {
      ciEnv::current()->record_failure("CodeCache is full"); 
      return;
    }

    if (_method) {
      // Emit stub for static call
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf, mark);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full"); 
        return;
      }
    }

    // now restore sp
    __ mov(sp, rfp);
  
#line 20228 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 3230 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 20240 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3221 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    address call = __ ic_call((address)opnd_array(1)->method());
    if (call == NULL) {
      ciEnv::current()->record_failure("CodeCache is full"); 
      return;
    }
  
#line 20260 "../generated/adfiles/ad_aarch64.cpp"
  }
  {

#line 3230 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 20272 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3238 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full"); 
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
  
#line 20310 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3238 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full"); 
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
  
#line 20348 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3238 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full"); 
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
  
#line 20386 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3275 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    __ br(target_reg);
  
#line 20404 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void TailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3281 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    // exception oop should be in r0
    // ret addr has been popped into lr
    // callee expects it in r3
    __ mov(r3, lr);
    __ br(target_reg);
  
#line 20426 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3265 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    __ far_jump(RuntimeAddress(OptoRuntime::rethrow_stub()));
  
#line 20455 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3270 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    MacroAssembler _masm(&cbuf);
    __ ret(lr);
  
#line 20471 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 13743 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    // TODO
    // implement proper trap call here
    __ brk(999);
  
#line 20489 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  {

#line 3138 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(opnd_array(0)->reg(ra_,this)/* result */);

     Label miss;
     MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x1 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 20518 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void partialSubtypeCheckVsZeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 3138 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(R5_enc);

     Label miss;
     MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x0 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 20548 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void string_compareNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    MacroAssembler _masm(&cbuf);

#line 13797 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc));
  
#line 20569 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void string_indexofNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    MacroAssembler _masm(&cbuf);

#line 13813 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */);
  
#line 20596 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void string_indexof_conNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    MacroAssembler _masm(&cbuf);

#line 13832 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */);
  
#line 20624 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void string_equalsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 13850 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
		      opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc));
  
#line 20644 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void array_equalsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  {
    MacroAssembler _masm(&cbuf);

#line 13865 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ char_arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                          opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc));
  
#line 20662 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void encode_iso_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  {
    MacroAssembler _masm(&cbuf);

#line 13883 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ encode_iso_array(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
         opnd_array(0)->as_Register(ra_,this)/* result */, as_FloatRegister(V0_enc),  as_FloatRegister(V1_enc),
         as_FloatRegister(V2_enc),  as_FloatRegister(V3_enc));
  
#line 20682 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint tlsLoadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2372 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 20712 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2378 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 20729 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void loadV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2384 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 20746 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2465 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 20764 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2471 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 20782 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void storeV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2477 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 20800 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13985 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 20816 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 13997 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 20832 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 14010 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, opnd_array(1)->constant()& 0xff);
  
#line 20848 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 14022 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, opnd_array(1)->constant()& 0xff);
  
#line 20864 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14035 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 20880 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14047 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 20896 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 14060 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, opnd_array(1)->constant()& 0xffff);
  
#line 20912 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 14072 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, opnd_array(1)->constant()& 0xffff);
  
#line 20928 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14084 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 20944 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14096 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 20960 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 14108 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, opnd_array(1)->constant());
  
#line 20976 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 14120 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, opnd_array(1)->constant());
  
#line 20992 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14132 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 21008 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate2L_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 14144 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
           as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 21026 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14158 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 21043 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14171 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 21060 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void replicate2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 14184 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 21077 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14202 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21096 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14216 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21115 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14231 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21134 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14245 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21153 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14259 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21172 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14273 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21191 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14287 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21210 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14301 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21229 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14315 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21248 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vadd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14328 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21267 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14345 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21286 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14359 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21305 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14374 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21324 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14388 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21343 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14402 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21362 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14416 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21381 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14430 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21400 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14444 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21419 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14458 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21438 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsub2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14472 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21457 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14489 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21476 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14503 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21495 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14517 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21514 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14531 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21533 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14545 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21552 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14559 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21571 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14573 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21590 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmla4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14590 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21610 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmla8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14604 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21630 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmla2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14618 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21650 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmla4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14632 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21670 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmls4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14649 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21690 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmls8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14663 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21710 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmls2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14677 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21730 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vmls4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14691 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21750 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vdiv2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14707 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21769 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vdiv4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14721 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21788 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vdiv2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14735 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21807 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vand8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14752 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21826 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vand16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14766 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21845 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14783 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21864 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14797 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21883 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vxor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14814 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21902 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vxor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 14828 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21921 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vshiftcnt8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 14842 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 21937 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vshiftcnt8B_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 14842 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 21953 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vshiftcnt16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 14853 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 21969 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vshiftcnt16B_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    MacroAssembler _masm(&cbuf);

#line 14853 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 21985 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 14865 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 22004 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 14878 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 22023 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 14915 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22045 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 14932 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22067 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 14950 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22089 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 14967 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22111 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 14983 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 22136 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15002 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 22161 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15022 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 8) sh = 7;
    sh = -sh & 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 22182 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15037 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 8) sh = 7;
    sh = -sh & 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 22203 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15053 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), -sh & 7);
    }
  
#line 22228 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15072 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), -sh & 7);
    }
  
#line 22253 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15092 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 22272 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15105 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 22291 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15121 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22313 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15138 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22335 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15156 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22357 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15173 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22379 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15189 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 22404 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15208 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 22429 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15228 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 16) sh = 15;
    sh = -sh & 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 22450 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15243 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 16) sh = 15;
    sh = -sh & 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 22471 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15259 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), -sh & 15);
    }
  
#line 22496 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15278 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    int sh = (int)opnd_array(2)->constant()& 31;
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), -sh & 15);
    }
  
#line 22521 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15297 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 22540 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15310 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 22559 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15325 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22581 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15342 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22603 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15359 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22625 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15376 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22647 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15391 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant()& 31);
  
#line 22666 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15404 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant()& 31);
  
#line 22685 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15417 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            -(int)opnd_array(2)->constant()& 31);
  
#line 22704 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15430 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            -(int)opnd_array(2)->constant()& 31);
  
#line 22723 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15443 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            -(int)opnd_array(2)->constant()& 31);
  
#line 22742 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15456 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            -(int)opnd_array(2)->constant()& 31);
  
#line 22761 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15469 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 22780 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15484 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22802 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 15501 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 22824 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsll2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15516 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant()& 63);
  
#line 22843 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsra2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15529 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            -(int)opnd_array(2)->constant()& 63);
  
#line 22862 "../generated/adfiles/ad_aarch64.cpp"
  }
}

void vsrl2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 15542 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            -(int)opnd_array(2)->constant()& 63);
  
#line 22881 "../generated/adfiles/ad_aarch64.cpp"
  }
}

const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0_orderedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmB0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmC0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmI0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmL0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmP0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmN0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchwNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchntaNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeC_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPLockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeIConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16Node::memory_operand() const { return _opnds[1]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // RegFlags
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    false,  // AbsI
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    true ,  // AryEq
    false,  // AtanD
    true ,  // Binary
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    false,  // CProj
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    true ,  // CallRuntime
    true ,  // CallStaticJava
    true ,  // CastII
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // ConstraintCast
    true ,  // CMoveD
    true ,  // CMoveF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    true ,  // CMoveN
    true ,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    true ,  // CmpUL
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    true ,  // CompareAndSwapN
    true ,  // GetAndAddI
    true ,  // GetAndAddL
    true ,  // GetAndSetI
    true ,  // GetAndSetL
    true ,  // GetAndSetP
    true ,  // GetAndSetN
    false,  // Con
    true ,  // ConN
    true ,  // ConNKlass
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    false,  // CosD
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CreateEx
    true ,  // DecodeN
    true ,  // DecodeNKlass
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // DivMod
    false,  // DivModI
    false,  // DivModL
    true ,  // EncodeISOArray
    true ,  // EncodeP
    true ,  // EncodePKlass
    false,  // ExpD
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // Goto
    true ,  // Halt
    true ,  // If
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    false,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    false,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    true ,  // LoadNKlass
    true ,  // LoadL
    false,  // LoadL_unaligned
    true ,  // LoadPLocked
    true ,  // LoadP
    true ,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    false,  // LogD
    false,  // Log10D
    false,  // Loop
    false,  // LoopLimit
    false,  // Mach
    false,  // MachProj
    true ,  // MaxI
    true ,  // MemBarAcquire
    true ,  // LoadFence
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // StoreFence
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    false,  // ModD
    false,  // ModF
    true ,  // ModI
    true ,  // ModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    true ,  // MulD
    true ,  // MulF
    true ,  // MulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    false,  // Opaque1
    false,  // Opaque2
    false,  // Opaque3
    false,  // ProfileBoolean
    true ,  // OrI
    true ,  // OrL
    true ,  // OverflowAddI
    true ,  // OverflowSubI
    true ,  // OverflowMulI
    true ,  // OverflowAddL
    true ,  // OverflowSubL
    true ,  // OverflowMulL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    false,  // PowD
    true ,  // PrefetchAllocation
    true ,  // PrefetchRead
    true ,  // PrefetchWrite
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // Root
    false,  // RoundDouble
    false,  // RoundFloat
    true ,  // SafePoint
    false,  // SafePointScalarObject
    true ,  // ShenandoahReadBarrier
    false,  // ShenandoahWriteBarrier
    false,  // ShenandoahWBMemProj
    false,  // SCMemProj
    false,  // SinD
    true ,  // SqrtD
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StorePConditional
    true ,  // StoreIConditional
    true ,  // StoreLConditional
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    true ,  // StoreN
    true ,  // StoreNKlass
    true ,  // StrComp
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    false,  // TanD
    true ,  // ThreadLocal
    false,  // Unlock
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    true ,  // AddVB
    true ,  // AddVS
    true ,  // AddVI
    true ,  // AddVL
    true ,  // AddVF
    true ,  // AddVD
    true ,  // SubVB
    true ,  // SubVS
    true ,  // SubVI
    true ,  // SubVL
    true ,  // SubVF
    true ,  // SubVD
    true ,  // MulVS
    true ,  // MulVI
    true ,  // MulVF
    true ,  // MulVD
    true ,  // DivVF
    true ,  // DivVD
    true ,  // LShiftCntV
    true ,  // RShiftCntV
    true ,  // LShiftVB
    true ,  // LShiftVS
    true ,  // LShiftVI
    true ,  // LShiftVL
    true ,  // RShiftVB
    true ,  // RShiftVS
    true ,  // RShiftVI
    true ,  // RShiftVL
    true ,  // URShiftVB
    true ,  // URShiftVS
    true ,  // URShiftVI
    true ,  // URShiftVL
    true ,  // AndV
    true ,  // OrV
    true ,  // XorV
    true ,  // LoadVector
    true ,  // StoreVector
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    true ,  // ReplicateL
    true ,  // ReplicateF
    true ,  // ReplicateD
    false,  // Extract
    false,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    false,  // ExtractS
    false,  // ExtractI
    false,  // ExtractL
    false,  // ExtractF
    false   // ExtractD
};


bool Matcher::stack_direction() const { return false; }

int Compile::sync_stack_slots() const { return 2; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 2 +
              round_to((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::in_preserve_stack_slots() { return 4; }

uint Compile::out_preserve_stack_slots() { return SharedRuntime::out_preserve_stack_slots(); }

uint Compile::varargs_C_out_slots_killed() const { return frame::arg_reg_save_area_bytes/BytesPerInt; }

void Matcher::calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length, bool is_outgoing) {

#line 3616 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    // No difference between ingoing/outgoing just pass false
    SharedRuntime::java_calling_convention(sig_bt, regs, length, false);
  
#line 23336 "../generated/adfiles/ad_aarch64.cpp"

}

void Matcher::c_calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length) {

#line 3622 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    // This is obviously always outgoing
    (void) SharedRuntime::c_calling_convention(sig_bt, regs, NULL, length);
  
#line 23347 "../generated/adfiles/ad_aarch64.cpp"

}

OptoRegPair Matcher::return_value(uint ideal_reg, bool is_outgoing) {

#line 3629 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };
  
    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                       // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 23383 "../generated/adfiles/ad_aarch64.cpp"

}

OptoRegPair Matcher::c_return_value(uint ideal_reg, bool is_outgoing) {

#line 3629 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.232.b09-0.el7_7.aarch64/openjdk/hotspot/src/cpu/aarch64/vm/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };
  
    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                       // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 23419 "../generated/adfiles/ad_aarch64.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(R12_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_method_oop_reg() { return OptoReg::Name(R12_num); }

int Matcher::interpreter_method_oop_reg_encode() { return _regEncode[interpreter_method_oop_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(R29_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(R31_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

bool Compile::needs_clone_jvms() { return false; }

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DAARCH64=1
#ifndef AARCH64
#  error "AARCH64 must be defined"
#endif // AARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
